@@ -45,6 +45,11 @@ typedef int socklen_t;
 #include <sys/socket.h>
 #endif
 
+// FlightGear modification: for FreeBSD compat
+#if !defined(WIN32)
+    #include <sys/time.h> // for struct timeval
+#endif
+    
 #ifdef BUILDING_DLL
 # if defined(WIN32) ||  defined(_WIN32_WCE)
 #  ifdef _MSC_VER
