@@ -24,9 +24,10 @@
 
 #include <simgear/sg_inlines.h>
 
-#include <Viewer/viewer.hxx>
+#include <Viewer/view.hxx>
 #include <Scenery/scenery.hxx>
 #include <Airports/dynamics.hxx>
+#include <Main/globals.hxx>
 
 #include "AIGroundVehicle.hxx"
 
