@@ -28,9 +28,6 @@
 #include <simgear/structure/commands.hxx>
 #include <simgear/structure/SGBinding.hxx>
 
-#include <boost/mem_fn.hpp>
-#include <boost/foreach.hpp>
-
 #include <Main/globals.hxx>
 #include <Main/fg_props.hxx>
 #include <Airports/airport.hxx>
@@ -56,7 +53,7 @@ public:
     Scenario(FGAIManager* man, const std::string& nm, SGPropertyNode* scenarios) :
         _internalName(nm)
     {
-        BOOST_FOREACH(SGPropertyNode* scEntry, scenarios->getChildren("entry")) {
+        for (auto scEntry : scenarios->getChildren("entry")) {
             FGAIBasePtr ai = man->addObject(scEntry);
             if (ai) {
                 _objects.push_back(ai);
@@ -81,9 +78,9 @@ public:
     
     ~Scenario()
     {
-        BOOST_FOREACH(FGAIBasePtr ai, _objects) {
-            ai->setDie(true);
-        }
+        std::for_each(_objects.begin(), _objects.end(),
+                      [](FGAIBasePtr ai) { ai->setDie(true); });
+
         
         FGNasalSys* nasalSys = (FGNasalSys*) globals->get_subsystem("nasal");
         if (!nasalSys)
@@ -117,7 +114,7 @@ FGAIManager::FGAIManager() :
 
 FGAIManager::~FGAIManager()
 {
-    std::for_each(ai_list.begin(), ai_list.end(), boost::mem_fn(&FGAIBase::unbind));
+    std::for_each(ai_list.begin(), ai_list.end(), std::mem_fn(&FGAIBase::unbind));
 }
 
 void
@@ -136,6 +133,16 @@ FGAIManager::init() {
     globals->get_commands()->addCommand("load-scenario", this, &FGAIManager::loadScenarioCommand);
     globals->get_commands()->addCommand("unload-scenario", this, &FGAIManager::unloadScenarioCommand);
     _environmentVisiblity = fgGetNode("/environment/visibility-m");
+    
+    // Create an (invisible) AIAircraft representation of the current
+    // users's aircraft, that mimicks the user aircraft's behavior.
+
+    _userAircraft = new FGAIAircraft;
+    _userAircraft->setCallSign ( fgGetString("/sim/multiplay/callsign")  );
+    _userAircraft->setGeodPos(globals->get_aircraft_position());
+    _userAircraft->setPerformance("", "jet_transport");
+    _userAircraft->setHeading(fgGetDouble("/orientation/heading-deg"));
+    _userAircraft->setSpeed(fgGetDouble("/velocities/groundspeed-kt"));
 }
 
 void
@@ -148,7 +155,7 @@ FGAIManager::postinit()
         enabled->setBoolValue(true);
 
     // process all scenarios
-    BOOST_FOREACH(SGPropertyNode* n, root->getChildren("scenario")) {
+    for (auto n : root->getChildren("scenario")) {
         const string& name = n->getStringValue();
         if (name.empty())
             continue;
@@ -170,7 +177,7 @@ FGAIManager::reinit()
     unloadAllScenarios();
     
     update(0.0);
-    std::for_each(ai_list.begin(), ai_list.end(), boost::mem_fn(&FGAIBase::reinit));
+    std::for_each(ai_list.begin(), ai_list.end(), std::mem_fn(&FGAIBase::reinit));
     
     // (re-)load scenarios
     postinit();
@@ -181,7 +188,7 @@ FGAIManager::shutdown()
 {
     unloadAllScenarios();
     
-    BOOST_FOREACH(FGAIBase* ai, ai_list) {
+    for (FGAIBase* ai : ai_list) {
         // other subsystems, especially ATC, may have references. This
         // lets them detect if the AI object should be skipped
         ai->setDie(true);
@@ -190,6 +197,7 @@ FGAIManager::shutdown()
     
     ai_list.clear();
     _environmentVisiblity.clear();
+    _userAircraft.clear();
     
     globals->get_commands()->removeCommand("load-scenario");
     globals->get_commands()->removeCommand("unload-scenario");
@@ -223,7 +231,8 @@ void FGAIManager::removeDeadItem(FGAIBase* base)
 }
 
 void
-FGAIManager::update(double dt) {
+FGAIManager::update(double dt)
+{
     // initialize these for finding nearest thermals
     range_nearest = 10000.0;
     strength = 0.0;
@@ -231,14 +240,14 @@ FGAIManager::update(double dt) {
     if (!enabled->getBoolValue())
         return;
 
-    fetchUserState();
+    fetchUserState(dt);
 
     // partition the list into dead followed by alive
-    ai_list_iterator firstAlive =
-      std::stable_partition(ai_list.begin(), ai_list.end(), boost::mem_fn(&FGAIBase::getDie));
+    auto firstAlive =
+      std::stable_partition(ai_list.begin(), ai_list.end(), std::mem_fn(&FGAIBase::getDie));
     
     // clean up each item and finally remove from the container
-    for (ai_list_iterator it=ai_list.begin(); it != firstAlive; ++it) {
+    for (auto it=ai_list.begin(); it != firstAlive; ++it) {
         removeDeadItem(*it);
     }
   
@@ -247,7 +256,7 @@ FGAIManager::update(double dt) {
     // every remaining item is alive. update them in turn, but guard for
     // exceptions, so a single misbehaving AI object doesn't bring down the
     // entire subsystem.
-    BOOST_FOREACH(FGAIBase* base, ai_list) {
+    for (FGAIBase* base : ai_list) {
         try {
             if (base->isa(FGAIBase::otThermal)) {
                 processThermal(dt, (FGAIThermal*)base);
@@ -269,7 +278,7 @@ void
 FGAIManager::updateLOD(SGPropertyNode* node)
 {
     SG_UNUSED(node);
-    std::for_each(ai_list.begin(), ai_list.end(), boost::mem_fn(&FGAIBase::updateLOD));
+    std::for_each(ai_list.begin(), ai_list.end(), std::mem_fn(&FGAIBase::updateLOD));
 }
 
 void
@@ -317,14 +326,19 @@ FGAIManager::getNumAiObjects() const
 }
 
 void
-FGAIManager::fetchUserState( void ) {
+FGAIManager::fetchUserState( double dt )
+{
 
     globals->get_aircraft_orientation(user_heading, user_pitch, user_roll);
     user_speed     = user_speed_node->getDoubleValue() * 0.592484;
     wind_from_east = wind_from_east_node->getDoubleValue();
     wind_from_north   = wind_from_north_node->getDoubleValue();
     user_altitude_agl = user_altitude_agl_node->getDoubleValue();
-
+    
+    _userAircraft->setGeodPos(globals->get_aircraft_position());
+    _userAircraft->setHeading(user_heading);
+    _userAircraft->setSpeed(fgGetDouble("/velocities/groundspeed-kt"));
+    _userAircraft->update(dt);
 }
 
 // only keep the results from the nearest thermal
@@ -339,7 +353,7 @@ FGAIManager::processThermal( double dt, FGAIThermal* thermal ) {
 
 }
 
-bool FGAIManager::loadScenarioCommand(const SGPropertyNode* args)
+bool FGAIManager::loadScenarioCommand(const SGPropertyNode* args, SGPropertyNode *)
 {
     std::string name = args->getStringValue("name");
     if (args->hasChild("load-property")) {
@@ -370,9 +384,9 @@ bool FGAIManager::loadScenarioCommand(const SGPropertyNode* args)
     return ok;
 }
 
-bool FGAIManager::unloadScenarioCommand(const SGPropertyNode* args)
+bool FGAIManager::unloadScenarioCommand(const SGPropertyNode * arg, SGPropertyNode * root)
 {
-    std::string name = args->getStringValue("name");
+    std::string name = arg->getStringValue("name");
     return unloadScenario(name);
 }
 
@@ -426,7 +440,7 @@ FGAIBasePtr FGAIManager::addObject(const SGPropertyNode* definition)
 bool FGAIManager::removeObject(const SGPropertyNode* args)
 {
     int id = args->getIntValue("id");
-    BOOST_FOREACH(FGAIBase* ai, get_ai_list()) {
+    for (FGAIBase* ai : get_ai_list()) {
         if (ai->getID() == id) {
             ai->setDie(true);
             break;
@@ -438,13 +452,12 @@ bool FGAIManager::removeObject(const SGPropertyNode* args)
 
 FGAIBasePtr FGAIManager::getObjectFromProperty(const SGPropertyNode* aProp) const
 {
-    BOOST_FOREACH(FGAIBase* ai, get_ai_list()) {
-        if (ai->_getProps() == aProp) {
-            return ai;
-        }
-    } // of AI objects iteration
-    
-    return NULL;
+    auto it = std::find_if(ai_list.begin(), ai_list.end(),
+                           [aProp](FGAIBasePtr ai) { return ai->_getProps() == aProp; });
+    if (it == ai_list.end()) {
+        return nullptr;
+    }
+    return *it;
 }
 
 bool
@@ -519,45 +532,6 @@ FGAIManager::loadScenarioFile(const std::string& filename)
     return 0;
 }
 
-bool
-FGAIManager::getStartPosition(const string& id, const string& pid,
-                              SGGeod& geodPos, double& hdng, SGVec3d& uvw)
-{
-    bool found = false;
-    SGPropertyNode* root = fgGetNode("sim/ai", true);
-    if (!root->getNode("enabled", true)->getBoolValue())
-        return found;
-
-    for (int i = 0 ; (!found) && i < root->nChildren() ; i++) {
-        SGPropertyNode *aiEntry = root->getChild( i );
-        if ( !strcmp( aiEntry->getName(), "scenario" ) ) {
-            const string& filename = aiEntry->getStringValue();
-            SGPropertyNode_ptr scenarioTop = loadScenarioFile(filename);
-            if (scenarioTop) {
-                SGPropertyNode* scenarios = scenarioTop->getChild("scenario");
-                if (scenarios) {
-                    for (int i = 0; i < scenarios->nChildren(); i++) {
-                        SGPropertyNode* scEntry = scenarios->getChild(i);
-                        const std::string& type = scEntry->getStringValue("type");
-                        const std::string& pnumber = scEntry->getStringValue("pennant-number");
-                        const std::string& name = scEntry->getStringValue("name");
-                        if (type == "carrier" && (pnumber == id || name == id)) {
-                            SGSharedPtr<FGAICarrier> carrier = new FGAICarrier;
-                            carrier->readFromScenario(scEntry);
-
-                            if (carrier->getParkPosition(pid, geodPos, hdng, uvw)) {
-                                found = true;
-                                break;
-                            }
-                        }
-                    }
-                }
-            }
-        }
-    }
-    return found;
-}
-
 const FGAIBase *
 FGAIManager::calcCollision(double alt, double lat, double lon, double fuse_range)
 {
@@ -616,10 +590,15 @@ FGAIManager::calcCollision(double alt, double lat, double lon, double fuse_range
 }
 
 double
-FGAIManager::calcRangeFt(const SGVec3d& aCartPos, FGAIBase* aObject) const
+FGAIManager::calcRangeFt(const SGVec3d& aCartPos, const FGAIBase* aObject) const
 {
     double distM = dist(aCartPos, aObject->getCartPos());
     return distM * SG_METER_TO_FEET;
 }
 
+FGAIAircraft* FGAIManager::getUserAircraft() const
+{
+    return _userAircraft.get();
+}
+
 //end AIManager.cxx
