@@ -30,6 +30,7 @@
 
 #include <Main/globals.hxx>
 #include <Main/fg_props.hxx>
+#include <Time/TimeManager.hxx>
 
 #include "AIMultiplayer.hxx"
 
@@ -81,6 +82,10 @@ bool FGAIMultiplayer::init(bool search_in_AI_path) {
 void FGAIMultiplayer::bind() {
     FGAIBase::bind();
 
+    //2018.1 mp-clock-mode indicates the clock mode that the client is running, so for backwards
+    //       compatibility ensure this is initialized to 0 which means pre 2018.1
+    props->setIntValue("sim/multiplay/mp-clock-mode", 0);
+    
     tie("refuel/contact", SGRawValuePointer<bool>(&contact));
     tie("tanker", SGRawValuePointer<bool>(&isTanker));
 
@@ -128,7 +133,8 @@ void FGAIMultiplayer::update(double dt)
   // The current simulation time we need to update for,
   // note that the simulation time is updated before calling all the
   // update methods. Thus it contains the time intervals *end* time
-  double curtime = globals->get_sim_time_sec();
+  // 2018: notice this time is specifically used for mp protocol
+  double curtime = globals->get_subsystem<TimeManager>()->getMPProtocolClockSec();
 
   // Get the last available time
   MotionInfo::reverse_iterator it = mMotionInfo.rbegin();
@@ -323,7 +329,6 @@ void FGAIMultiplayer::update(double dt)
                   {
                       //cout << "Found " << pIt->second->getPath() << ":";
 
-                      int ival;
                       float val;
                       /*
                        * RJH - 2017-01-25
@@ -342,10 +347,10 @@ void FGAIMultiplayer::update(double dt)
                           case props::INT:
                           case props::BOOL:
                           case props::LONG:
-                              ival = (int)(0.5 + (1 - tau)*((double)(*prevPropIt)->int_value) +
-                                  tau*((double)(*nextPropIt)->int_value));
-                              pIt->second->setIntValue(ival);
-                              //cout << "Int: " << ival << "\n";
+                              // Jean Pellotier, 2018-01-02 : we don't want interpolation for integer values, they are mostly used 
+                              // for non linearly changing values (e.g. transponder etc ...)
+                              // fixes: https://sourceforge.net/p/flightgear/codetickets/1885/
+                              pIt->second->setIntValue((*nextPropIt)->int_value);
                               break;
                           case props::FLOAT:
                           case props::DOUBLE:
