@@ -1,7 +1,4 @@
-//
-// simple.cxx -- a really simplistic class to manage airport ID,
-//               lat, lon of the center of one of it's runways, and
-//               elevation in feet.
+// airport.cxx -- Classes representing airports, seaports and helipads
 //
 // Written by Curtis Olson, started April 1998.
 // Updated by Durk Talsma, started December, 2004.
@@ -54,6 +51,7 @@
 #include <ATC/CommStation.hxx>
 #include <Navaids/NavDataCache.hxx>
 #include <Navaids/navrecord.hxx>
+#include <Navaids/positioned.hxx>
 #include <Airports/groundnetwork.hxx>
 #include <Airports/xmlloader.hxx>
 
@@ -109,15 +107,6 @@ bool FGAirport::isHeliport() const
   return type() == HELIPORT;
 }
 
-bool FGAirport::isAirportType(FGPositioned* pos)
-{
-    if (!pos) {
-        return false;
-    }
-    
-    return (pos->type() >= AIRPORT) && (pos->type() <= SEAPORT);
-}
-
 //------------------------------------------------------------------------------
 unsigned int FGAirport::numRunways() const
 {
