@@ -37,7 +37,7 @@
 
 #include <simgear/constants.h>
 #include <simgear/debug/logstream.hxx>
-#include <simgear/misc/sgstream.hxx>
+#include <simgear/io/iostreams/sgstream.hxx>
 #include <simgear/misc/strutils.hxx>
 #include <simgear/structure/exception.hxx>
 #include <simgear/misc/sg_path.hxx>
@@ -99,7 +99,6 @@ void APTLoader::readAptDatFile(const SGPath &aptdb_file,
                           sg_location(aptdb_file));
   }
 
-  SG_LOG( SG_GENERAL, SG_INFO, "Opened apt.dat file: '" << apt_dat << "'" );
   string line;
 
   unsigned int rowCode = 0;     // terminology used in the apt.dat format spec
@@ -189,12 +188,7 @@ void APTLoader::readAptDatFile(const SGPath &aptdb_file,
         airportInfo.file = aptdb_file;
         airportInfo.rowCode = rowCode;
         airportInfo.firstLineNum = line_num;
-        airportInfo.firstLineTokens =
-#if __cplusplus >= 201103L
-          std::move(tokens);    // requires C++11, untested
-#else
-          tokens;
-#endif
+        airportInfo.firstLineTokens = std::move(tokens);
       }
     } else if ( rowCode == 99 ) {
       SG_LOG( SG_GENERAL, SG_DEBUG,
@@ -203,12 +197,8 @@ void APTLoader::readAptDatFile(const SGPath &aptdb_file,
     } else if ( !skipAirport ) {
       // Line belonging to an already started, and not skipped airport entry;
       // just append it.
-      airportInfoMap[currentAirportId].otherLines.
-#if __cplusplus >= 201103L
-        emplace_back(line_num, rowCode, line); // requires C++11, untested
-#else
-        push_back(Line(line_num, rowCode, line));
-#endif
+      airportInfoMap[currentAirportId].otherLines.emplace_back(
+        line_num, rowCode, line);
     }
   } // of file reading loop
 
