@@ -42,6 +42,8 @@
 #include <Airports/runways.hxx>
 #include <Airports/groundnetwork.hxx>
 #include <Navaids/NavDataCache.hxx>
+#include <AIModel/AIManager.hxx>
+#include <AIModel/AIBase.hxx>
 
 #include "airport.hxx"
 #include "dynamics.hxx"
@@ -152,6 +154,62 @@ FGParking* ParkingAssignment::parking() const
 
 ////////////////////////////////////////////////////////////////////////////////
 
+/**
+ * @brief Helper to cache all AIObject positions near the airport when
+ * searching for available parkings. This allows us to reject parkings
+ * which we might not have marked as occupied, but which an object is
+ * neverthless close to; such as the primary user or MP aircraft.
+ */
+class NearbyAIObjectCache
+{
+public:
+    NearbyAIObjectCache(FGAirportRef apt) :
+        m_airport(apt)
+    {}
+
+    bool isAnythingNear(const SGVec3d& cart, double radiusM)
+    {
+        if (!m_populated) {
+            populate();
+        }
+
+        for (auto c : m_cache) {
+            const double d = dist(cart, c);
+            if (d < radiusM) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
+private:
+    void populate()
+    {
+#if !defined(FG_TESTLIB)
+        SGVec3d cartAirportPos = m_airport->cart();
+        FGAIManager* aiManager = globals->get_subsystem<FGAIManager>();
+        for (auto ai : aiManager->get_ai_list()) {
+            const auto cart = ai->getCartPos();
+
+            // 20km cutoff from airport centre
+            if (dist(cartAirportPos, cart) > 20000) {
+                continue;
+            }
+
+            m_cache.push_back(cart);
+        }
+#endif
+        m_populated = true;
+    }
+
+    bool m_populated = false;
+    FGAirportRef m_airport;
+    std::vector<SGVec3d> m_cache;
+};
+
+////////////////////////////////////////////////////////////////////////////////
+
 FGAirportDynamics::FGAirportDynamics(FGAirport * ap):
     _ap(ap), rwyPrefs(ap),
     startupController    (this),
@@ -167,7 +225,6 @@ FGAirportDynamics::FGAirportDynamics(FGAirport * ap):
 // Destructor
 FGAirportDynamics::~FGAirportDynamics()
 {
-    SG_LOG(SG_AI, SG_INFO, "destroyed dynamics for:" << _ap->ident());
 }
 
 
@@ -182,13 +239,21 @@ FGParking* FGAirportDynamics::innerGetAvailableParking(double radius, const stri
                                            const string & airline,
                                            bool skipEmptyAirlineCode)
 {
+    NearbyAIObjectCache nearCache(parent());
     const FGParkingList& parkings(parent()->groundNetwork()->allParkings());
-    FGParkingList::const_iterator it;
-    for (it = parkings.begin(); it != parkings.end(); ++it) {
-        FGParkingRef parking = *it;
+    FGParkingList candidates;
+    for (auto parking : parkings) {
         if (!isParkingAvailable(parking)) {
           continue;
         }
+        
+        if (parking->getRadius() < radius) {
+            continue;
+        }
+        
+        if (!flType.empty() && (parking->getType() != flType)) {
+            continue;
+        }
 
         if (skipEmptyAirlineCode && parking->getCodes().empty()) {
           continue;
@@ -200,11 +265,26 @@ FGParking* FGAirportDynamics::innerGetAvailableParking(double radius, const stri
           }
         }
 
-        setParkingAvailable(parking, false);
-        return parking;
+        if (nearCache.isAnythingNear(parking->cart(), parking->getRadius())) {
+            continue;
+        }
+
+        candidates.push_back(parking);
+    }
+    
+    if (candidates.empty()) {
+        return nullptr;
     }
 
-    return NULL;
+    // sort by increasing radius, so we return the smallest radius candidate
+    // this avoids large spaces (A380 sized) being given to Fokkers/ATR-72s
+    std::sort(candidates.begin(), candidates.end(),
+              [](const FGParkingRef& a, const FGParkingRef& b) {
+                  return a->getRadius() < b->getRadius();
+              });
+    
+    setParkingAvailable(candidates.front(), false);
+    return candidates.front();
 }
 
 bool FGAirportDynamics::hasParkings() const
@@ -302,7 +382,7 @@ FGParkingList FGAirportDynamics::getParkings(bool onlyAvailable, const std::stri
     FGParkingList result(parent()->groundNetwork()->allParkings());
 
     GetParkingsPredicate pred(onlyAvailable, type, this);
-    FGParkingList::iterator it = std::remove_if(result.begin(), result.end(), pred);
+    auto it = std::remove_if(result.begin(), result.end(), pred);
     result.erase(it, result.end());
     return result;
 }
@@ -479,8 +559,7 @@ string FGAirportDynamics::fallbackGetActiveRunway(int action, double heading)
         // discount runways based on cross / tail-wind
         WindExclusionCheck windCheck(windHeading, windSpeed);
         RunwayVec runways(parent()->getRunways());
-        RunwayVec::iterator it = std::remove_if(runways.begin(), runways.end(),
-                                                windCheck);
+        auto it = std::remove_if(runways.begin(), runways.end(), windCheck);
         runways.erase(it, runways.end());
 
         // sort highest scored to lowest scored
