@@ -63,14 +63,14 @@
 using namespace flightgear;
 using std::string;
 
-static bool commandLoadFlightPlan(const SGPropertyNode* arg)
+static bool commandLoadFlightPlan(const SGPropertyNode* arg, SGPropertyNode *)
 {
   FGRouteMgr* self = (FGRouteMgr*) globals->get_subsystem("route-manager");
   SGPath path = SGPath::fromUtf8(arg->getStringValue("path"));
   return self->loadRoute(path);
 }
 
-static bool commandSaveFlightPlan(const SGPropertyNode* arg)
+static bool commandSaveFlightPlan(const SGPropertyNode* arg, SGPropertyNode *)
 {
   FGRouteMgr* self = (FGRouteMgr*) globals->get_subsystem("route-manager");
   SGPath path = SGPath::fromUtf8(arg->getStringValue("path"));
@@ -92,7 +92,7 @@ static bool commandSaveFlightPlan(const SGPropertyNode* arg)
   }
 }
 
-static bool commandActivateFlightPlan(const SGPropertyNode* arg)
+static bool commandActivateFlightPlan(const SGPropertyNode* arg, SGPropertyNode *)
 {
   FGRouteMgr* self = (FGRouteMgr*) globals->get_subsystem("route-manager");
   bool activate = arg->getBoolValue("activate", true);
@@ -105,14 +105,14 @@ static bool commandActivateFlightPlan(const SGPropertyNode* arg)
   return true;
 }
 
-static bool commandClearFlightPlan(const SGPropertyNode*)
+static bool commandClearFlightPlan(const SGPropertyNode*, SGPropertyNode *)
 {
   FGRouteMgr* self = (FGRouteMgr*) globals->get_subsystem("route-manager");
   self->clearRoute();
   return true;
 }
 
-static bool commandSetActiveWaypt(const SGPropertyNode* arg)
+static bool commandSetActiveWaypt(const SGPropertyNode* arg, SGPropertyNode *)
 {
   FGRouteMgr* self = (FGRouteMgr*) globals->get_subsystem("route-manager");
   int index = arg->getIntValue("index");
@@ -124,7 +124,7 @@ static bool commandSetActiveWaypt(const SGPropertyNode* arg)
   return true;
 }
 
-static bool commandInsertWaypt(const SGPropertyNode* arg)
+static bool commandInsertWaypt(const SGPropertyNode* arg, SGPropertyNode *)
 {
   FGRouteMgr* self = (FGRouteMgr*) globals->get_subsystem("route-manager");
   int index = arg->getIntValue("index");
@@ -213,7 +213,7 @@ static bool commandInsertWaypt(const SGPropertyNode* arg)
   return true;
 }
 
-static bool commandDeleteWaypt(const SGPropertyNode* arg)
+static bool commandDeleteWaypt(const SGPropertyNode* arg, SGPropertyNode *)
 {
   FGRouteMgr* self = (FGRouteMgr*) globals->get_subsystem("route-manager");
   int index = arg->getIntValue("index");
@@ -374,7 +374,8 @@ void FGRouteMgr::init() {
 void FGRouteMgr::postinit()
 {
   setFlightPlan(new FlightPlan());
-  
+  _plan->setIdent("default-flightplan");
+    
   SGPath path = SGPath::fromUtf8(_pathNode->getStringValue());
   if (!path.isNull()) {
     SG_LOG(SG_AUTOPILOT, SG_INFO, "loading flight-plan from: " << path);
@@ -445,8 +446,13 @@ void FGRouteMgr::setFlightPlan(const FlightPlanRef& plan)
   }
   
   if (_plan) {
-    _plan->removeDelegate(this);
-    active->setBoolValue(false);
+      _plan->removeDelegate(this);
+
+      if (isRouteActive()) {
+          _plan->finish();
+      }
+      
+      active->setBoolValue(false);
   }
   
   _plan = plan;
@@ -859,7 +865,7 @@ void FGRouteMgr::setDepartureICAO(const std::string& aIdent)
         return;
     }
     
-  if (aIdent.length() < 4) {
+  if (aIdent.length() < 3) {
     _plan->setDeparture((FGAirport*) NULL);
   } else {
     _plan->setDeparture(FGAirport::findByIdent(aIdent));
@@ -997,7 +1003,7 @@ void FGRouteMgr::setDestinationICAO(const std::string& aIdent)
         return;
     }
     
-  if (aIdent.length() < 4) {
+  if (aIdent.length() < 3) {
     _plan->setDestination((FGAirport*) NULL);
   } else {
     _plan->setDestination(FGAirport::findByIdent(aIdent));
@@ -1187,7 +1193,7 @@ SGPropertyNode_ptr FGRouteMgr::wayptNodeAtIndex(int index) const
   return mirror->getChild("wp", index);
 }
 
-bool FGRouteMgr::commandDefineUserWaypoint(const SGPropertyNode* arg)
+bool FGRouteMgr::commandDefineUserWaypoint(const SGPropertyNode * arg, SGPropertyNode * root)
 {
     std::string ident = arg->getStringValue("ident");
     if (ident.empty()) {
@@ -1209,7 +1215,7 @@ bool FGRouteMgr::commandDefineUserWaypoint(const SGPropertyNode* arg)
     return true;
 }
 
-bool FGRouteMgr::commandDeleteUserWaypoint(const SGPropertyNode* arg)
+bool FGRouteMgr::commandDeleteUserWaypoint(const SGPropertyNode * arg, SGPropertyNode * root)
 {
     std::string ident = arg->getStringValue("ident");
     if (ident.empty()) {
