@@ -103,10 +103,9 @@ public:
   virtual double GetAGLevel(double t, const FGLocation& l,
                             FGLocation& cont, FGColumnVector3& n,
                             FGColumnVector3& v, FGColumnVector3& w) const {
-    double loc_cart[3] = { l(FGJSBBase::eX), l(FGJSBBase::eY), l(FGJSBBase::eZ) };
-    double contact[3], normal[3], vel[3], angularVel[3], agl = 0;
-    mInterface->get_agl_ft(t, loc_cart, SG_METER_TO_FEET*2, contact, normal,
-                           vel, angularVel, &agl);
+    double contact[3], normal[3], vel[3], angularVel[3];
+    double agl = mInterface->get_agl_ft(t, l, SG_METER_TO_FEET*2, contact,
+                                        normal, vel, angularVel);
     n = FGColumnVector3( normal[0], normal[1], normal[2] );
     v = FGColumnVector3( vel[0], vel[1], vel[2] );
     w = FGColumnVector3( angularVel[0], angularVel[1], angularVel[2] );
@@ -115,10 +114,9 @@ public:
   }
 
   virtual double GetTerrainGeoCentRadius(double t, const FGLocation& l) const {
-    double loc_cart[3] = { l(FGJSBBase::eX), l(FGJSBBase::eY), l(FGJSBBase::eZ) };
-    double contact[3], normal[3], vel[3], angularVel[3], agl = 0;
-    mInterface->get_agl_ft(t, loc_cart, SG_METER_TO_FEET*2, contact, normal,
-                           vel, angularVel, &agl);
+    double contact[3], normal[3], vel[3], angularVel[3];
+    mInterface->get_agl_ft(t, l, SG_METER_TO_FEET*2, contact,
+                           normal, vel, angularVel);
     return sqrt(contact[0]*contact[0]+contact[1]*contact[1]+contact[2]*contact[2]);
   }
 
@@ -157,7 +155,7 @@ std::map<std::string,int> FGJSBsim::TURBULENCE_TYPE_NAMES;
 static FGTurbulenceSeverityTable TurbulenceSeverityTable;
 
 FGJSBsim::FGJSBsim( double dt )
-  : FGInterface(dt), got_wire(false)
+  : FGInterface(dt)
 {
     bool result;
     if( TURBULENCE_TYPE_NAMES.empty() ) {
@@ -235,6 +233,8 @@ FGJSBsim::FGJSBsim( double dt )
     fgGetNode("/fdm/jsbsim/sim-time-sec", true)->alias( node );
 // end of sim-time-sec deprecation patch
 
+    _ai_wake_enabled = fgGetNode("fdm/ai-wake/enabled", true);
+
     terrain = fgGetNode("/sim/fdm/surface", true);
 
     fdmex->Setdt( dt );
@@ -335,7 +335,9 @@ FGJSBsim::FGJSBsim( double dt )
     ab_brake_engaged = fgGetNode("/autopilot/autobrake/engaged", true);
     ab_brake_left_pct = fgGetNode("/autopilot/autobrake/brake-left-output", true);
     ab_brake_right_pct = fgGetNode("/autopilot/autobrake/brake-right-output", true);
-    
+    arrestor_wire_engaged_hook = fgGetNode("/fdm/jsbsim/systems/hook/arrestor-wire-engaged-hook", true);
+    release_hook = fgGetNode("/fdm/jsbsim/systems/hook/tailhook-release-cmd", true);
+
     altitude = fgGetNode("/position/altitude-ft");
     temperature = fgGetNode("/environment/temperature-degc",true);
     pressure = fgGetNode("/environment/pressure-inhg",true);
@@ -365,6 +367,9 @@ FGJSBsim::FGJSBsim( double dt )
     last_hook_root[0] = 0; last_hook_root[1] = 0; last_hook_root[2] = 0;
 
     crashed = false;
+
+    mesh = new AircraftMesh(fgGetDouble("/fdm/jsbsim/metrics/bw-ft"),
+                            fgGetDouble("/fdm/jsbsim/metrics/cbarw-ft"));
 }
 
 /******************************************************************************/
@@ -421,11 +426,11 @@ void FGJSBsim::init()
 
     if ( needTrim ) {
       const FGLocation& cart = fgic->GetPosition();
-      double cart_pos[3], contact[3], d[3], vel[3], agl;
-      update_ground_cache(cart, cart_pos, 0.01);
+      double contact[3], d[3], vel[3];
+      update_ground_cache(cart, 0.01);
 
-      get_agl_ft(fdmex->GetSimTime(), cart_pos, SG_METER_TO_FEET*2, contact,
-                 d, vel, d, &agl);
+      get_agl_ft(fdmex->GetSimTime(), cart, SG_METER_TO_FEET*2, contact, d, vel,
+                 d);
       double terrain_alt = sqrt(contact[0]*contact[0] + contact[1]*contact[1]
                                 + contact[2]*contact[2]) - cart.GetSeaLevelRadius();
 
@@ -445,6 +450,15 @@ void FGJSBsim::init()
 
     copy_from_JSBsim(); //update the bus
 
+    _fmag = fgGetNode("/fdm/jsbsim/external_reactions/ai-wake/magnitude", false);
+    _fbx = fgGetNode("/fdm/jsbsim/external_reactions/ai-wake/x", false);
+    _fby = fgGetNode("/fdm/jsbsim/external_reactions/ai-wake/y", false);
+    _fbz = fgGetNode("/fdm/jsbsim/external_reactions/ai-wake/z", false);
+    _mmag = fgGetNode("/fdm/jsbsim/external_reactions/ai-wake/magnitude-lbsft", false);
+    _mbx = fgGetNode("/fdm/jsbsim/external_reactions/ai-wake/l", false);
+    _mby = fgGetNode("/fdm/jsbsim/external_reactions/ai-wake/m", false);
+    _mbz = fgGetNode("/fdm/jsbsim/external_reactions/ai-wake/n", false);
+
     SG_LOG( SG_FLIGHT, SG_INFO, "  Initialized JSBSim with:" );
 
     switch(fgic->GetSpeedSet()) {
@@ -519,9 +533,8 @@ void FGJSBsim::update( double dt )
 
     int multiloop = _calc_multiloop(dt);
     FGLocation cart = Auxiliary->GetLocationVRP();
-    double cart_pos[3];
 
-    update_ground_cache(cart, cart_pos, dt);
+    update_ground_cache(cart, dt);
 
     copy_to_JSBsim();
 
@@ -561,6 +574,8 @@ void FGJSBsim::update( double dt )
       }
     }
 
+    reset_wake_group();
+
     // translate JSBsim back to FG structure so that the
     // autopilot (and the rest of the sim can use the updated values
     copy_from_JSBsim();
@@ -801,10 +816,9 @@ bool FGJSBsim::copy_from_JSBsim()
 
     _set_Altitude_AGL( Propagate->GetDistanceAGL() );
     {
-      double loc_cart[3] = { l(FGJSBBase::eX), l(FGJSBBase::eY), l(FGJSBBase::eZ) };
       double contact[3], d[3], sd, t;
       is_valid_m(&t, d, &sd);
-      get_agl_ft(t, loc_cart, SG_METER_TO_FEET*2, contact, d, d, d, &sd);
+      get_agl_ft(t, l, SG_METER_TO_FEET*2, contact, d, d, d);
       double rwrad
         = FGColumnVector3( contact[0], contact[1], contact[2] ).Magnitude();
       _set_Runway_altitude( rwrad - get_Sea_level_radius() );
@@ -1293,8 +1307,7 @@ void FGJSBsim::do_trim(void)
   SG_LOG( SG_FLIGHT, SG_INFO, "  Trim complete" );
 }
 
-bool FGJSBsim::update_ground_cache(const FGLocation& cart, double* cart_pos,
-                                   double dt)
+bool FGJSBsim::update_ground_cache(const FGLocation& cart, double dt)
 {
   // Compute the radius of the aircraft. That is the radius of a ball
   // where all gear units are in. At the moment it is at least 10ft ...
@@ -1311,9 +1324,7 @@ bool FGJSBsim::update_ground_cache(const FGLocation& cart, double* cart_pos,
   // ground in this area.
   double groundCacheRadius = acrad + 2*dt*Propagate->GetUVW().Magnitude();
 
-  cart_pos[0] = cart(1);
-  cart_pos[1] = cart(2);
-  cart_pos[2] = cart(3);
+  double cart_pos[3] {cart(1), cart(2), cart(3)};
   double t0 = fdmex->GetSimTime();
   bool cache_ok = prepare_ground_cache_ft( t0, t0 + dt, cart_pos,
                                            groundCacheRadius );
@@ -1337,22 +1348,22 @@ bool FGJSBsim::update_ground_cache(const FGLocation& cart, double* cart_pos,
   return cache_ok;
 }
 
-bool
-FGJSBsim::get_agl_ft(double t, const double pt[3], double alt_off,
+double
+FGJSBsim::get_agl_ft(double t, const FGColumnVector3& loc, double alt_off,
                      double contact[3], double normal[3], double vel[3],
-                     double angularVel[3], double *agl)
+                     double angularVel[3])
 {
   const simgear::BVHMaterial* material;
   simgear::BVHNode::Id id;
+  double pt[3] {loc(1), loc(2), loc(3)};
 
   // don't check the return value and continue above scenery discontinuity
   // see http://osdir.com/ml/flightgear-sim/2014-04/msg00145.html
   FGInterface::get_agl_ft(t, pt, alt_off, contact, normal, vel,
-                               angularVel, material, id);
+                          angularVel, material, id);
 
   SGGeod geodPt = SGGeod::fromCart(SG_FEET_TO_METER*SGVec3d(pt));
   SGQuatd hlToEc = SGQuatd::fromLonLat(geodPt);
-  *agl = dot(hlToEc.rotate(SGVec3d(0, 0, 1)), SGVec3d(contact) - SGVec3d(pt));
 
 #ifdef JSBSIM_USE_GROUNDREACTIONS
   bool terrain_active = (terrain->getIntValue("override-level", -1) > 0) ? false : true;
@@ -1382,7 +1393,7 @@ FGJSBsim::get_agl_ft(double t, const double pt[3], double alt_off,
 #else
   terrain->setBoolValue("valid", false);
 #endif
-  return true;
+  return dot(hlToEc.rotate(SGVec3d(0, 0, 1)), SGVec3d(contact) - SGVec3d(pt));
 }
 
 inline static double sqr(double x)
@@ -1447,17 +1458,15 @@ void FGJSBsim::update_external_forces(double t_off)
     FGColumnVector3 hook_tip_body = hook_root_body;
     hook_tip_body(1) -= hook_length * cos_fi;
     hook_tip_body(3) += hook_length * sin_fi;    
-    
-    double contact[3];
-    double ground_normal[3];
-    double ground_vel[3];
-    double ground_angular_vel[3];
-    double root_agl_ft;
-
-    if (!got_wire) {
-        bool got = get_agl_ft(t_off, hook_area[1], 0, contact, ground_normal,
-                              ground_vel, ground_angular_vel, &root_agl_ft);
-        if (got && root_agl_ft > 0 && root_agl_ft < hook_length) {
+    if (!arrestor_wire_engaged_hook->getBoolValue()) {
+      double contact[3];
+      double ground_normal[3];
+      double ground_vel[3];
+      double ground_angular_vel[3];
+      double root_agl_ft = get_agl_ft(t_off, hook_root, 0, contact,
+                                      ground_normal, ground_vel,
+                                      ground_angular_vel);
+        if (root_agl_ft > 0 && root_agl_ft < hook_length) {
             FGColumnVector3 ground_normal_body = Tl2b * (Tec2l * FGColumnVector3(ground_normal[0], ground_normal[1], ground_normal[2]));
             FGColumnVector3 contact_body = Tl2b * Location.LocationToLocal(FGColumnVector3(contact[0], contact[1], contact[2]));
             double D = -DotProduct(contact_body, ground_normal_body);
@@ -1505,31 +1514,40 @@ void FGJSBsim::update_external_forces(double t_off)
     	    }
 	}
     } else {
-        FGColumnVector3 hook_root_vel = Propagate->GetVel() + (Tb2l * (Propagate->GetPQR() *  hook_root_body));
-        double wire_ends_ec[2][3];
-        double wire_vel_ec[2][3];
-        get_wire_ends_ft(t_off, wire_ends_ec, wire_vel_ec);
-        FGColumnVector3 wire_vel_1 = Tec2l * FGColumnVector3(wire_vel_ec[0][0], wire_vel_ec[0][1], wire_vel_ec[0][2]);
-        FGColumnVector3 wire_vel_2 = Tec2l * FGColumnVector3(wire_vel_ec[1][0], wire_vel_ec[1][1], wire_vel_ec[1][2]);
-        FGColumnVector3 rel_vel = hook_root_vel - (wire_vel_1 + wire_vel_2) / 2;
-        if (rel_vel.Magnitude() < 3) {
-            got_wire = false;
+        if (release_hook->getBoolValue()) {
             release_wire();
             fgSetDouble("/fdm/jsbsim/external_reactions/hook/magnitude", 0.0);
+            arrestor_wire_engaged_hook->setBoolValue(false);
+            release_hook->setBoolValue(false);
         } else {
-            FGColumnVector3 wire_end1_body = Tl2b * Location.LocationToLocal(FGColumnVector3(wire_ends_ec[0][0], wire_ends_ec[0][1], wire_ends_ec[0][2])) - hook_root_body;
-            FGColumnVector3 wire_end2_body = Tl2b * Location.LocationToLocal(FGColumnVector3(wire_ends_ec[1][0], wire_ends_ec[1][1], wire_ends_ec[1][2])) - hook_root_body;
-            FGColumnVector3 force_plane_normal = wire_end1_body * wire_end2_body;
-            force_plane_normal.Normalize();
-            cos_fi = DotProduct(force_plane_normal, FGColumnVector3(0, 0, 1));
-            if (cos_fi < 0) cos_fi = -cos_fi;
-            sin_fi = sqrt(1 - sqr(cos_fi));
-            fi = atan2(sin_fi, cos_fi) * SG_RADIANS_TO_DEGREES;
-        
-            fgSetDouble("/fdm/jsbsim/external_reactions/hook/x", -cos_fi);
-            fgSetDouble("/fdm/jsbsim/external_reactions/hook/y", 0);
-            fgSetDouble("/fdm/jsbsim/external_reactions/hook/z", sin_fi);
-            fgSetDouble("/fdm/jsbsim/external_reactions/hook/magnitude", fgGetDouble("/fdm/jsbsim/systems/hook/force"));
+            FGColumnVector3 hook_root_vel = Propagate->GetVel() + (Tb2l * (Propagate->GetPQR() *  hook_root_body));
+            double wire_ends_ec[2][3];
+            double wire_vel_ec[2][3];
+            get_wire_ends_ft(t_off, wire_ends_ec, wire_vel_ec);
+            FGColumnVector3 wire_vel_1 = Tec2l * FGColumnVector3(wire_vel_ec[0][0], wire_vel_ec[0][1], wire_vel_ec[0][2]);
+            FGColumnVector3 wire_vel_2 = Tec2l * FGColumnVector3(wire_vel_ec[1][0], wire_vel_ec[1][1], wire_vel_ec[1][2]);
+            FGColumnVector3 rel_vel = hook_root_vel - (wire_vel_1 + wire_vel_2) / 2;
+            if (rel_vel.Magnitude() < 3) {
+                release_wire();
+                fgSetDouble("/fdm/jsbsim/external_reactions/hook/magnitude", 0.0);
+                arrestor_wire_engaged_hook->setBoolValue(false);
+                release_hook->setBoolValue(false);
+            }
+            else {
+                FGColumnVector3 wire_end1_body = Tl2b * Location.LocationToLocal(FGColumnVector3(wire_ends_ec[0][0], wire_ends_ec[0][1], wire_ends_ec[0][2])) - hook_root_body;
+                FGColumnVector3 wire_end2_body = Tl2b * Location.LocationToLocal(FGColumnVector3(wire_ends_ec[1][0], wire_ends_ec[1][1], wire_ends_ec[1][2])) - hook_root_body;
+                FGColumnVector3 force_plane_normal = wire_end1_body * wire_end2_body;
+                force_plane_normal.Normalize();
+                cos_fi = DotProduct(force_plane_normal, FGColumnVector3(0, 0, 1));
+                if (cos_fi < 0) cos_fi = -cos_fi;
+                sin_fi = sqrt(1 - sqr(cos_fi));
+                fi = atan2(sin_fi, cos_fi) * SG_RADIANS_TO_DEGREES;
+
+                fgSetDouble("/fdm/jsbsim/external_reactions/hook/x", -cos_fi);
+                fgSetDouble("/fdm/jsbsim/external_reactions/hook/y", 0);
+                fgSetDouble("/fdm/jsbsim/external_reactions/hook/z", sin_fi);
+                fgSetDouble("/fdm/jsbsim/external_reactions/hook/magnitude", fgGetDouble("/fdm/jsbsim/systems/hook/force"));
+            }
         }
     }
 
@@ -1539,7 +1557,7 @@ void FGJSBsim::update_external_forces(double t_off)
     hook_area[0][1] = hook_tip(2);
     hook_area[0][2] = hook_tip(3);
 
-    if (!got_wire) {
+    if (!arrestor_wire_engaged_hook->getBoolValue()) {
         // The previous positions.
         hook_area[2][0] = last_hook_root[0];
         hook_area[2][1] = last_hook_root[1];
@@ -1551,7 +1569,7 @@ void FGJSBsim::update_external_forces(double t_off)
         // Check if we caught a wire.
         // Returns true if we caught one.
         if (caught_wire_ft(t_off, hook_area)) {
-                got_wire = true;
+                arrestor_wire_engaged_hook->setBoolValue(true);
         }
     }
     
@@ -1564,5 +1582,35 @@ void FGJSBsim::update_external_forces(double t_off)
     last_hook_root[2] = hook_area[1][2];
     
     fgSetDouble("/fdm/jsbsim/systems/hook/tailhook-pos-deg", fi);
-}
 
+    if (_ai_wake_enabled->getBoolValue()) {
+      FGColumnVector3 uvw = Propagate->GetUVW();
+      FGQuaternion ql2b = Propagate->GetQuaternion();
+      FGLocation l = Auxiliary->GetLocationVRP();
+      SGVec3d cartPos(l(1), l(2), l(3));
+      // The scalar component is the first component in FGQuaternion but
+      // the last component in SGQuat.
+      SGQuatd orient(ql2b(2), ql2b(3), ql2b(4), ql2b(1));
+
+      mesh->setPosition(cartPos * SG_FEET_TO_METER, orient);
+
+      SGVec3d f = mesh->GetForce(get_wake_group(),
+                                 SGVec3d(uvw(1), uvw(2), uvw(3)),
+                                 Atmosphere->GetDensity());
+      const SGVec3d& m = mesh->GetMoment();
+
+      if (_fmag) _fmag->setDoubleValue(1.0);
+      if (_fbx) _fbx->setDoubleValue(f[0]);
+      if (_fby) _fby->setDoubleValue(f[1]);
+      if (_fbz) _fbz->setDoubleValue(f[2]);
+
+      if (_mmag) _mmag->setDoubleValue(1.0);
+      if (_mbx) _mbx->setDoubleValue(m[0]);
+      if (_mby) _mby->setDoubleValue(m[1]);
+      if (_mbz) _mbz->setDoubleValue(m[2]);
+    }
+    else {
+      if (_fmag) _fmag->setDoubleValue(0.0);
+      if (_mmag) _mmag->setDoubleValue(0.0);
+    }
+}
