@@ -65,7 +65,7 @@ using namespace std;
 
 namespace JSBSim {
 
-IDENT(IdSrc,"$Id: FGPropulsion.cpp,v 1.87 2016/05/05 15:38:09 bcoconni Exp $");
+IDENT(IdSrc,"$Id: FGPropulsion.cpp,v 1.88 2017/02/25 14:23:19 bcoconni Exp $");
 IDENT(IdHdr,ID_PROPULSION);
 
 extern short debug_lvl;
@@ -463,14 +463,15 @@ bool FGPropulsion::Load(Element* el)
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-string FGPropulsion::FindFullPathName(const string& filename) const
+SGPath FGPropulsion::FindFullPathName(const SGPath& path) const
 {
-  if (!ReadingEngine) return FGModel::FindFullPathName(filename);
+  if (!ReadingEngine) return FGModel::FindFullPathName(path);
 
-  string name = CheckFullPathName(FDMExec->GetFullAircraftPath() + "/Engines", filename);
-  if (!name.empty()) return name;
+  SGPath name = CheckPathName(FDMExec->GetFullAircraftPath()/string("Engines"),
+                              path);
+  if (!name.isNull()) return name;
 
-  return CheckFullPathName(FDMExec->GetEnginePath(), filename);
+  return CheckPathName(FDMExec->GetEnginePath(), path);
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
