@@ -48,7 +48,7 @@ using namespace std;
 
 namespace JSBSim {
 
-IDENT(IdSrc,"$Id: FGDistributor.cpp,v 1.6 2014/02/17 05:33:25 jberndt Exp $");
+IDENT(IdSrc,"$Id: FGDistributor.cpp,v 1.7 2015/02/27 20:46:01 bcoconni Exp $");
 IDENT(IdHdr,ID_DISTRIBUTOR);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -75,7 +75,7 @@ FGDistributor::FGDistributor(FGFCS* fcs, Element* element) : FGFCSComponent(fcs,
 
   case_element = element->FindElement("case");
   while (case_element) {
-    current_case = new struct Case;
+    current_case = new Case;
     test_element = case_element->FindElement("test");
     if (test_element) current_case->SetTest(new FGCondition(test_element, PropertyManager));
     prop_val_element = case_element->FindElement("property");
