@@ -42,6 +42,7 @@ INCLUDES
 #include <iostream>
 #include <sstream>
 
+#include "FGFDMExec.h"
 #include "math/FGFunction.h"
 #include "FGTurbine.h"
 #include "FGThruster.h"
@@ -51,14 +52,13 @@ using namespace std;
 
 namespace JSBSim {
 
-IDENT(IdSrc,"$Id: FGTurbine.cpp,v 1.48 2015/12/02 04:25:23 dpculp Exp $");
+IDENT(IdSrc,"$Id: FGTurbine.cpp,v 1.49 2017/06/03 19:49:20 bcoconni Exp $");
 IDENT(IdHdr,ID_TURBINE);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-
 FGTurbine::FGTurbine(FGFDMExec* exec, Element *el, int engine_number, struct Inputs& input)
   : FGEngine(engine_number, input), FDMExec(exec)
 {
@@ -86,6 +86,14 @@ FGTurbine::FGTurbine(FGFDMExec* exec, Element *el, int engine_number, struct Inp
 
 FGTurbine::~FGTurbine()
 {
+  // Delete those functions that have requested the construction of a FGSpoolUp
+  // instance. FGModelFunctions will manage the destruction of the other
+  // instances.
+  if (dynamic_cast<FGSpoolUp*>(N1SpoolUp)) delete N1SpoolUp;
+  if (dynamic_cast<FGSpoolUp*>(N1SpoolDown)) delete N1SpoolDown;
+  if (dynamic_cast<FGSpoolUp*>(N2SpoolUp)) delete N2SpoolUp;
+  if (dynamic_cast<FGSpoolUp*>(N2SpoolDown)) delete N2SpoolDown;
+
   Debug(1);
 }
 
@@ -197,8 +205,6 @@ double FGTurbine::Off(void)
 double FGTurbine::Run()
 {
   double idlethrust, milthrust, thrust;
-  double spoolup;                        // acceleration in pct/sec
-  double sigma = in.DensityRatio;
   double T = in.Temperature;
 
   idlethrust = MilThrust * IdleThrustLookup->GetValue();
@@ -207,18 +213,16 @@ double FGTurbine::Run()
   Running = true;
   Starter = false;
 
-  // adjust acceleration for N2 and atmospheric density
-  double n = N2norm + 0.1;
-  if (n > 1) n = 1; 
-  spoolup = delay / (1 + 3 * (1-n)*(1-n)*(1-n) + (1 - sigma));
   N1_factor = MaxN1 - IdleN1;
   N2_factor = MaxN2 - IdleN2;
   if ((Injected == 1) && Injection && (InjWaterNorm > 0)) {
     N1_factor += InjN1increment;
     N2_factor += InjN2increment;
   }  
-  N2 = Seek(&N2, IdleN2 + ThrottlePos * N2_factor, spoolup, spoolup * 3.0);
-  N1 = Seek(&N1, IdleN1 + ThrottlePos * N1_factor, spoolup, spoolup * 2.4);
+  N2 = Seek(&N2, IdleN2 + ThrottlePos * N2_factor,
+            N2SpoolUp->GetValue(), N2SpoolDown->GetValue());
+  N1 = Seek(&N1, IdleN1 + ThrottlePos * N1_factor,
+            N1SpoolUp->GetValue(), N1SpoolDown->GetValue());
   N2norm = (N2 - IdleN2) / N2_factor;
   thrust = idlethrust + (milthrust * N2norm * N2norm);
   EGT_degC = in.TAT_c + 363.1 + ThrottlePos * 357.1;
@@ -423,7 +427,9 @@ bool FGTurbine::Load(FGFDMExec* exec, Element *el)
 
   while(function_element) {
     string name = function_element->GetAttributeValue("name");
-    if (name == "IdleThrust" || name == "MilThrust" || name == "AugThrust" || name == "Injection")
+    if (name == "IdleThrust" || name == "MilThrust" || name == "AugThrust"
+        || name == "Injection" || name == "N1SpoolUp" || name == "N1SpoolDown"
+        || name == "N2SpoolUp" || name == "N2SpoolDown")
       function_element->SetAttributeValue("name", string("propulsion/engine[#]/") + name);
 
     function_element = el->FindNextElement("function");
@@ -480,8 +486,22 @@ bool FGTurbine::Load(FGFDMExec* exec, Element *el)
   InjectionLookup = GetPreFunction(property_prefix+"/Injection");
 
   // Pre-calculations and initializations
+  N1SpoolUp = GetPreFunction(property_prefix+"/N1SpoolUp");
+  if (!N1SpoolUp)
+    N1SpoolUp = new FGSpoolUp(this, BypassRatio, 1.0);
+
+  N1SpoolDown = GetPreFunction(property_prefix+"/N1SpoolDown");
+  if (!N1SpoolDown)
+    N1SpoolDown = new FGSpoolUp(this, BypassRatio, 2.4);
+
+  N2SpoolUp = GetPreFunction(property_prefix+"/N2SpoolUp");
+  if (!N2SpoolUp)
+    N2SpoolUp = new FGSpoolUp(this, BypassRatio, 1.0);
+
+  N2SpoolDown = GetPreFunction(property_prefix+"/N2SpoolDown");
+  if (!N2SpoolDown)
+    N2SpoolDown = new FGSpoolUp(this, BypassRatio, 3.0);
 
-  delay = 90.0 / (BypassRatio + 3.0);
   N1_factor = MaxN1 - IdleN1;
   N2_factor = MaxN2 - IdleN2;
   OilTemp_degK = in.TAT_c + 273.0;
