@@ -20,11 +20,6 @@
 
 #include "AircraftModel.hxx"
 
-#include <QDir>
-#include <QThread>
-#include <QMutex>
-#include <QMutexLocker>
-#include <QDataStream>
 #include <QSettings>
 #include <QDebug>
 #include <QSharedPointer>
@@ -39,308 +34,14 @@
 
 // FlightGear
 #include <Main/globals.hxx>
+#include <Include/version.h>
+
+#include "QmlAircraftInfo.hxx"
 
 const int STANDARD_THUMBNAIL_HEIGHT = 128;
-const int STANDARD_THUMBNAIL_WIDTH = 172;
-static quint32 CACHE_VERSION = 7;
 
 using namespace simgear::pkg;
 
-AircraftItem::AircraftItem()
-{
-}
-
-AircraftItem::AircraftItem(QDir dir, QString filePath)
-{
-    SGPropertyNode root;
-    readProperties(filePath.toStdString(), &root);
-
-    if (!root.hasChild("sim")) {
-        throw sg_io_exception(std::string("Malformed -set.xml file"), filePath.toStdString());
-    }
-
-    SGPropertyNode_ptr sim = root.getNode("sim");
-
-    path = filePath;
-    pathModTime = QFileInfo(path).lastModified();
-    if (sim->getBoolValue("exclude-from-gui", false)) {
-        excluded = true;
-        return;
-    }
-
-    description = sim->getStringValue("description");
-    authors =  sim->getStringValue("author");
-
-    if (sim->hasChild("rating")) {
-        SGPropertyNode_ptr ratingsNode = sim->getNode("rating");
-        ratings[0] = ratingsNode->getIntValue("FDM");
-        ratings[1] = ratingsNode->getIntValue("systems");
-        ratings[2] = ratingsNode->getIntValue("cockpit");
-        ratings[3] = ratingsNode->getIntValue("model");
-
-    }
-
-    if (sim->hasChild("long-description")) {
-        // clean up any XML whitspace in the text.
-        longDescription = QString(sim->getStringValue("long-description")).simplified();
-    }
-
-    if (sim->hasChild("variant-of")) {
-        variantOf = sim->getStringValue("variant-of");
-    } else {
-        isPrimary = true;
-    }
-
-    if (sim->hasChild("primary-set")) {
-        isPrimary = sim->getBoolValue("primary-set");
-    }
-
-    if (sim->hasChild("tags")) {
-        SGPropertyNode_ptr tagsNode = sim->getChild("tags");
-        int nChildren = tagsNode->nChildren();
-        for (int i = 0; i < nChildren; i++) {
-            const SGPropertyNode* c = tagsNode->getChild(i);
-            if (strcmp(c->getName(), "tag") == 0) {
-                const char* tagName = c->getStringValue();
-                usesHeliports |= (strcmp(tagName, "helicopter") == 0);
-                // could also consider vtol tag?
-                usesSeaports |= (strcmp(tagName, "seaplane") == 0);
-                usesSeaports |= (strcmp(tagName, "floats") == 0);
-            }
-        } // of tags iteration
-    } // of set-xml has tags
-
-    if (sim->hasChild("previews")) {
-        SGPropertyNode_ptr previewsNode = sim->getChild("previews");
-        for (auto previewNode : previewsNode->getChildren("preview")) {
-            // add file path as url
-            QString pathInXml = QString::fromStdString(previewNode->getStringValue("path"));
-            QString previewPath = dir.absoluteFilePath(pathInXml);
-            previews.append(QUrl::fromLocalFile(previewPath));
-        }
-    }
-
-    if (sim->hasChild("thumbnail")) {
-        thumbnailPath = sim->getStringValue("thumbnail");
-    } else {
-        thumbnailPath = "thumbnail.jpg";
-    }
-}
-
-QString AircraftItem::baseName() const
-{
-    QString fn = QFileInfo(path).fileName();
-    fn.truncate(fn.count() - 8);
-    return fn;
-}
-
-void AircraftItem::fromDataStream(QDataStream& ds)
-{
-    ds >> path >> pathModTime >> excluded;
-    if (excluded) {
-        return;
-    }
-
-    ds >> description >> longDescription >> authors >> variantOf >> isPrimary;
-    for (int i=0; i<4; ++i) ds >> ratings[i];
-    ds >> previews;
-    ds >> thumbnailPath;
-}
-
-void AircraftItem::toDataStream(QDataStream& ds) const
-{
-    ds << path << pathModTime << excluded;
-    if (excluded) {
-        return;
-    }
-
-    ds << description << longDescription << authors << variantOf << isPrimary;
-    for (int i=0; i<4; ++i) ds << ratings[i];
-    ds << previews;
-    ds << thumbnailPath;
-}
-
-QPixmap AircraftItem::thumbnail(bool loadIfRequired) const
-{
-    if (m_thumbnail.isNull() && loadIfRequired) {
-        QFileInfo info(path);
-        QDir dir = info.dir();
-        if (dir.exists(thumbnailPath)) {
-            m_thumbnail.load(dir.filePath(thumbnailPath));
-            // resize to the standard size
-            if (m_thumbnail.height() > STANDARD_THUMBNAIL_HEIGHT) {
-                m_thumbnail = m_thumbnail.scaledToHeight(STANDARD_THUMBNAIL_HEIGHT, Qt::SmoothTransformation);
-            }
-        }
-    }
-
-    return m_thumbnail;
-}
-
-class AircraftScanThread : public QThread
-{
-    Q_OBJECT
-public:
-    AircraftScanThread(QStringList dirsToScan) :
-        m_dirs(dirsToScan),
-        m_done(false)
-    {
-    }
-
-    ~AircraftScanThread()
-    {
-    }
-
-    /** thread-safe access to items already scanned */
-    QVector<AircraftItemPtr> items()
-    {
-        QVector<AircraftItemPtr> result;
-        QMutexLocker g(&m_lock);
-        result.swap(m_items);
-        g.unlock();
-        return result;
-    }
-
-    void setDone()
-    {
-        m_done = true;
-    }
-Q_SIGNALS:
-    void addedItems();
-
-protected:
-    virtual void run()
-    {
-        readCache();
-
-        Q_FOREACH(QString d, m_dirs) {
-            scanAircraftDir(QDir(d));
-            if (m_done) {
-                return;
-            }
-        }
-
-        writeCache();
-    }
-
-private:
-    void readCache()
-    {
-        QSettings settings;
-        QByteArray cacheData = settings.value("aircraft-cache").toByteArray();
-        if (!cacheData.isEmpty()) {
-            QDataStream ds(cacheData);
-            quint32 count, cacheVersion;
-            ds >> cacheVersion >> count;
-
-            if (cacheVersion != CACHE_VERSION) {
-                return; // mis-matched cache, version, drop
-            }
-
-             for (quint32 i=0; i<count; ++i) {
-                AircraftItemPtr item(new AircraftItem);
-                item->fromDataStream(ds);
-
-                QFileInfo finfo(item->path);
-                if (finfo.exists() && (finfo.lastModified() == item->pathModTime)) {
-                    // corresponding -set.xml file still exists and is
-                    // unmodified
-                    m_cachedItems[item->path] = item;
-                }
-            } // of cached item iteration
-        }
-    }
-
-    void writeCache()
-    {
-        QSettings settings;
-        QByteArray cacheData;
-        {
-            QDataStream ds(&cacheData, QIODevice::WriteOnly);
-            quint32 count = m_nextCache.count();
-            ds << CACHE_VERSION << count;
-
-            Q_FOREACH(AircraftItemPtr item, m_nextCache.values()) {
-                item->toDataStream(ds);
-            }
-        }
-
-        settings.setValue("aircraft-cache", cacheData);
-    }
-
-    void scanAircraftDir(QDir path)
-    {
-        QTime t;
-        t.start();
-
-        QStringList filters;
-        filters << "*-set.xml";
-        Q_FOREACH(QFileInfo child, path.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot)) {
-            QDir childDir(child.absoluteFilePath());
-            QMap<QString, AircraftItemPtr> baseAircraft;
-            QList<AircraftItemPtr> variants;
-
-            Q_FOREACH(QFileInfo xmlChild, childDir.entryInfoList(filters, QDir::Files)) {
-                try {
-                    QString absolutePath = xmlChild.absoluteFilePath();
-                    AircraftItemPtr item;
-
-                    if (m_cachedItems.contains(absolutePath)) {
-                        item = m_cachedItems.value(absolutePath);
-                    } else {
-                        item = AircraftItemPtr(new AircraftItem(childDir, absolutePath));
-                    }
-
-                    m_nextCache[absolutePath] = item;
-
-                    if (item->excluded) {
-                        continue;
-                    }
-
-                    if (item->isPrimary) {
-                        baseAircraft.insert(item->baseName(), item);
-                    } else {
-                        variants.append(item);
-                    }
-                } catch (sg_exception& e) {
-                    continue;
-                }
-
-                if (m_done) {
-                    return;
-                }
-            } // of set.xml iteration
-
-            // bind variants to their principals
-            Q_FOREACH(AircraftItemPtr item, variants) {
-                if (!baseAircraft.contains(item->variantOf)) {
-                    qWarning() << "can't find principal aircraft " << item->variantOf << " for variant:" << item->path;
-                    continue;
-                }
-
-                baseAircraft.value(item->variantOf)->variants.append(item);
-            }
-
-            // lock mutex while we modify the items array
-            {
-                QMutexLocker g(&m_lock);
-                m_items+=(baseAircraft.values().toVector());
-            }
-
-            emit addedItems();
-        } // of subdir iteration
-    }
-
-    QMutex m_lock;
-    QStringList m_dirs;
-    QVector<AircraftItemPtr> m_items;
-
-    QMap<QString, AircraftItemPtr > m_cachedItems;
-    QMap<QString, AircraftItemPtr > m_nextCache;
-
-    bool m_done;
-};
-
 class PackageDelegate : public simgear::pkg::Delegate
 {
 public:
@@ -366,15 +67,17 @@ protected:
             qWarning() << "failed refresh of "
                 << QString::fromStdString(aCatalog->url()) << ":" << aReason << endl;
         }
+
+        m_model->catalogsRefreshed();
     }
 
-    virtual void startInstall(InstallRef aInstall)
+    void startInstall(InstallRef aInstall) override
     {
         QModelIndex mi(indexForPackage(aInstall->package()));
         m_model->dataChanged(mi, mi);
     }
 
-    virtual void installProgress(InstallRef aInstall, unsigned int bytes, unsigned int total)
+    void installProgress(InstallRef aInstall, unsigned int bytes, unsigned int total) override
     {
         Q_UNUSED(bytes);
         Q_UNUSED(total);
@@ -382,7 +85,7 @@ protected:
         m_model->dataChanged(mi, mi);
     }
 
-    virtual void finishInstall(InstallRef aInstall, StatusCode aReason)
+    void finishInstall(InstallRef aInstall, StatusCode aReason) override
     {
         QModelIndex mi(indexForPackage(aInstall->package()));
         m_model->dataChanged(mi, mi);
@@ -396,11 +99,25 @@ protected:
         }
     }
 
-    virtual void availablePackagesChanged() Q_DECL_OVERRIDE
+    void availablePackagesChanged() override
     {
         m_model->refreshPackages();
     }
 
+    void installStatusChanged(InstallRef aInstall, StatusCode aReason) override
+    {
+        Q_UNUSED(aReason);
+        QModelIndex mi(indexForPackage(aInstall->package()));
+        m_model->dataChanged(mi, mi);
+    }
+
+    void finishUninstall(const PackageRef& pkg) override
+    {
+        QModelIndex mi(indexForPackage(pkg));
+        m_model->dataChanged(mi, mi);
+    }
+
+
     virtual void dataForThumbnail(const std::string& aThumbnailUrl,
                                   size_t length, const uint8_t* bytes)
     {
@@ -416,7 +133,8 @@ protected:
             pix = pix.scaledToHeight(STANDARD_THUMBNAIL_HEIGHT, Qt::SmoothTransformation);
         }
 
-        m_model->m_downloadedPixmapCache.insert(QString::fromStdString(aThumbnailUrl), pix);
+        QString url = QString::fromStdString(aThumbnailUrl);
+        m_model->m_downloadedPixmapCache.insert(url, pix);
 
         // notify any affected items. Linear scan here avoids another map/dict structure.
         for (auto pkg : m_model->m_packages) {
@@ -447,7 +165,7 @@ private:
         }
 
         int offset = std::distance(m_model->m_packages.begin(), it);
-        return m_model->index(offset + m_model->m_items.size());
+        return m_model->index(offset + m_model->m_cachedLocalAircraftCount);
     }
 
     AircraftItemModel* m_model;
@@ -456,11 +174,15 @@ private:
 AircraftItemModel::AircraftItemModel(QObject* pr) :
     QAbstractListModel(pr)
 {
+    auto cache = LocalAircraftCache::instance();
+    connect(cache, &LocalAircraftCache::scanStarted,
+            this, &AircraftItemModel::onScanStarted);
+    connect(cache, &LocalAircraftCache::addedItems,
+            this, &AircraftItemModel::onScanAddedItems);
 }
 
 AircraftItemModel::~AircraftItemModel()
 {
-    abandonCurrentScan();
     delete m_delegate;
 }
 
@@ -480,88 +202,22 @@ void AircraftItemModel::setPackageRoot(const simgear::pkg::RootRef& root)
     }
 }
 
-void AircraftItemModel::setPaths(QStringList paths)
+void AircraftItemModel::onScanStarted()
 {
-    m_paths = paths;
-}
-
-void AircraftItemModel::setMessageWidgetVisible(bool vis)
-{
-    if (m_showMessageWidget == vis) {
-        return;
-    }
-
-    m_showMessageWidget = vis;
-
-    if (vis) {
-        beginInsertRows(QModelIndex(), 0, 0);
-        m_items.prepend(AircraftItemPtr(new AircraftItem));
-        m_delegateStates.prepend(DelegateState());
-        endInsertRows();
-    } else {
-        beginRemoveRows(QModelIndex(), 0, 0);
-        m_items.removeAt(0);
-        m_delegateStates.removeAt(0);
+    const int numToRemove = m_cachedLocalAircraftCount;
+    if (numToRemove > 0) {
+        int lastRow = numToRemove - 1;
+        beginRemoveRows(QModelIndex(), 0, lastRow);
+        m_delegateStates.remove(0, numToRemove);
+        m_cachedLocalAircraftCount = 0;
         endRemoveRows();
     }
 }
 
-QModelIndex AircraftItemModel::messageWidgetIndex() const
-{
-    if (!m_showMessageWidget) {
-        return QModelIndex();
-    }
-
-    return index(0);
-}
-
-void AircraftItemModel::scanDirs()
-{
-	abandonCurrentScan();
-
-    int firstRow = (m_showMessageWidget ? 1 : 0);
-	int numToRemove = m_items.size() - firstRow;
-	if (numToRemove > 0) {
-		int lastRow = firstRow + numToRemove - 1;
-
-		beginRemoveRows(QModelIndex(), firstRow, lastRow);
-		m_items.remove(firstRow, numToRemove);
-		m_delegateStates.remove(firstRow, numToRemove);
-		endRemoveRows();
-	}
-
-    QStringList dirs = m_paths;
-
-    Q_FOREACH(SGPath ap, globals->get_aircraft_paths()) {
-        dirs << QString::fromStdString(ap.utf8Str());
-    }
-
-    SGPath rootAircraft(globals->get_fg_root());
-    rootAircraft.append("Aircraft");
-    dirs << QString::fromStdString(rootAircraft.utf8Str());
-
-    m_scanThread = new AircraftScanThread(dirs);
-    connect(m_scanThread, &AircraftScanThread::finished, this,
-            &AircraftItemModel::onScanFinished);
-    connect(m_scanThread, &AircraftScanThread::addedItems,
-            this, &AircraftItemModel::onScanResults);
-    m_scanThread->start();
-}
-
-void AircraftItemModel::abandonCurrentScan()
-{
-    if (m_scanThread) {
-        m_scanThread->setDone();
-        m_scanThread->wait(1000);
-        delete m_scanThread;
-        m_scanThread = NULL;
-    }
-}
-
 void AircraftItemModel::refreshPackages()
 {
     simgear::pkg::PackageList newPkgs = m_packageRoot->allPackages();
-    const int firstRow = m_items.size();
+    const int firstRow = m_cachedLocalAircraftCount;
     const int newSize = newPkgs.size();
     const int newTotalSize = firstRow + newSize;
 
@@ -589,33 +245,24 @@ void AircraftItemModel::refreshPackages()
     }
 
     emit dataChanged(index(firstRow), index(firstRow + newSize - 1));
-    emit packagesNeedUpdating(!m_packageRoot->packagesNeedingUpdate().empty());
+    m_cachedUpdateCount = m_packageRoot->packagesNeedingUpdate().size();
+    emit aircraftNeedingUpdatedChanged();
 }
 
 int AircraftItemModel::rowCount(const QModelIndex& parent) const
 {
-    return m_items.size() + m_packages.size();
+    return m_cachedLocalAircraftCount + m_packages.size();
 }
 
 QVariant AircraftItemModel::data(const QModelIndex& index, int role) const
 {
     int row = index.row();
-    if (m_showMessageWidget) {
-        if (row == 0) {
-            if (role == AircraftPackageStatusRole) {
-                return MessageWidget;
-            }
-
-            return QVariant();
-        }
-    }
-
     if (role == AircraftVariantRole) {
         return m_delegateStates.at(row).variant;
     }
 
-    if (row >= m_items.size()) {
-        quint32 packageIndex = row - m_items.size();
+    if (row >= m_cachedLocalAircraftCount) {
+        quint32 packageIndex = row - m_cachedLocalAircraftCount;
         const PackageRef& pkg(m_packages[packageIndex]);
         InstallRef ex = pkg->existingInstall();
 
@@ -629,7 +276,7 @@ QVariant AircraftItemModel::data(const QModelIndex& index, int role) const
 
         return dataFromPackage(pkg, m_delegateStates.at(row), role);
     } else {
-        const AircraftItemPtr item(m_items.at(row));
+        const AircraftItemPtr item(LocalAircraftCache::instance()->itemAt(row));
         return dataFromItem(item, m_delegateStates.at(row), role);
     }
 }
@@ -652,14 +299,6 @@ QVariant AircraftItemModel::dataFromItem(AircraftItemPtr item, const DelegateSta
         }
     }
 
-    if (role == AircraftThumbnailSizeRole) {
-        QPixmap pm = item->thumbnail(false);
-        if (pm.isNull()) {
-            return QSize(STANDARD_THUMBNAIL_WIDTH, STANDARD_THUMBNAIL_HEIGHT);
-        }
-        return pm.size();
-    }
-
     if (role == Qt::DisplayRole) {
         if (item->description.isEmpty()) {
             return tr("Missing description for: %1").arg(item->baseName());
@@ -674,18 +313,12 @@ QVariant AircraftItemModel::dataFromItem(AircraftItemPtr item, const DelegateSta
         return item->authors;
     } else if ((role >= AircraftRatingRole) && (role < AircraftVariantDescriptionRole)) {
         return item->ratings[role - AircraftRatingRole];
-    } else if (role == AircraftPreviewsRole) {
-        QVariantList result;
-        Q_FOREACH(QUrl u, item->previews) {
-            result.append(u);
-        }
-        return result;
     } else if (role == AircraftThumbnailRole) {
         return item->thumbnail();
     } else if (role == AircraftPackageIdRole) {
         // can we fake an ID? otherwise fall through to a null variant
     } else if (role == AircraftPackageStatusRole) {
-        return PackageInstalled; // always the case
+        return LocalAircraftCache::PackageInstalled; // always the case
     } else if (role == Qt::ToolTipRole) {
         return item->path;
     } else if (role == AircraftURIRole) {
@@ -702,6 +335,14 @@ QVariant AircraftItemModel::dataFromItem(AircraftItemPtr item, const DelegateSta
         return item->usesHeliports;
     } else if (role == AircraftIsSeaplaneRole) {
         return item->usesSeaports;
+    } else if ((role == AircraftInstallDownloadedSizeRole) ||
+               (role == AircraftPackageSizeRole))
+    {
+        return 0;
+    } else if (role == AircraftStatusRole) {
+        return item->status(0 /* variant is always 0 */);
+    } else if (role == AircraftMinVersionRole) {
+        return item->minFGVersion;
     }
 
     return QVariant();
@@ -739,32 +380,25 @@ QVariant AircraftItemModel::dataFromPackage(const PackageRef& item, const Delega
         InstallRef i = item->existingInstall();
         if (i.valid()) {
             if (i->isDownloading()) {
-                return PackageDownloading;
+                return LocalAircraftCache::PackageDownloading;
             }
             if (i->isQueued()) {
-                return PackageQueued;
+                return LocalAircraftCache::PackageQueued;
             }
             if (i->hasUpdate()) {
-                return PackageUpdateAvailable;
+                return LocalAircraftCache::PackageUpdateAvailable;
             }
 
-            return PackageInstalled;
+            return LocalAircraftCache::PackageInstalled;
         } else {
-            return PackageNotInstalled;
+            return LocalAircraftCache::PackageNotInstalled;
         }
     } else if (role == AircraftVariantCountRole) {
         // this value wants the number of aditional variants, i.e not
         // including the primary. Hence the -1 term.
         return static_cast<quint32>(item->variants().size() - 1);
-    } else if (role == AircraftThumbnailSizeRole) {
-        QPixmap pm = packageThumbnail(item, state, false).value<QPixmap>();
-        if (pm.isNull())
-            return QSize(STANDARD_THUMBNAIL_WIDTH, STANDARD_THUMBNAIL_HEIGHT);
-        return pm.size();
     } else if (role == AircraftThumbnailRole) {
         return packageThumbnail(item, state);
-    } else if (role == AircraftPreviewsRole) {
-        return packagePreviews(item, state);
     } else if (role == AircraftAuthorsRole) {
         std::string authors = item->getLocalisedProp("author", state.variant);
         if (!authors.empty()) {
@@ -783,9 +417,16 @@ QVariant AircraftItemModel::dataFromPackage(const PackageRef& item, const Delega
         int ratingIndex = role - AircraftRatingRole;
         SGPropertyNode* ratings = item->properties()->getChild("rating");
         if (!ratings) {
-            return QVariant();
+            return 0;
         }
         return ratings->getChild(ratingIndex)->getIntValue();
+    } else if (role == AircraftStatusRole) {
+        return QmlAircraftInfo::packageAircraftStatus(item);
+    } else if (role == AircraftMinVersionRole) {
+        const std::string v = item->properties()->getStringValue("minimum-fg-version");
+        if (!v.empty()) {
+            return QString::fromStdString(v);
+        }
     }
 
     return QVariant();
@@ -827,35 +468,6 @@ QVariant AircraftItemModel::packageThumbnail(PackageRef p, const DelegateState&
     return QVariant();
 }
 
-QVariant AircraftItemModel::packagePreviews(PackageRef p, const DelegateState& ds) const
-{
-    const Package::PreviewVec& previews = p->previewsForVariant(ds.variant);
-    if (previews.empty()) {
-        return QVariant();
-    }
-
-    QVariantList result;
-    // if we have an install, return file URLs, not remote (http) ones
-    InstallRef ex = p->existingInstall();
-    if (ex.valid()) {
-        for (auto p : previews) {
-            SGPath localPreviewPath = ex->path() / p.path;
-            if (!localPreviewPath.exists()) {
-                qWarning() << "missing local preview" << QString::fromStdString(localPreviewPath.utf8Str());
-                continue;
-            }
-            result.append(QUrl::fromLocalFile(QString::fromStdString(localPreviewPath.utf8Str())));
-        }
-    }
-
-    // return remote urls
-    for (auto p : previews) {
-        result.append(QUrl(QString::fromStdString(p.url)));
-    }
-
-    return result;
-}
-
 bool AircraftItemModel::setData(const QModelIndex &index, const QVariant &value, int role)
   {
       int row = index.row();
@@ -872,7 +484,36 @@ bool AircraftItemModel::setData(const QModelIndex &index, const QVariant &value,
       }
 
       return false;
-  }
+}
+
+QHash<int, QByteArray> AircraftItemModel::roleNames() const
+{
+    QHash<int, QByteArray> result = QAbstractListModel::roleNames();
+
+    result[Qt::DisplayRole] = "title";
+    result[AircraftURIRole] = "uri";
+    result[AircraftPackageIdRole] = "package";
+    result[AircraftAuthorsRole] = "authors";
+    result[AircraftVariantCountRole] = "variantCount";
+    result[AircraftLongDescriptionRole] = "description";
+    result[AircraftThumbnailRole] = "thumbnail";
+    result[AircraftPackageSizeRole] = "packageSizeBytes";
+    result[AircraftPackageStatusRole] = "packageStatus";
+
+    result[AircraftInstallDownloadedSizeRole] = "downloadedBytes";
+    result[AircraftVariantRole] = "activeVariant";
+
+    result[AircraftStatusRole] = "aircraftStatus";
+    result[AircraftMinVersionRole] = "requiredFGVersion";
+
+    result[AircraftHasRatingsRole] = "hasRatings";
+    result[AircraftRatingRole] = "ratingFDM";
+    result[AircraftRatingRole + 1] = "ratingSystems";
+    result[AircraftRatingRole + 2] = "ratingCockpit";
+    result[AircraftRatingRole + 3] = "ratingExterior";
+
+    return result;
+}
 
 QModelIndex AircraftItemModel::indexOfAircraftURI(QUrl uri) const
 {
@@ -881,23 +522,13 @@ QModelIndex AircraftItemModel::indexOfAircraftURI(QUrl uri) const
     }
 
     if (uri.isLocalFile()) {
-        QString path = uri.toLocalFile();
-        for (int row=0; row <m_items.size(); ++row) {
-            const AircraftItemPtr item(m_items.at(row));
-            if (item->path == path) {
-                return index(row);
-            }
-
-            // check variants too
-            for (int vr=0; vr < item->variants.size(); ++vr) {
-                if (item->variants.at(vr)->path == path) {
-                    return index(row);
-                }
-            }
+        int row = LocalAircraftCache::instance()->findIndexWithUri(uri);
+        if (row >= 0) {
+            return index(row);
         }
     } else if (uri.scheme() == "package") {
         QString ident = uri.path();
-        int rowOffset = m_items.size();
+        int rowOffset = m_cachedLocalAircraftCount;
 
         PackageRef pkg = m_packageRoot->getPackageById(ident.toStdString());
         if (pkg) {
@@ -926,27 +557,25 @@ void AircraftItemModel::selectVariantForAircraftURI(QUrl uri)
     QModelIndex modelIndex;
 
     if (uri.isLocalFile()) {
-        QString path = uri.toLocalFile();
-        for (int row=0; row <m_items.size(); ++row) {
-            const AircraftItemPtr item(m_items.at(row));
-            if (item->path == path) {
-                modelIndex = index(row);
-                variantIndex = 0;
-                break;
-            }
+        int row = LocalAircraftCache::instance()->findIndexWithUri(uri);
+        if (row < 0) {
+            return;
+        }
 
-            // check variants too
-            for (int vr=0; vr < item->variants.size(); ++vr) {
-                if (item->variants.at(vr)->path == path) {
-                    modelIndex = index(row);
-                    variantIndex = vr + 1;
-                    break;
-                }
+        modelIndex = index(row);
+        // now check if we are actually selecting a variant
+        const AircraftItemPtr item = LocalAircraftCache::instance()->itemAt(row);
+
+        const QString path = uri.toLocalFile();
+        for (int vr=0; vr < item->variants.size(); ++vr) {
+            if (item->variants.at(vr)->path == path) {
+                variantIndex = vr + 1;
+                break;
             }
         }
     } else if (uri.scheme() == "package") {
         QString ident = uri.path();
-        int rowOffset = m_items.size();
+        int rowOffset = m_cachedLocalAircraftCount;
 
         PackageRef pkg = m_packageRoot->getPackageById(ident.toStdString());
         if (pkg) {
@@ -971,18 +600,21 @@ void AircraftItemModel::selectVariantForAircraftURI(QUrl uri)
 QString AircraftItemModel::nameForAircraftURI(QUrl uri) const
 {
     if (uri.isLocalFile()) {
-        QString path = uri.toLocalFile();
-        for (int row=0; row <m_items.size(); ++row) {
-            const AircraftItemPtr item(m_items.at(row));
-            if (item->path == path) {
-                return item->description;
-            }
+        AircraftItemPtr item = LocalAircraftCache::instance()->findItemWithUri(uri);
+        if (!item) {
+            return {};
+        }
 
-            // check variants too
-            for (int vr=0; vr < item->variants.size(); ++vr) {
-                if (item->variants.at(vr)->path == path) {
-                    return item->description;
-                }
+        const QString path = uri.toLocalFile();
+        if (item->path == path) {
+            return item->description;
+        }
+
+        // check variants too
+        for (int vr=0; vr < item->variants.size(); ++vr) {
+            auto variant = item->variants.at(vr);
+            if (variant->path == path) {
+                return variant->description;
             }
         }
     } else if (uri.scheme() == "package") {
@@ -994,38 +626,25 @@ QString AircraftItemModel::nameForAircraftURI(QUrl uri) const
         }
     } else {
         qWarning() << "Unknown aircraft URI scheme" << uri << uri.scheme();
-        return QString();
     }
 
-    return QString();
+    return {};
 }
 
-void AircraftItemModel::onScanResults()
+void AircraftItemModel::onScanAddedItems(int addedCount)
 {
-    QVector<AircraftItemPtr> newItems = m_scanThread->items();
-    if (newItems.isEmpty())
-        return;
+    Q_UNUSED(addedCount);
+    const auto items = LocalAircraftCache::instance()->allItems();
+    const int newItemCount = items.size() - m_cachedLocalAircraftCount;
+    const int firstRow = m_cachedLocalAircraftCount;
+    const int lastRow = firstRow + newItemCount - 1;
 
-    int firstRow = m_items.count();
-    int lastRow = firstRow + newItems.count() - 1;
     beginInsertRows(QModelIndex(), firstRow, lastRow);
-    m_items+=newItems;
-
-    // default variants in all cases
-    for (int i=0; i< newItems.count(); ++i) {
-        m_delegateStates.insert(firstRow + i, DelegateState());
-    }
-
+    m_delegateStates.insert(m_cachedLocalAircraftCount, newItemCount, {});
+    m_cachedLocalAircraftCount += newItemCount;
     endInsertRows();
 }
 
-void AircraftItemModel::onScanFinished()
-{
-    delete m_scanThread;
-    m_scanThread = NULL;
-    emit scanCompleted();
-}
-
 void AircraftItemModel::installFailed(QModelIndex index, simgear::pkg::Delegate::StatusCode reason)
 {
     QString msg;
@@ -1055,11 +674,11 @@ void AircraftItemModel::installSucceeded(QModelIndex index)
 
 bool AircraftItemModel::isIndexRunnable(const QModelIndex& index) const
 {
-    if (index.row() < m_items.size()) {
+    if (index.row() < m_cachedLocalAircraftCount) {
         return true; // local file, always runnable
     }
 
-    quint32 packageIndex = index.row() - m_items.size();
+    quint32 packageIndex = index.row() - m_cachedLocalAircraftCount;
     const PackageRef& pkg(m_packages[packageIndex]);
     InstallRef ex = pkg->existingInstall();
     if (!ex.valid()) {
@@ -1069,28 +688,22 @@ bool AircraftItemModel::isIndexRunnable(const QModelIndex& index) const
     return !ex->isDownloading();
 }
 
-bool AircraftItemModel::isCandidateAircraftPath(QString path)
+int AircraftItemModel::aircraftNeedingUpdated() const
 {
-    QStringList filters;
-    filters << "*-set.xml";
-    int dirCount = 0,
-        setXmlCount = 0;
-
-    QDir d(path);
-    Q_FOREACH(QFileInfo child, d.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot)) {
-        QDir childDir(child.absoluteFilePath());
-        ++dirCount;
-        Q_FOREACH(QFileInfo xmlChild, childDir.entryInfoList(filters, QDir::Files)) {
-            ++setXmlCount;
-        }
-
-        if ((setXmlCount > 0) || (dirCount > 10)) {
-            break;
-        }
-    }
-
-    return (setXmlCount > 0);
+    return m_cachedUpdateCount;
 }
 
+bool AircraftItemModel::showUpdateAll() const
+{
+    return (m_cachedUpdateCount > 0) && m_showUpdateAll;
+}
+
+void AircraftItemModel::setShowUpdateAll(bool showUpdateAll)
+{
+    if (m_showUpdateAll == showUpdateAll)
+        return;
+
+    m_showUpdateAll = showUpdateAll;
+    emit aircraftNeedingUpdatedChanged();
+}
 
-#include "AircraftModel.moc"
