@@ -783,8 +783,12 @@ FGPUIDialog::display (SGPropertyNode *props)
         return;
     }
 
-    int screenw = globals->get_props()->getIntValue("/sim/startup/xsize");
-    int screenh = globals->get_props()->getIntValue("/sim/startup/ysize");
+    // map from physical to logical units for PUI
+    const double ratio = fgGetDouble("/sim/rendering/gui-pixel-ratio", 1.0);
+    const int physicalWidth = fgGetInt("/sim/startup/xsize"),
+            physicalHeight = fgGetInt("/sim/startup/ysize");
+    const int screenw = static_cast<int>(physicalWidth / ratio),
+              screenh = static_cast<int>(physicalHeight / ratio);
 
     bool userx = props->hasValue("x");
     bool usery = props->hasValue("y");
@@ -796,6 +800,9 @@ FGPUIDialog::display (SGPropertyNode *props)
 
     SGPropertyNode *fontnode = props->getNode("font");
     if (fontnode) {
+        SGPropertyNode *property_node = fontnode->getChild("property");
+        if (property_node)
+            fontnode = globals->get_props()->getNode(property_node->getStringValue());
         _font = FGFontCache::instance()->get(fontnode);
     } else {
         _font = _gui->getDefaultFont();
@@ -1061,6 +1068,7 @@ FGPUIDialog::makeObject (SGPropertyNode *props, int parentWidth, int parentHeigh
 
         setupObject(obj, props);
         _activeWidgets.push_back(obj);
+        setColor(obj, props, FOREGROUND | LABEL);
         return obj;
     } else {
         return 0;
@@ -1091,9 +1099,18 @@ FGPUIDialog::setupObject (puObject *object, SGPropertyNode *props)
         object->setBorderThickness( props->getIntValue("border", 2) );
 
     if (SGPropertyNode *nft = props->getNode("font", false)) {
-       puFont *lfnt = FGFontCache::instance()->get(nft);
-       object->setLabelFont(*lfnt);
-       object->setLegendFont(*lfnt);
+        if (nft) {
+            SGPropertyNode *property_node = nft->getChild("property");
+            if (property_node)
+                nft = globals->get_props()->getNode(property_node->getStringValue());
+            _font = FGFontCache::instance()->get(nft);
+        }
+        else {
+            _font = _gui->getDefaultFont();
+        }
+        puFont *lfnt = FGFontCache::instance()->get(nft);
+        object->setLabelFont(*lfnt);
+        object->setLegendFont(*lfnt);
     } else {
        object->setLabelFont(*_font);
     }
