@@ -37,6 +37,25 @@
 
 #include <simgear/io/untar.hxx>
 
+class SceneryExtractor : public simgear::TarExtractor
+{
+public:
+    SceneryExtractor(const SGPath& root) :
+        TarExtractor(root)
+    {}
+protected:
+
+    auto filterPath(std::string& path) -> PathResult override
+    {
+        if ((path.find("Objects/") == 0) || (path.find("Terrain/") == 0)) {
+            return Accepted;
+        }
+        
+        path = "Terrain/" + path;
+        return Modified;
+    }
+};
+
 class InstallSceneryThread : public QThread
 {
     Q_OBJECT
@@ -93,7 +112,7 @@ private:
     void extractNextArchive()
     {
         SGPath root(m_extractDir.toStdString());
-        m_untar.reset(new simgear::TarExtractor(root));
+        m_untar.reset(new SceneryExtractor(root));
 
         QString path = m_remainingPaths.front();
         m_remainingPaths.pop_front();
@@ -223,7 +242,7 @@ void InstallSceneryDialog::reject()
 void InstallSceneryDialog::pickFiles()
 {
     QStringList downloads = QStandardPaths::standardLocations(QStandardPaths::DownloadLocation);
-    QStringList files = QFileDialog::getOpenFileNames(this, "Choose scenery to install",
+    QStringList files = QFileDialog::getOpenFileNames(this, tr("Choose scenery to install"),
                                                       downloads.first(), "*.tar *.gz *.tgz");
     if (!files.isEmpty()) {
         QDir d(m_downloadDir);
