@@ -32,6 +32,7 @@
 #include "AirportDiagram.hxx"
 #include "NavaidDiagram.hxx"
 #include "LaunchConfig.hxx"
+#include "DefaultAircraftLocator.hxx"
 
 #include <Airports/airport.hxx>
 #include <Airports/groundnetwork.hxx>
@@ -56,6 +57,8 @@ QString fixNavaidName(QString s)
         QString up = w.toUpper();
 
         // expand common abbreviations
+        // note these are not translated, since they are abbreivations
+        // for English-langauge airports, mostly in the US/Canada
         if (up == "FLD") {
             changedWords.append("Field");
             continue;
@@ -229,10 +232,11 @@ public:
 
         IdentSearchFilter filter(aircraft);
         FGPositionedList exactMatches = NavDataCache::instance()->findAllWithIdent(term, &filter, true);
-
-        for (unsigned int i=0; i<exactMatches.size(); ++i) {
-            m_ids.push_back(exactMatches[i]->guid());
-            m_items.push_back(exactMatches[i]);
+        m_ids.reserve(exactMatches.size());
+        m_items.reserve(exactMatches.size());
+        for (auto match : exactMatches) {
+            m_ids.push_back(match->guid());
+            m_items.push_back(match);
         }
         endResetModel();
 
@@ -322,13 +326,15 @@ private slots:
         }
         
         PositionedIDVec newIds = m_search->results();
-
-        beginInsertRows(QModelIndex(), m_ids.size(), newIds.size() - 1);
-        for (unsigned int i=m_ids.size(); i < newIds.size(); ++i) {
-            m_ids.push_back(newIds[i]);
-            m_items.push_back(FGPositionedRef()); // null ref
+        if (!newIds.empty()) {
+            m_ids.reserve(newIds.size());
+            beginInsertRows(QModelIndex(), m_ids.size(), newIds.size() - 1);
+            for (auto id : newIds) {
+                m_ids.push_back(id);
+                m_items.push_back({}); // null ref
+            }
+            endInsertRows();
         }
-        endInsertRows();
 
         if (m_search->isComplete()) {
             m_searchActive = false;
@@ -407,7 +413,7 @@ LocationWidget::LocationWidget(QWidget *parent) :
 
     m_backButton = new QToolButton(this);
     m_backButton->setGeometry(0, 0, 64, 32);
-    m_backButton->setText("<< Back");
+    m_backButton->setText(tr("<< Back"));
     m_backButton->raise();
 
     connect(m_backButton, &QAbstractButton::clicked,
@@ -434,7 +440,46 @@ void LocationWidget::restoreSettings()
 {
     QSettings settings;
     m_recentLocations = loadPositionedList(settings.value("recent-locations"));
-    m_searchModel->setItems(m_recentLocations);
+    onShowHistory();
+}
+
+bool LocationWidget::isParkedLocation() const
+{
+    if (FGPositioned::isAirportType(m_location.ptr())) {
+        if (m_ui->parkingRadio->isChecked()) {
+            return true;
+        }
+    }
+
+    // treat all other ground starts as taxi or on runway, i.e engines
+    // running if possible
+    return false;
+}
+
+bool LocationWidget::isAirborneLocation() const
+{
+    const int altitude = m_ui->altitudeSpinbox->value();
+    const bool altIsPositive = (altitude > 0);
+    const bool offsetSet = m_ui->offsetGroup->isChecked();
+
+    if (m_locationIsLatLon) {
+        return altIsPositive;
+    }
+
+    if (FGPositioned::isAirportType(m_location.ptr())) {
+        if (m_ui->runwayRadio->isChecked() && offsetSet) {
+            // in this case no altitude migth be set, but we assume
+            // it's still an airborne pos
+            return true;
+        }
+
+        // this allows for people using offsets from a parking position or
+        // similar weirdness :)
+        return altIsPositive;
+    }
+
+    // relative to a navaid or fix - base off altitude.
+    return altIsPositive;
 }
 
 void LocationWidget::restoreLocation(QVariantMap l)
@@ -459,7 +504,7 @@ void LocationWidget::restoreLocation(QVariantMap l)
 
     // now we've loaded airport location data (potentially), we can apply
     // more settings
-    if (FGAirport::isAirportType(m_location.ptr())) {
+    if (FGPositioned::isAirportType(m_location.ptr())) {
         if (l.contains("location-apt-runway")) {
             QString runway = l.value("location-apt-runway").toString();
             int index = m_ui->runwayCombo->findText(runway);
@@ -490,7 +535,7 @@ bool LocationWidget::shouldStartPaused() const
         return false; // defaults to on-ground at KSFO
     }
 
-    if (FGAirport::isAirportType(m_location.ptr())) {
+    if (FGPositioned::isAirportType(m_location.ptr())) {
         return m_ui->onFinalCheckbox->isChecked();
     } else {
         // navaid, start paused
@@ -507,7 +552,7 @@ QVariantMap LocationWidget::saveLocation() const
     } else if (m_location) {
         locationSet.insert("location-id", static_cast<qlonglong>(m_location->guid()));
 
-        if (FGAirport::isAirportType(m_location.ptr())) {
+        if (FGPositioned::isAirportType(m_location.ptr())) {
             locationSet.insert("location-on-final", m_ui->onFinalCheckbox->isChecked());
             locationSet.insert("location-apt-final-distance", m_ui->approachDistanceSpin->value());
             if (m_ui->runwayRadio->isChecked()) {
@@ -570,7 +615,7 @@ void LocationWidget::setLocationProperties()
         return;
     }
 
-    if (FGAirport::isAirportType(m_location.ptr())) {
+    if (FGPositioned::isAirportType(m_location.ptr())) {
         FGAirport* apt = static_cast<FGAirport*>(m_location.ptr());
         fgSetString("/sim/presets/airport-id", apt->ident());
         fgSetBool("/sim/presets/on-ground", true);
@@ -681,7 +726,7 @@ void LocationWidget::onCollectConfig()
         return;
     }
 
-    if (FGAirport::isAirportType(m_location.ptr())) {
+    if (FGPositioned::isAirportType(m_location.ptr())) {
         FGAirport* apt = static_cast<FGAirport*>(m_location.ptr());
         m_config->setArg("airport", QString::fromStdString(apt->ident()));
 
@@ -785,7 +830,7 @@ void LocationWidget::onSearch()
     m_searchModel->setSearch(search, m_aircraftType);
 
     if (m_searchModel->isSearchActive()) {
-        m_ui->searchStatusText->setText(QString("Searching for '%1'").arg(search));
+        m_ui->searchStatusText->setText(tr("Searching for '%1'").arg(search));
         m_ui->searchIcon->setVisible(true);
         m_ui->searchIcon->movie()->start();
     } else if (m_searchModel->rowCount(QModelIndex()) == 1) {
@@ -797,11 +842,11 @@ void LocationWidget::onSearchComplete()
 {
     QString search = m_ui->locationSearchEdit->text();
     m_ui->searchIcon->setVisible(false);
-    m_ui->searchStatusText->setText(QString("Results for '%1'").arg(search));
+    m_ui->searchStatusText->setText(tr("Results for '%1'").arg(search));
 
     int numResults = m_searchModel->rowCount(QModelIndex());
     if (numResults == 0) {
-        m_ui->searchStatusText->setText(QString("No matches for '%1'").arg(search));
+        m_ui->searchStatusText->setText(tr("No matches for '%1'").arg(search));
     } else if (numResults == 1) {
         addToRecent(m_searchModel->itemAtRow(0));
         setBaseLocation(m_searchModel->itemAtRow(0));
@@ -810,7 +855,7 @@ void LocationWidget::onSearchComplete()
 
 void LocationWidget::onLocationChanged()
 {
-    bool locIsAirport = FGAirport::isAirportType(m_location.ptr());
+    bool locIsAirport = FGPositioned::isAirportType(m_location.ptr());
     if (!m_location) {
         onBackToSearch();
         return;
@@ -941,13 +986,13 @@ QString LocationWidget::locationDescription() const
 {
     if (!m_location) {
         if (m_locationIsLatLon) {
-            return QString("at position %1").arg(formatGeodAsString(m_geodLocation));
+            return tr("at position %1").arg(formatGeodAsString(m_geodLocation));
         }
 
-        return QString("No location selected");
+        return tr("No location selected");
     }
 
-    bool locIsAirport = FGAirport::isAirportType(m_location.ptr());
+    bool locIsAirport = FGPositioned::isAirportType(m_location.ptr());
     QString ident = QString::fromStdString(m_location->ident()),
         name = QString::fromStdString(m_location->name());
 
@@ -966,19 +1011,19 @@ QString LocationWidget::locationDescription() const
 
             if (onFinal) {
                 int finalDistance = m_ui->approachDistanceSpin->value();
-                locationOnAirport = QString("on %2-mile final to %1").arg(runwayName).arg(finalDistance);
+                locationOnAirport = tr("on %2-mile final to %1").arg(runwayName).arg(finalDistance);
             } else {
-                locationOnAirport = QString("on %1").arg(runwayName);
+                locationOnAirport = tr("on %1").arg(runwayName);
             }
         } else if (m_ui->parkingRadio->isChecked()) {
-            locationOnAirport = QString("at parking position %1").arg(m_ui->parkingCombo->currentText());
+            locationOnAirport = tr("at parking position %1").arg(m_ui->parkingCombo->currentText());
         }
 
-        return QString("%2 (%1): %3").arg(ident).arg(name).arg(locationOnAirport);
+        return tr("%2 (%1): %3").arg(ident).arg(name).arg(locationOnAirport);
     } else {
         QString offsetDesc = tr("at");
         if (m_ui->offsetGroup->isChecked()) {
-            offsetDesc = QString("%1nm %2 of").
+            offsetDesc = tr("%1nm %2 of").
                     arg(m_ui->offsetNmSpinbox->value(), 0, 'f', 1).
                     arg(compassPointFromHeading(m_ui->offsetBearingSpinbox->value()));
         }
@@ -990,13 +1035,13 @@ QString LocationWidget::locationDescription() const
         case FGPositioned::NDB:
             navaidType = QString("NDB"); break;
         case FGPositioned::FIX:
-            return QString("%2 waypoint %1").arg(ident).arg(offsetDesc);
+            return tr("%2 waypoint %1").arg(ident).arg(offsetDesc);
         default:
             // unsupported type
             break;
         }
 
-        return QString("%4 %1 %2 (%3)").arg(navaidType).arg(ident).arg(name).arg(offsetDesc);
+        return tr("%4 %1 %2 (%3)").arg(navaidType).arg(ident).arg(name).arg(offsetDesc);
     }
 
     return tr("No location selected");
@@ -1005,7 +1050,7 @@ QString LocationWidget::locationDescription() const
 
 void LocationWidget::updateDescription()
 {
-    bool locIsAirport = FGAirport::isAirportType(m_location.ptr());
+    bool locIsAirport = FGPositioned::isAirportType(m_location.ptr());
     if (locIsAirport) {
         FGAirport* apt = static_cast<FGAirport*>(m_location.ptr());
 
@@ -1072,8 +1117,20 @@ void LocationWidget::addToRecent(FGPositionedRef pos)
 
 void LocationWidget::onShowHistory()
 {
-    qDebug() << Q_FUNC_INFO;
-    m_searchModel->setItems(m_recentLocations);
+    // prepend the default location
+    FGPositionedList locs = m_recentLocations;
+    const std::string defaultICAO = flightgear::defaultAirportICAO();
+
+    auto it = std::find_if(locs.begin(), locs.end(), [defaultICAO](FGPositionedRef pos) {
+        return pos->ident() == defaultICAO;
+    });
+
+    if (it == locs.end()) {
+        FGAirportRef apt = FGAirport::findByIdent(defaultICAO);
+        locs.insert(locs.begin(), apt);
+    }
+
+    m_searchModel->setItems(locs);
 }
 
 void LocationWidget::setBaseLocation(FGPositionedRef ref)
