@@ -24,6 +24,7 @@
 
 // Qt
 #include <QFileDialog>
+#include <QDir>
 #include <QString>
 #include <QStringList>
 
@@ -40,9 +41,12 @@ void QtFileDialog::exec()
     int fakeargc = 1;
     static char fakeargv0[] = "fgfs";
     static char * fakeargv[2] = {fakeargv0, 0};
-    // This does nothing if it has already been run, so the fake argc/argv
-    // are only used if run without launcher
-    flightgear::initApp(fakeargc, fakeargv);
+    // This does nothing if it has already been run, so the fake argc/argv are
+    // only used if run without launcher. Don't attempt to initialize the
+    // QSettings, because this would require FGGlobals to be initialized (for
+    // globals->get_fg_home()), which would prevent using this function at
+    // early startup.
+    flightgear::initApp(fakeargc, fakeargv, false /* doInitQSettings */);
     
     // concatenate filter patterns, as Qt uses a single string
     std::string filter="";
@@ -65,7 +69,7 @@ void QtFileDialog::exec()
     dlg.setLabelText(QFileDialog::Accept,QString::fromStdString(_buttonText));
     dlg.selectFile(QString::fromStdString(_placeholder));
     if(_showHidden){
-        SG_LOG(SG_GENERAL, SG_ALERT, "QtFileDialog: can't show hidden files in Qt");
+        dlg.setFilter(dlg.filter() | QDir::Hidden);
     }
     if(dlg.exec()){
         QStringList result = dlg.selectedFiles();
