@@ -260,8 +260,8 @@ public:
 static EventTypeByName EVENT_TYPE_BY_NAME;
 
 
-FGLinuxInputDevice::FGLinuxInputDevice( std::string aName, std::string aDevname ) :
-  FGInputDevice(aName),
+FGLinuxInputDevice::FGLinuxInputDevice( std::string aName, std::string aDevname, std::string aSerial ) :
+  FGInputDevice(aName,aSerial),
   devname( aDevname ),
   fd(-1)
 {
@@ -286,9 +286,9 @@ static inline bool bitSet( unsigned char * buf, unsigned bit )
   return (buf[bit/sizeof(unsigned char)/8] >> (bit%(sizeof(unsigned char)*8))) & 1;
 }
 
-void FGLinuxInputDevice::Open()
+bool FGLinuxInputDevice::Open()
 {
-  if( fd != -1 ) return;
+  if( fd != -1 ) return true;
   if( (fd = ::open( devname.c_str(), O_RDWR )) == -1 ) { 
     throw std::exception();
   }
@@ -371,6 +371,8 @@ void FGLinuxInputDevice::Open()
       }
     }
   }
+
+  return true;
 }
 
 double FGLinuxInputDevice::Normalize( struct input_event & event ) 
@@ -481,10 +483,12 @@ void FGLinuxEventInput::postinit()
  
     dev = udev_device_get_parent( dev );
     const char * name = udev_device_get_sysattr_value(dev,"name");
-
+    const char * serial = udev_device_get_sysattr_value(dev, "serial");
     SG_LOG(SG_INPUT,SG_DEBUG, "name=" << (name?name:"<null>") << ", node=" << (node?node:"<null>"));
-    if( name && node )
-      AddDevice( new FGLinuxInputDevice(name, node) );
+    if( name && node ) {
+      std::string serialString = serial ? serial : std::string{};
+      AddDevice( new FGLinuxInputDevice(name, node, serialString) );
+    }
 
     udev_device_unref(dev);
   }
