@@ -26,6 +26,8 @@
 #  include "config.h"
 #endif
 
+#include <memory>
+
 #include "FGMouseInput.hxx"
 
 #include <boost/foreach.hpp>
@@ -38,7 +40,6 @@
 #include "FGButton.hxx"
 #include "Main/globals.hxx"
 #include <Viewer/renderer.hxx>
-#include <plib/pu.h>
 #include <Model/panelnode.hxx>
 #include <Cockpit/panel.hxx>
 #include <Viewer/FGEventHandler.hxx>
@@ -110,11 +111,11 @@ void ActivePickCallbacks::update( double dt, unsigned int keyModState )
  */
 struct mouse_mode {
     mouse_mode ();
-    virtual ~mouse_mode ();
+
     FGMouseCursor::Cursor cursor;
     bool constrained;
     bool pass_through;
-    FGButton * buttons;
+    std::unique_ptr<FGButton[]> buttons;
     SGBindingList x_bindings[KEYMOD_MAX];
     SGBindingList y_bindings[KEYMOD_MAX];
 };
@@ -125,15 +126,15 @@ struct mouse_mode {
  */
 struct mouse {
     mouse ();
-    virtual ~mouse ();
+
     int x, y;
     SGPropertyNode_ptr mode_node;
     SGPropertyNode_ptr mouse_button_nodes[MAX_MOUSE_BUTTONS];
     int nModes;
     int current_mode;
-    
+
     SGTimeStamp timeSinceLastMove;
-    mouse_mode * modes;
+    std::unique_ptr<mouse_mode[]> modes;
 };
 
 static
@@ -154,7 +155,6 @@ class FGMouseInput::FGMouseInputPrivate : public SGPropertyChangeListener
 {
 public:
     FGMouseInputPrivate() :
-        initialized(false),
         haveWarped(false),
         xSizeNode(fgGetNode("/sim/startup/xsize", false ) ),
         ySizeNode(fgGetNode("/sim/startup/ysize", false ) ),
@@ -263,7 +263,7 @@ public:
         FGMouseCursor::instance()->setCursor(cur);
         if (!didPick) {
           SGPropertyNode_ptr args(new SGPropertyNode);
-          globals->get_commands()->execute("update-hover", args);
+          globals->get_commands()->execute("update-hover", args, nullptr);
 
         }
     }
@@ -325,7 +325,6 @@ public:
 
     mouse mice[MAX_MICE];
     
-    bool initialized;
     bool hideCursor, haveWarped;
     bool tooltipTimeoutDone;
     bool clickTriggersTooltip;
@@ -348,7 +347,7 @@ public:
 // The Mouse Input Implementation
 ////////////////////////////////////////////////////////////////////////
 
-static FGMouseInput* global_mouseInput = NULL;
+static FGMouseInput* global_mouseInput = nullptr;
 
 static void mouseClickHandler(int button, int updown, int x, int y, bool mainWindow, const osgGA::GUIEventAdapter* ea)
 {
@@ -362,30 +361,13 @@ static void mouseMotionHandler(int x, int y, const osgGA::GUIEventAdapter* ea)
         global_mouseInput->doMouseMotion(x, y, ea);
 }
 
-
-
-FGMouseInput::FGMouseInput() :
-  d(new FGMouseInputPrivate)
-{
-    global_mouseInput = this;
-}
-
-FGMouseInput::~FGMouseInput()
-{
-    global_mouseInput = NULL;
-}
+FGMouseInput::FGMouseInput() = default;
 
 void FGMouseInput::init()
 {
-    if (d->initialized) {
-        SG_LOG(SG_INPUT, SG_WARN, "Duplicate init of FGMouseInput");
-
-        return;
-    }
-    
-    d->initialized = true;
-    
   SG_LOG(SG_INPUT, SG_DEBUG, "Initializing mouse bindings");
+
+  d.reset(new FGMouseInputPrivate());
   std::string module = "";
 
   SGPropertyNode * mouse_nodes = fgGetNode("/input/mice");
@@ -408,7 +390,10 @@ void FGMouseInput::init()
       m.mode_node->setIntValue(0);
     }
     for (j = 0; j < MAX_MOUSE_BUTTONS; j++) {
-      buf.seekp(ios_base::beg);
+      // According to <https://stackoverflow.com/a/12112642/4756009> and other
+      // similar questions on stackoverflow.com, it seems safer not to try to
+      // reuse the 'buf' variable we have above.
+      std::ostringstream buf;
       buf << "/devices/status/mice/mouse["<< i << "]/button[" << j << "]";
       m.mouse_button_nodes[j] = fgGetNode(buf.str().c_str(), true);
       m.mouse_button_nodes[j]->setBoolValue(false);
@@ -416,7 +401,7 @@ void FGMouseInput::init()
 
    // Read all the modes
     m.nModes = mouse_node->getIntValue("mode-count", 1);
-    m.modes = new mouse_mode[m.nModes];
+    m.modes.reset(new mouse_mode[m.nModes]);
 
     for (int j = 0; j < m.nModes; j++) {
       int k;
@@ -430,10 +415,9 @@ void FGMouseInput::init()
       m.modes[j].pass_through = mode_node->getBoolValue("pass-through", false);
 
       // Read the button bindings for this mode
-      m.modes[j].buttons = new FGButton[MAX_MOUSE_BUTTONS];
-      std::ostringstream buf;
+      m.modes[j].buttons.reset(new FGButton[MAX_MOUSE_BUTTONS]);
       for (k = 0; k < MAX_MOUSE_BUTTONS; k++) {
-        buf.seekp(ios_base::beg);
+        std::ostringstream buf;
         buf << "mouse button " << k;
         m.modes[j].buttons[k].init( mode_node->getChild("button", k), buf.str(), module );
       }
@@ -466,11 +450,28 @@ void FGMouseInput::init()
 
   fgRegisterMouseClickHandler(mouseClickHandler);
   fgRegisterMouseMotionHandler(mouseMotionHandler);
+  global_mouseInput = this;
+}
+
+void FGMouseInput::shutdown()
+{
+  SG_LOG(SG_INPUT, SG_DEBUG, "Shutting down mouse bindings");
+
+  // This ensures that mouseClickHandler and mouseMotionHandler are no-ops.
+  global_mouseInput = nullptr;
+  // Reset the Pimpl
+  d.reset();
+}
+
+void FGMouseInput::reinit()
+{
+  shutdown();
+  init();
 }
 
 void FGMouseInput::update ( double dt )
 {
-    if (!d->initialized) {
+    if (!d) {
         SG_LOG(SG_INPUT, SG_WARN, "update of mouse before init");
     }
     
@@ -501,7 +502,7 @@ void FGMouseInput::update ( double dt )
   {
       d->tooltipTimeoutDone = true;
       SGPropertyNode_ptr arg(new SGPropertyNode);
-      globals->get_commands()->execute("tooltip-timeout", arg);
+      globals->get_commands()->execute("tooltip-timeout", arg, nullptr);
   }
   
   if ( d->hideCursor ) {
@@ -519,41 +520,21 @@ mouse::mouse ()
     y(-1),
     nModes(1),
     current_mode(0),
-    modes(NULL)
+    modes()
 {
 }
 
-mouse::~mouse ()
-{
-  delete [] modes;
-}
-
 mouse_mode::mouse_mode ()
   : cursor(FGMouseCursor::CURSOR_ARROW),
     constrained(false),
     pass_through(false),
-    buttons(NULL)
+    buttons()
 {
 }
 
-mouse_mode::~mouse_mode ()
-{
-                                // FIXME: memory leak
-//   for (int i = 0; i < KEYMOD_MAX; i++) {
-//     int j;
-//     for (j = 0; i < x_bindings[i].size(); j++)
-//       delete bindings[i][j];
-//     for (j = 0; j < y_bindings[i].size(); j++)
-//       delete bindings[i][j];
-//   }
-  if (buttons) {
-    delete [] buttons;
-  }
-}
-
 void FGMouseInput::doMouseClick (int b, int updown, int x, int y, bool mainWindow, const osgGA::GUIEventAdapter* ea)
 {
-    if (!d->initialized) {
+    if (!d) {
         // can occur during reset
         return;
     }
@@ -598,11 +579,7 @@ void FGMouseInput::doMouseClick (int b, int updown, int x, int y, bool mainWindo
   }
 
   if (mode.pass_through) {
-    // remove once PUI uses standard picking mechanism
-    if (0 <= x && 0 <= y && puMouse(b, updown, x, y))
-      return; // pui handled it
-
-    // pui didn't want the click event so compute a
+    // compute a
     // scenegraph intersection point corresponding to the mouse click
     if (updown == MOUSE_BUTTON_DOWN) {
       d->activePickCallbacks.init( b, ea );
@@ -610,7 +587,7 @@ void FGMouseInput::doMouseClick (int b, int updown, int x, int y, bool mainWindo
       if (d->clickTriggersTooltip) {
             SGPropertyNode_ptr args(new SGPropertyNode);
             args->setStringValue("reason", "click");
-            globals->get_commands()->execute("tooltip-timeout", args);
+            globals->get_commands()->execute("tooltip-timeout", args, nullptr);
             d->tooltipTimeoutDone = true;
       }
     } else {
@@ -619,7 +596,6 @@ void FGMouseInput::doMouseClick (int b, int updown, int x, int y, bool mainWindo
     } // mouse button was released
   } // of pass-through mode
 
-  // OK, PUI and the panel didn't want the click
   if (b >= MAX_MOUSE_BUTTONS) {
     SG_LOG(SG_INPUT, SG_ALERT, "Mouse button " << b
            << " where only " << MAX_MOUSE_BUTTONS << " expected");
@@ -655,13 +631,7 @@ void FGMouseInput::processMotion(int x, int y, const osgGA::GUIEventAdapter* ea)
   }
   
   mouse_mode &mode = m.modes[modeIndex];
-  
-  // Pass on to PUI if requested, and return
-  // if PUI consumed the event.
-  if (mode.pass_through && puMouse(x, y)) {
-    return;
-  }
-
+ 
   if (d->haveWarped)
   {
     // don't fire mouse-movement events at the first update after warping the mouse,
@@ -698,7 +668,7 @@ void FGMouseInput::processMotion(int x, int y, const osgGA::GUIEventAdapter* ea)
 
 void FGMouseInput::doMouseMotion (int x, int y, const osgGA::GUIEventAdapter* ea)
 {
-    if (!d->initialized) {
+    if (!d) {
         // can occur during reset
         return;
     }
@@ -726,5 +696,11 @@ void FGMouseInput::doMouseMotion (int x, int y, const osgGA::GUIEventAdapter* ea
   d->mouseYNode->setIntValue(y);
 }
 
+bool FGMouseInput::isRightDragToLookEnabled() const
+{
+    if (!d) {
+        return false;
+    }
 
-
+    return (d->rightClickModeCycle == false);
+}
