@@ -27,7 +27,7 @@
 
 #include <simgear/sg_inlines.h>
 #include <simgear/misc/sg_path.hxx>
-#include <simgear/misc/sgstream.hxx>
+#include <simgear/io/iostreams/sgstream.hxx>
 #include <simgear/timing/sg_time.hxx>
 #include <simgear/magvar/magvar.hxx>
 #include <simgear/structure/exception.hxx>
