@@ -63,12 +63,17 @@
 #include "main.hxx"
 #include <Include/version.h>
 #include <Main/globals.hxx>
+#include <Main/fg_init.hxx>
 #include <Main/options.hxx>
 #include <Main/fg_props.hxx>
 #include <GUI/MessageBox.hxx>
 
 #include "fg_os.hxx"
 
+#if defined(HAVE_QT)
+#include <GUI/QtLauncher.hxx>
+#endif
+
 #if defined(HAVE_CRASHRPT)
 	#include <CrashRpt.h>
 
@@ -308,6 +313,10 @@ int main ( int argc, char **argv )
     setlocale(LC_NUMERIC, "C");
     setlocale(LC_COLLATE, "C");
 
+    if (flightgear::Options::checkForArg(argc, argv, "uninstall")) {
+        return fgUninstall();
+    }
+
     bool fgviewer = flightgear::Options::checkForArg(argc, argv, "fgviewer");
     int exitStatus = EXIT_FAILURE;
     try {
@@ -351,6 +360,10 @@ int main ( int argc, char **argv )
             perror("Possible cause");
     }
 
+#if defined(HAVE_QT)
+    flightgear::shutdownQtApp();
+#endif
+
 #if defined(HAVE_CRASHRPT)
 	crUninstall();
 #endif
@@ -364,10 +377,13 @@ void fgExitCleanup() {
 
     if (_bootstrap_OSInit != 0) {
         fgSetMouseCursor(MOUSE_CURSOR_POINTER);
-
         fgOSCloseWindow();
     }
 
+    // you might imagine we'd call shutdownQtApp here, but it's not safe to do
+    // so in an atexit handler, and crashes on Mac. Thiago states this explicitly:
+    // https://bugreports.qt.io/browse/QTBUG-48709
+
     // on the common exit path globals is already deleted, and NULL,
     // so this only happens on error paths.
     delete globals;
