@@ -60,6 +60,7 @@
 #include <simgear/misc/sg_dir.hxx>
 #include <simgear/io/iostreams/sgstream.hxx>
 #include <simgear/misc/strutils.hxx>
+#include <simgear/embedded_resources/EmbeddedResourceManager.hxx>
 #include <simgear/props/props_io.hxx>
 #include <simgear/scene/tsync/terrasync.hxx>
 
@@ -75,6 +76,8 @@
 #include <simgear/package/Install.hxx>
 #include <simgear/package/Catalog.hxx>
 
+#include <Add-ons/AddonManager.hxx>
+
 #include <Aircraft/controls.hxx>
 #include <Aircraft/replay.hxx>
 #include <Aircraft/FlightHistory.hxx>
@@ -85,8 +88,6 @@
 #include <Airports/dynamics.hxx>
 #include <Airports/airportdynamicsmanager.hxx>
 
-#include <AIModel/AIManager.hxx>
-
 #include <ATC/atc_mgr.hxx>
 
 #include <Autopilot/route_mgr.hxx>
@@ -107,6 +108,7 @@
 #include <AIModel/submodel.hxx>
 #include <AIModel/AIManager.hxx>
 #include <AIModel/performancedb.hxx>
+#include <Main/locale.hxx>
 #include <Navaids/navdb.hxx>
 #include <Navaids/navlist.hxx>
 #include <Scenery/scenery.hxx>
@@ -221,6 +223,9 @@ public:
             e.getFormattedMessage());
           return false;
         }
+
+        checkAircraftMinVersion();
+
           // apply state after the -set.xml, but before any options are are set
           flightgear::applyInitialState();
         return true;
@@ -281,6 +286,7 @@ public:
       // apply state after the -set.xml, but before any options are are set
       flightgear::applyInitialState();
 
+      checkAircraftMinVersion();
 
     return true;
   }
@@ -348,6 +354,27 @@ private:
 
     return VISIT_CONTINUE;
   }
+
+  bool checkAircraftMinVersion()
+  {
+      SGPropertyNode* minVersionNode = globals->get_props()->getNode("/sim/minimum-fg-version");
+      if (minVersionNode) {
+          std::string minVersion = minVersionNode->getStringValue();
+          const int c = simgear::strutils::compare_versions(FLIGHTGEAR_VERSION, minVersion, 2);
+          if (c < 0) {
+              SG_LOG(SG_AIRCRAFT, SG_DEV_ALERT, "Aircraft minimum version (" << minVersion <<
+                     ") is higher than FG version:" << FLIGHTGEAR_VERSION);
+              flightgear::modalMessageBox("Aircraft requires newer version of FlightGear",
+                                          "The selected aircraft requires FlightGear version " + minVersion
+                                          + " to work correctly. Some features may not work as expected, or the aircraft may not load at all.");
+              return false;
+          }
+      } else {
+          SG_LOG(SG_AIRCRAFT, SG_DEV_ALERT, "Aircraft does not specify a minimum FG version: please add one at /sim/minimum-fg-version");
+      }
+
+      return true;
+  }
   
   std::string _searchAircraft;
   SGPath _foundPath;
@@ -892,7 +919,7 @@ void fgCreateSubsystems(bool duringReset) {
     // Initialize the input subsystem.
     ////////////////////////////////////////////////////////////////////
 
-    globals->add_subsystem("input", new FGInput, SGSubsystemMgr::GENERAL);
+    globals->add_new_subsystem<FGInput>(SGSubsystemMgr::GENERAL);
 
 
     ////////////////////////////////////////////////////////////////////
@@ -1056,21 +1083,19 @@ void fgStartNewReset()
     // remove most subsystems, with a few exceptions.
     for (int g=0; g<SGSubsystemMgr::MAX_GROUPS; ++g) {
         SGSubsystemGroup* grp = subsystemManger->get_group(static_cast<SGSubsystemMgr::GroupType>(g));
-        const string_list& names(grp->member_names());
-        string_list::const_iterator it;
-        for (it = names.begin(); it != names.end(); ++it) {
-            if ((*it == "time") || (*it == "terrasync") || (*it == "events")
-                || (*it == "lighting") || (*it == FGScenery::subsystemName()))
+        for (auto nm : grp->member_names()) {
+            if ((nm == "time") || (nm == "terrasync") || (nm == "events")
+                || (nm == "lighting") || (nm == FGScenery::subsystemName()))
             {
                 continue;
             }
             
             try {
-                subsystemManger->remove(it->c_str());
+                subsystemManger->remove(nm.c_str());
             } catch (std::exception& e) {
-                SG_LOG(SG_GENERAL, SG_INFO, "caught std::exception shutting down:" << *it);
+                SG_LOG(SG_GENERAL, SG_INFO, "caught std::exception shutting down:" << nm);
             } catch (...) {
-                SG_LOG(SG_GENERAL, SG_INFO, "caught generic exception shutting down:" << *it);
+                SG_LOG(SG_GENERAL, SG_INFO, "caught generic exception shutting down:" << nm);
             }
             
             // don't delete here, dropping the ref should be sufficient
@@ -1112,12 +1137,27 @@ void fgStartNewReset()
     globals->resetPropertyRoot();
     // otherwise channels are duplicated
     globals->get_channel_options_list()->clear();
-  
+
+    flightgear::addons::AddonManager::reset();
+    flightgear::addons::AddonManager::createInstance();
+
     fgInitConfig(0, NULL, true);
     fgInitGeneral(); // all of this?
     
     flightgear::Options::sharedInstance()->processOptions();
-    
+
+    // Rebuild the lists of allowed paths for cases where a path comes from an
+    // untrusted source, such as the global property tree (this uses $FG_HOME
+    // and other paths set by Options::processOptions()).
+    fgInitAllowedPaths();
+
+    const auto& resMgr = simgear::EmbeddedResourceManager::instance();
+    // The language was (re)set in processOptions()
+    const string locale = globals->get_locale()->getPreferredLanguage();
+    resMgr->selectLocale(locale);
+    SG_LOG(SG_GENERAL, SG_INFO,
+           "EmbeddedResourceManager: selected locale '" << locale << "'");
+
     // PRESERVED properties over-write state from options, intentionally
     if ( copyProperties(preserved, globals->get_props()) ) {
         SG_LOG( SG_GENERAL, SG_INFO, "Preserved state restored successfully" );
@@ -1157,9 +1197,11 @@ void fgStartNewReset()
     globals->set_matlib( new SGMaterialLib );
     
 // terra-sync needs the property tree root, pass it back in
-    simgear::SGTerraSync* terra_sync = static_cast<simgear::SGTerraSync*>(subsystemManger->get_subsystem("terrasync"));
-    terra_sync->setRoot(globals->get_props());
-
+    auto terra_sync = static_cast<simgear::SGTerraSync*>(subsystemManger->get_subsystem("terrasync"));
+    if (terra_sync) {
+        terra_sync->setRoot(globals->get_props());
+    }
+    
     fgSetBool("/sim/signals/reinit", false);
     fgSetBool("/sim/freeze/master", false);
     fgSetBool("/sim/sceneryloaded",false);
@@ -1186,3 +1228,43 @@ void fgInitPackageRoot()
     globals->setPackageRoot(pkgRoot);
 
 }
+
+int fgUninstall()
+{
+    SGPath dataPath = SGPath::fromEnv("FG_HOME", platformDefaultDataPath());
+    simgear::Dir fgHome(dataPath);
+    if (fgHome.exists()) {
+        if (!fgHome.remove(true /* recursive */)) {
+            fprintf(stderr, "Errors occurred trying to remove FG_HOME");
+            return EXIT_FAILURE;
+        }
+    }
+
+    if (fgHome.exists()) {
+        fprintf(stderr, "unable to remove FG_HOME");
+        return EXIT_FAILURE;
+    }
+
+#if defined(SG_WINDOWS)
+    SGPath p = flightgear::defaultDownloadDir();
+    // we don't want to remove the whole dir, let's nuke specific
+    // subdirs which are (hopefully) safe
+
+    SGPath terrasyncPath = p / "TerraSync";
+    if (terrasyncPath.exists()) {
+        simgear::Dir dir(terrasyncPath);
+        if (!dir.remove(true /*recursive*/)) {
+            fprintf(stderr, "Errors occurred trying to remove Documents/FlightGear/TerraSync");
+        }
+    }
+
+    SGPath packagesPath = p / "Aircraft";
+    if (packagesPath.exists()) {
+        simgear::Dir dir(packagesPath);
+        if (!dir.remove(true /*recursive*/)) {
+            fprintf(stderr, "Errors occurred trying to remove Documents/FlightGear/Aircraft");
+        }
+    }
+#endif
+    return EXIT_SUCCESS;
+}
