@@ -45,6 +45,7 @@
 #include <simgear/scene/model/modellib.hxx>
 #include <simgear/package/Root.hxx>
 
+#include <Add-ons/AddonResourceProvider.hxx>
 #include <Aircraft/controls.hxx>
 #include <Airports/runways.hxx>
 #include <Autopilot/route_mgr.hxx>
@@ -58,6 +59,7 @@
 #include <Scenery/tilemgr.hxx>
 #include <Viewer/renderer.hxx>
 #include <GUI/FGFontCache.hxx>
+#include <GUI/MessageBox.hxx>
 
 #include <simgear/sound/soundmgr.hxx>
 #include <simgear/scene/material/matlib.hxx>
@@ -165,8 +167,10 @@ FGGlobals::FGGlobals() :
     props = SGPropertyNode_ptr(root);
     locale = new FGLocale(props);
 
-    simgear::ResourceManager::instance()->addProvider(new AircraftResourceProvider);
-    simgear::ResourceManager::instance()->addProvider(new CurrentAircraftDirProvider);
+    auto resMgr = simgear::ResourceManager::instance();
+    resMgr->addProvider(new AircraftResourceProvider());
+    resMgr->addProvider(new CurrentAircraftDirProvider());
+    resMgr->addProvider(new flightgear::addons::ResourceProvider());
     initProperties();
 }
 
@@ -725,7 +729,7 @@ static void tryAutosaveMigration(const SGPath& userDataPath, SGPropertyNode* pro
         if (matches != 2) {
             continue;
         }
-        
+
         if (currentVersion < v) {
             // ignore autosaves from more recent versions; this happens when
             // running unsable and stable at the same time
@@ -761,7 +765,8 @@ static void tryAutosaveMigration(const SGPath& userDataPath, SGPropertyNode* pro
 
     // read migration blacklist
     string_list blacklist;
-    for (auto node : fgGetNode("/sim/autosave-migration/blacklist")->getChildren("path")) {
+    SGPropertyNode_ptr blacklistNode = fgGetNode("/sim/autosave-migration/blacklist", true);
+    for (auto node : blacklistNode->getChildren("path")) {
         blacklist.push_back(node->getStringValue());
     }
 
@@ -770,11 +775,20 @@ static void tryAutosaveMigration(const SGPath& userDataPath, SGPropertyNode* pro
 
     // copy remaining props out
     copyProperties(&oldProps, props);
+
+    // inform the user
+#if !defined(FG_TESTLIB)
+    flightgear::modalMessageBox("Settings migrated",
+                                "Saved settings were migrated from a previous version of FlightGear. "
+                                "If you encounter any problems when using the system, try restoring "
+                                "the default settings, before reporting a problem. "
+                                "Saved settings can affect the appearance, performance and features of the simulator.");
+#endif
 }
 
 // Load user settings from the autosave file (normally in $FG_HOME)
 void
-FGGlobals::loadUserSettings(SGPath userDataPath, bool tryMigrate)
+FGGlobals::loadUserSettings(SGPath userDataPath)
 {
     if (userDataPath.isNull()) {
         userDataPath = get_fg_home();
@@ -794,7 +808,7 @@ FGGlobals::loadUserSettings(SGPath userDataPath, bool tryMigrate)
           SG_LOG(SG_INPUT, SG_WARN, "failed to read user settings:" << e.getMessage()
             << "(from " << e.getOrigin() << ")");
       }
-    } else if (tryMigrate) {
+    } else {
         tryAutosaveMigration(userDataPath, &autosave);
     }
     copyProperties(&autosave, globals->get_props());
