@@ -9,12 +9,17 @@
 
 #include "logger.hxx"
 
-#include <fstream>
+#include <ios>
 #include <string>
+#include <cstdlib>
 
 #include <simgear/debug/logstream.hxx>
+#include <simgear/io/iostreams/sgstream.hxx>
+#include <simgear/misc/sg_path.hxx>
 
 #include "fg_props.hxx"
+#include "globals.hxx"
+#include "util.hxx"
 
 using std::string;
 using std::endl;
@@ -23,18 +28,6 @@ using std::endl;
 // Implementation of FGLogger
 ////////////////////////////////////////////////////////////////////////
 
-FGLogger::FGLogger ()
-{
-}
-
-FGLogger::~FGLogger ()
-{
-    for (unsigned int i = 0; i < _logs.size(); i++) {
-        delete _logs[i];
-    }
-    _logs.clear();
-}
-
 void
 FGLogger::init ()
 {
@@ -43,22 +36,40 @@ FGLogger::init ()
     return;
 
   std::vector<SGPropertyNode_ptr> children = logging->getChildren("log");
-  for (unsigned int i = 0; i < children.size(); i++) {
-
-    SGPropertyNode * child = children[i];
+  _logs.reserve(children.size());
 
+  for (const auto child: children) {
     if (!child->getBoolValue("enabled", false))
         continue;
 
-    _logs.push_back(new Log());
-    Log &log = *_logs[_logs.size()-1];
-    
+    _logs.emplace_back(new Log());
+    Log &log = *_logs.back();
+
     string filename = child->getStringValue("filename");
     if (filename.empty()) {
         filename = "fg_log.csv";
         child->setStringValue("filename", filename.c_str());
     }
 
+    // Security: the path comes from the global Property Tree; it *must* be
+    //           validated before we overwrite the file.
+    const SGPath authorizedPath = fgValidatePath(SGPath::fromUtf8(filename),
+                                                 /* write */ true);
+
+    if (authorizedPath.isNull()) {
+      const string propertyPath = child->getChild("filename")
+                                       ->getPath(/* simplify */ true);
+      const string msg =
+        "The FGLogger logging system, via the '" + propertyPath + "' property, "
+        "was asked to write to '" + filename + "', however this path is not "
+        "authorized for writing anymore for security reasons. " +
+        "Please choose another location, for instance in the $FG_HOME/Export "
+        "folder (" + (globals->get_fg_home() / "Export").utf8Str() + ").";
+
+      SG_LOG(SG_GENERAL, SG_ALERT, msg);
+      exit(EXIT_FAILURE);
+    }
+
     string delimiter = child->getStringValue("delimiter");
     if (delimiter.empty()) {
         delimiter = ",";
@@ -68,9 +79,11 @@ FGLogger::init ()
     log.interval_ms = child->getLongValue("interval-ms");
     log.last_time_ms = globals->get_sim_time_sec() * 1000;
     log.delimiter = delimiter.c_str()[0];
-    log.output = new std::ofstream(filename.c_str());
-    if (!log.output) {
+    // Security: use the return value of fgValidatePath()
+    log.output.reset(new sg_ofstream(authorizedPath, std::ios_base::out));
+    if ( !(*log.output) ) {
       SG_LOG(SG_GENERAL, SG_ALERT, "Cannot write log to " << filename);
+      _logs.pop_back();
       continue;
     }
 
@@ -106,9 +119,6 @@ FGLogger::init ()
 void
 FGLogger::reinit ()
 {
-    for (unsigned int i = 0; i < _logs.size(); i++) {
-        delete _logs[i];
-    }
     _logs.clear();
     init();
 }
@@ -148,16 +158,10 @@ FGLogger::update (double dt)
 ////////////////////////////////////////////////////////////////////////
 
 FGLogger::Log::Log ()
-  : output(0),
-    interval_ms(0),
+  : interval_ms(0),
     last_time_ms(-999999.0),
     delimiter(',')
 {
 }
 
-FGLogger::Log::~Log ()
-{
-  delete output;
-}
-
 // end of logger.cxx
