@@ -56,6 +56,8 @@ extern bool global_crashRptEnabled;
 #include <simgear/math/sg_random.h>
 #include <simgear/misc/strutils.hxx>
 
+#include <Add-ons/AddonManager.hxx>
+#include <Main/locale.hxx>
 #include <Model/panelnode.hxx>
 #include <Scenery/scenery.hxx>
 #include <Sound/soundmanager.hxx>
@@ -80,6 +82,9 @@ extern bool global_crashRptEnabled;
 #include "subsystemFactory.hxx"
 #include "options.hxx"
 
+#include <simgear/embedded_resources/EmbeddedResourceManager.hxx>
+#include <EmbeddedResources/FlightGear-resources.hxx>
+
 #if defined(HAVE_QT)
 #include <GUI/QtLauncher.hxx>
 #endif
@@ -94,7 +99,6 @@ using std::vector;
 extern int _bootstrap_OSInit;
 
 static SGPropertyNode_ptr frame_signal;
-static TimeManager* timeMgr;
 
 // What should we do when we have nothing else to do?  Let's get ready
 // for the next move and update the display?
@@ -108,10 +112,11 @@ static void fgMainLoop( void )
 
     frame_signal->fireValueChanged();
 
+    auto timeManager = globals->get_subsystem<TimeManager>();
     // compute simulated time (allowing for pause, warp, etc) and
     // real elapsed time
     double sim_dt, real_dt;
-    timeMgr->computeTimeDeltas(sim_dt, real_dt);
+    timeManager->computeTimeDeltas(sim_dt, real_dt);
 
     // update all subsystems
     globals->get_subsystem_mgr()->update(sim_dt);
@@ -231,7 +236,6 @@ static void registerMainLoop()
 {
     // stash current frame signal property
     frame_signal = fgGetNode("/sim/signals/frame", true);
-    timeMgr = (TimeManager*) globals->get_subsystem("time");
     fgRegisterIdleHandler( fgMainLoop );
 }
 
@@ -274,8 +278,7 @@ static void fgIdleFunction ( void ) {
     } else if ( idle_state == 4 ) {
         idle_state++;
 
-        TimeManager* t = new TimeManager;
-        globals->add_subsystem("time", t, SGSubsystemMgr::INIT);
+        globals->add_new_subsystem<TimeManager>(SGSubsystemMgr::INIT);
 
         // Do some quick general initializations
         if( !fgInitGeneral()) {
@@ -303,7 +306,7 @@ static void fgIdleFunction ( void ) {
 
         simgear::SGModelLib::init(globals->get_fg_root().local8BitStr(), globals->get_props());
 
-        TimeManager* timeManager = (TimeManager*) globals->get_subsystem("time");
+        auto timeManager = globals->get_subsystem<TimeManager>();
         timeManager->init();
 
         ////////////////////////////////////////////////////////////////////
@@ -383,6 +386,26 @@ void fgResetIdleState()
     fgRegisterIdleHandler( &fgIdleFunction );
 }
 
+void fgInitSecureMode()
+{
+    bool secureMode = true;
+    if (Options::sharedInstance()->isOptionSet("allow-nasal-from-sockets")) {
+        SG_LOG(SG_GENERAL, SG_ALERT, "\n!! Network connections allowed to use Nasal !!\n"
+       "Network connections will be allowed full access to the simulator \n"
+       "including running arbitrary scripts. Ensure you have adequate security\n"
+        "(such as a firewall which blocks external connections).\n");
+        secureMode = false;
+    }
+    
+    // it's by design that we overwrite any existing property tree value
+    // here - this prevents an aircraft or add-on setting the property
+    // value underneath us, eg in their -set.xml
+    SGPropertyNode_ptr secureFlag = fgGetNode("/sim/secure-flag", true);
+    secureFlag->setBoolValue(secureMode);
+    secureFlag->setAttributes(SGPropertyNode::READ |
+                              SGPropertyNode::PRESERVE |
+                              SGPropertyNode::PROTECTED);
+}
 
 static void upper_case_property(const char *name)
 {
@@ -460,14 +483,14 @@ int fgMainInit( int argc, char **argv )
         return EXIT_FAILURE;
     }
 
-    if (!fgGetBool("/sim/fghome-readonly")) {
+    const bool readOnlyFGHome = fgGetBool("/sim/fghome-readonly");
+    if (!readOnlyFGHome) {
         // now home is initialised, we can log to a file inside it
         logToHome();
     }
 
     std::string version(FLIGHTGEAR_VERSION);
-    SG_LOG( SG_GENERAL, SG_INFO, "FlightGear:  Version "
-            << version );
+    SG_LOG( SG_GENERAL, SG_INFO, "FlightGear:  Version " << version );
     SG_LOG( SG_GENERAL, SG_INFO, "FlightGear:  Build Type " << FG_BUILD_TYPE );
     SG_LOG( SG_GENERAL, SG_INFO, "Built with " << SG_COMPILER_STR);
 	SG_LOG( SG_GENERAL, SG_INFO, "Jenkins number/ID " << HUDSON_BUILD_NUMBER << ":"
@@ -485,7 +508,7 @@ int fgMainInit( int argc, char **argv )
     upper_case_property("/sim/tower/airport-id");
     upper_case_property("/autopilot/route-manager/input");
 
-// check if the launcher is reuested, since it affects config file parsing
+// check if the launcher is requested, since it affects config file parsing
     bool showLauncher = flightgear::Options::checkForArg(argc, argv, "launcher");
     // an Info.plist bundle can't define command line arguments, but it can set
     // environment variables. This avoids needed a wrapper shell-script on OS-X.
@@ -497,6 +520,13 @@ int fgMainInit( int argc, char **argv )
         flightgear::Options::sharedInstance()->setShouldLoadDefaultConfig(false);
     }
 
+    if (showLauncher && readOnlyFGHome) {
+        // this is perhaps not what the user wanted, let's inform them
+        flightgear::modalMessageBox("Multiple copies of FlightGear",
+                                    "Another copy of FlightGear is already running on this computer, "
+                                    "so this copy will run in read-only mode.");
+    }
+
     // Load the configuration parameters.  (Command line options
     // override config file options.  Config file options override
     // defaults.)
@@ -518,9 +548,11 @@ int fgMainInit( int argc, char **argv )
     }
 #else
     if (showLauncher) {
-        SG_LOG(SG_GENERAL, SG_ALERT, "\n!Launcher requested, but FlightGear was compiled without Qt support!");
+        SG_LOG(SG_GENERAL, SG_ALERT, "\n!Launcher requested, but FlightGear was compiled without Qt support!\n");
     }
 #endif
+    
+    fgInitSecureMode();
     fgInitAircraftPaths(false);
 
     configResult = fgInitAircraft(false);
@@ -530,6 +562,8 @@ int fgMainInit( int argc, char **argv )
         return EXIT_SUCCESS;
     }
 
+    addons::AddonManager::createInstance();
+
     configResult = flightgear::Options::sharedInstance()->processOptions();
     if (configResult == flightgear::FG_OPTIONS_ERROR) {
         return EXIT_FAILURE;
@@ -537,6 +571,20 @@ int fgMainInit( int argc, char **argv )
         return EXIT_SUCCESS;
     }
 
+    // Set the lists of allowed paths for cases where a path comes from an
+    // untrusted source, such as the global property tree (this uses $FG_HOME
+    // and other paths set by Options::processOptions()).
+    fgInitAllowedPaths();
+
+    const auto& resMgr = simgear::EmbeddedResourceManager::createInstance();
+    initFlightGearEmbeddedResources();
+    // The language was set in processOptions()
+    const std::string locale = globals->get_locale()->getPreferredLanguage();
+    // Must always be done after all resources have been added to 'resMgr'
+    resMgr->selectLocale(locale);
+    SG_LOG(SG_GENERAL, SG_INFO,
+           "EmbeddedResourceManager: selected locale '" << locale << "'");
+
     // Initialize the Window/Graphics environment.
     fgOSInit(&argc, argv);
     _bootstrap_OSInit++;
