@@ -18,9 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include "config.h"
 
 #include "FlightPlan.hxx"
 
@@ -32,7 +30,6 @@
 // Boost
 #include <boost/algorithm/string/case_conv.hpp>
 #include <boost/algorithm/string.hpp>
-#include <boost/foreach.hpp>
 
 // SimGear
 #include <simgear/structure/exception.hxx>
@@ -51,6 +48,7 @@
 #include <Navaids/waypoint.hxx>
 #include <Navaids/routePath.hxx>
 #include <Navaids/airways.hxx>
+#include <Autopilot/route_mgr.hxx>
 
 using std::string;
 using std::vector;
@@ -63,7 +61,6 @@ typedef std::vector<FlightPlan::DelegateFactory*> FPDelegateFactoryVec;
 static FPDelegateFactoryVec static_delegateFactories;
   
 FlightPlan::FlightPlan() :
-  _delegateLock(0),
   _currentIndex(-1),
     _followLegTrackToFix(true),
     _aircraftCategory(ICAO_AIRCRAFT_CATEGORY_C),
@@ -72,12 +69,11 @@ FlightPlan::FlightPlan() :
   _sid(NULL),
   _star(NULL),
   _approach(NULL),
-  _totalDistance(0.0),
-  _delegate(NULL)
+  _totalDistance(0.0)
 {
   _departureChanged = _arrivalChanged = _waypointsChanged = _currentWaypointChanged = false;
   
-  BOOST_FOREACH(DelegateFactory* factory, static_delegateFactories) {
+  for (auto factory : static_delegateFactories) {
     Delegate* d = factory->createFlightPlanDelegate(this);
     if (d) { // factory might not always create a delegate
       d->_deleteWithPlan = true;
@@ -89,17 +85,14 @@ FlightPlan::FlightPlan() :
 FlightPlan::~FlightPlan()
 {
 // delete all delegates which we own.
-  Delegate* d = _delegate;
-  while (d) {
-    Delegate* cur = d;
-    d = d->_inner;
-    if (cur->_deleteWithPlan) {
-      delete cur;
+    for (auto d : _delegates) {
+        if (d->_deleteWithPlan) {
+            delete d;
+        }
     }
-  }
-    
+
 // delete legs
-    BOOST_FOREACH(Leg* l, _legs) {
+    for (auto l : _legs) {
         delete l;
     }
 }
@@ -108,7 +101,7 @@ FlightPlan* FlightPlan::clone(const string& newIdent) const
 {
   FlightPlan* c = new FlightPlan();
   c->_ident = newIdent.empty() ? _ident : newIdent;
-  c->lockDelegate();
+  c->lockDelegates();
   
 // copy destination / departure data.
   c->setDeparture(_departure);
@@ -125,12 +118,16 @@ FlightPlan* FlightPlan::clone(const string& newIdent) const
   c->setSTAR(_star);
   c->setSID(_sid);
   
+// mark data as unchanged since this is a clean plan
+  c->_arrivalChanged = false;
+  c->_departureChanged = false;
+    
 // copy legs
   c->_waypointsChanged = true;
   for (int l=0; l < numLegs(); ++l) {
     c->_legs.push_back(_legs[l]->cloneFor(c));
   }
-  c->unlockDelegate();
+  c->unlockDelegates();
   return c;
 }
 
@@ -182,14 +179,14 @@ void FlightPlan::insertWayptsAtIndex(const WayptVec& wps, int aIndex)
   }
  
   LegVec newLegs;
-  BOOST_FOREACH(WayptRef wp, wps) {
+  for (WayptRef wp : wps) {
     newLegs.push_back(new Leg(this, wp));
   }
   
-  lockDelegate();
+  lockDelegates();
   _waypointsChanged = true;
   _legs.insert(it, newLegs.begin(), newLegs.end());
-  unlockDelegate();
+  unlockDelegates();
 }
 
 void FlightPlan::deleteIndex(int aIndex)
@@ -204,7 +201,7 @@ void FlightPlan::deleteIndex(int aIndex)
     return;
   }
   
-  lockDelegate();
+  lockDelegates();
   _waypointsChanged = true;
   
   LegVec::iterator it = _legs.begin();
@@ -220,7 +217,7 @@ void FlightPlan::deleteIndex(int aIndex)
     --_currentIndex; // shift current index down if necessary
   }
   
-  unlockDelegate();
+  unlockDelegates();
 }
   
 void FlightPlan::clear()
@@ -231,22 +228,20 @@ void FlightPlan::clear()
         return;
     }
 
-  lockDelegate();
+  lockDelegates();
   _waypointsChanged = true;
   _currentWaypointChanged = true;
   _arrivalChanged = true;
   _departureChanged = true;
   
   _currentIndex = -1;
-  BOOST_FOREACH(Leg* l, _legs) {
+  for (Leg* l : _legs) {
     delete l;
   }
   _legs.clear();  
   
-  if (_delegate) {
-    _delegate->runCleared();
-  }
-  unlockDelegate();
+    notifyCleared();
+  unlockDelegates();
 }
   
 class RemoveWithFlag
@@ -302,12 +297,12 @@ int FlightPlan::clearWayptsWithFlag(WayptFlag flag)
   
 // now delete and remove
   RemoveWithFlag rf(flag);
-  LegVec::iterator it = std::remove_if(_legs.begin(), _legs.end(), rf);
+  auto it = std::remove_if(_legs.begin(), _legs.end(), rf);
   if (it == _legs.end()) {
     return 0; // nothing was cleared, don't fire the delegate
   }
   
-  lockDelegate();
+  lockDelegates();
   _waypointsChanged = true;
   if ((count > 0) || currentIsBeingCleared) {
     _currentWaypointChanged = true;
@@ -316,15 +311,18 @@ int FlightPlan::clearWayptsWithFlag(WayptFlag flag)
   _legs.erase(it, _legs.end());
     
   if (_legs.empty()) { // maybe all legs were deleted
-    if (_delegate) {
-      _delegate->runCleared();
-    }
+      notifyCleared();
   }
   
-  unlockDelegate();
+  unlockDelegates();
   return rf.numDeleted();
 }
-  
+    
+bool FlightPlan::isActive() const
+{
+    return (_currentIndex >= 0);
+}
+
 void FlightPlan::setCurrentIndex(int index)
 {
   if ((index < -1) || (index >= numLegs())) {
@@ -335,27 +333,27 @@ void FlightPlan::setCurrentIndex(int index)
     return;
   }
   
-  lockDelegate();
+  lockDelegates();
   _currentIndex = index;
   _currentWaypointChanged = true;
-  unlockDelegate();
+  unlockDelegates();
 }
 
 void FlightPlan::finish()
 {
-    if (_currentIndex == -1) {
-        return;
-    }
-    
-    lockDelegate();
-    _currentIndex = -1;
-    _currentWaypointChanged = true;
-    
-    if (_delegate) {
-        _delegate->runFinished();
-    }
-    
-    unlockDelegate();
+  if (_currentIndex == -1) {
+    return;
+  }
+  
+  lockDelegates();
+  _currentIndex = -1;
+  _currentWaypointChanged = true;
+  
+  for (auto d : _delegates) {
+    d->endOfFlightPlan();
+  }
+  
+  unlockDelegates();
 }
   
 int FlightPlan::findWayptIndex(const SGGeod& aPos) const
@@ -431,12 +429,12 @@ void FlightPlan::setDeparture(FGAirport* apt)
     return;
   }
   
-  lockDelegate();
+  lockDelegates();
   _departureChanged = true;
   _departure = apt;
-  _departureRunway = NULL;
-  setSID((SID*)NULL);
-  unlockDelegate();
+  _departureRunway = nullptr;
+  clearSID();
+  unlockDelegates();
 }
   
 void FlightPlan::setDeparture(FGRunway* rwy)
@@ -445,15 +443,25 @@ void FlightPlan::setDeparture(FGRunway* rwy)
     return;
   }
   
-  lockDelegate();
+  lockDelegates();
   _departureChanged = true;
 
   _departureRunway = rwy;
   if (rwy->airport() != _departure) {
     _departure = rwy->airport();
-    setSID((SID*)NULL);
+    clearSID();
   }
-  unlockDelegate();
+  unlockDelegates();
+}
+  
+void FlightPlan::clearDeparture()
+{
+  lockDelegates();
+  _departureChanged = true;
+  _departure = nullptr;
+  _departureRunway = nullptr;
+  clearSID();
+  unlockDelegates();
 }
   
 void FlightPlan::setSID(SID* sid, const std::string& transition)
@@ -462,11 +470,11 @@ void FlightPlan::setSID(SID* sid, const std::string& transition)
     return;
   }
   
-  lockDelegate();
+  lockDelegates();
   _departureChanged = true;
   _sid = sid;
   _sidTransition = transition;
-  unlockDelegate();
+  unlockDelegates();
 }
   
 void FlightPlan::setSID(Transition* trans)
@@ -482,6 +490,15 @@ void FlightPlan::setSID(Transition* trans)
   setSID((SID*) trans->parent(), trans->ident());
 }
   
+void FlightPlan::clearSID()
+{
+  lockDelegates();
+  _departureChanged = true;
+  _sid = nullptr;
+  _sidTransition.clear();
+  unlockDelegates();
+}
+  
 Transition* FlightPlan::sidTransition() const
 {
   if (!_sid || _sidTransition.empty()) {
@@ -497,13 +514,13 @@ void FlightPlan::setDestination(FGAirport* apt)
     return;
   }
   
-  lockDelegate();
+  lockDelegates();
   _arrivalChanged = true;
   _destination = apt;
-  _destinationRunway = NULL;
-  setSTAR((STAR*)NULL);
-  setApproach(NULL);
-  unlockDelegate();
+  _destinationRunway = nullptr;
+  clearSTAR();
+  setApproach(nullptr);
+  unlockDelegates();
 }
     
 void FlightPlan::setDestination(FGRunway* rwy)
@@ -512,28 +529,39 @@ void FlightPlan::setDestination(FGRunway* rwy)
     return;
   }
   
-  lockDelegate();
+  lockDelegates();
   _arrivalChanged = true;
   _destinationRunway = rwy;
   if (_destination != rwy->airport()) {
     _destination = rwy->airport();
-    setSTAR((STAR*)NULL);
+    clearSTAR();
   }
   
-  unlockDelegate();
+  unlockDelegates();
 }
   
+void FlightPlan::clearDestination()
+{
+  lockDelegates();
+  _arrivalChanged = true;
+  _destination = nullptr;
+  _destinationRunway = nullptr;
+  clearSTAR();
+  setApproach(nullptr);
+  unlockDelegates();
+}
+
 void FlightPlan::setSTAR(STAR* star, const std::string& transition)
 {
   if (_star == star) {
     return;
   }
   
-  lockDelegate();
+  lockDelegates();
   _arrivalChanged = true;
   _star = star;
   _starTransition = transition;
-  unlockDelegate();
+  unlockDelegates();
 }
   
 void FlightPlan::setSTAR(Transition* trans)
@@ -549,6 +577,16 @@ void FlightPlan::setSTAR(Transition* trans)
   setSTAR((STAR*) trans->parent(), trans->ident());
 }
 
+void FlightPlan::clearSTAR()
+{
+
+  lockDelegates();
+  _arrivalChanged = true;
+  _star = nullptr;
+  _starTransition.clear();
+  unlockDelegates();
+}
+  
 Transition* FlightPlan::starTransition() const
 {
   if (!_star || _starTransition.empty()) {
@@ -564,7 +602,7 @@ void FlightPlan::setApproach(flightgear::Approach *app)
     return;
   }
   
-  lockDelegate();
+  lockDelegates();
   _arrivalChanged = true;
   _approach = app;
   if (app) {
@@ -577,7 +615,7 @@ void FlightPlan::setApproach(flightgear::Approach *app)
       _destination = _destinationRunway->airport();
     }
   }
-  unlockDelegate();
+  unlockDelegates();
 }
   
 bool FlightPlan::save(const SGPath& path)
@@ -641,7 +679,7 @@ bool FlightPlan::load(const SGPath& path)
   SG_LOG(SG_NAVAID, SG_INFO, "going to read flight-plan from:" << path);
   
   bool Status = false;
-  lockDelegate();
+  lockDelegates();
 
   // try different file formats
   if (loadGpxFormat(path)) // GPX format
@@ -653,8 +691,17 @@ bool FlightPlan::load(const SGPath& path)
   if (loadPlainTextFormat(path)) // simple textual list of waypoints
       Status = true;
 
+  
+  if (Status == true) {
+    setIdent(path.file_base());
+  }
+  
+  // mark data as unchanged since this is a clean plan
+  _arrivalChanged = false;
+  _departureChanged = false;
+    
   _waypointsChanged = true;
-  unlockDelegate();
+  unlockDelegates();
 
   return Status;
 }
@@ -1130,45 +1177,53 @@ WayptRef FlightPlan::waypointFromString(const string& tgt )
 
 void FlightPlan::activate()
 {
-    lockDelegate();
-
-    _currentIndex = 0;
-    _currentWaypointChanged = true;
-
-    for (unsigned int i=0; i < _legs.size(); ) {
-        if (_legs[i]->waypoint()->type() == "via") {
-            WayptRef preceeding = _legs[i - 1]->waypoint();
-            Via* via = static_cast<Via*>(_legs[i]->waypoint());
-            WayptVec wps = via->expandToWaypoints(preceeding);
-
-            // delete the VIA leg
-            LegVec::iterator it = _legs.begin();
-            it += i;
-            Leg* l = *it;
-            _legs.erase(it);
-            delete l;
-
-            // create new lefs and insert
-            it = _legs.begin();
-            it += i;
-
-            LegVec newLegs;
-            BOOST_FOREACH(WayptRef wp, wps) {
-                newLegs.push_back(new Leg(this, wp));
-            }
-
-            _waypointsChanged = true;
-            _legs.insert(it, newLegs.begin(), newLegs.end());
-        } else {
-            ++i; // normal case, no expansion
-        }
+  FGRouteMgr* routeManager = globals->get_subsystem<FGRouteMgr>();
+  if (routeManager) {
+    if (routeManager->flightPlan() != this) {
+      SG_LOG(SG_NAVAID, SG_INFO, "setting new flight-plan on route-manager");
+      routeManager->setFlightPlan(this);
     }
-
-    if (_delegate) {
-        _delegate->runActivated();
+  }
+  
+  lockDelegates();
+  
+  _currentIndex = 0;
+  _currentWaypointChanged = true;
+  
+  for (unsigned int i=0; i < _legs.size(); ) {
+    if (_legs[i]->waypoint()->type() == "via") {
+      WayptRef preceeding = _legs[i - 1]->waypoint();
+      Via* via = static_cast<Via*>(_legs[i]->waypoint());
+      WayptVec wps = via->expandToWaypoints(preceeding);
+      
+      // delete the VIA leg
+      LegVec::iterator it = _legs.begin();
+      it += i;
+      Leg* l = *it;
+      _legs.erase(it);
+      delete l;
+      
+      // create new lefs and insert
+      it = _legs.begin();
+      it += i;
+      
+      LegVec newLegs;
+      for (WayptRef wp : wps) {
+        newLegs.push_back(new Leg(this, wp));
+      }
+      
+      _waypointsChanged = true;
+      _legs.insert(it, newLegs.begin(), newLegs.end());
+    } else {
+      ++i; // normal case, no expansion
     }
-
-    unlockDelegate();
+  }
+  
+  for (auto d : _delegates) {
+    d->activated();
+  }
+  
+  unlockDelegates();
 }
 
 FlightPlan::Leg::Leg(FlightPlan* owner, WayptRef wpt) :
@@ -1314,7 +1369,7 @@ SGGeod FlightPlan::pointAlongRoute(int aIndex, double aOffsetNm) const
     return rp.positionForDistanceFrom(aIndex, aOffsetNm * SG_NM_TO_METER);
 }
     
-void FlightPlan::lockDelegate()
+void FlightPlan::lockDelegates()
 {
   if (_delegateLock == 0) {
     assert(!_departureChanged && !_arrivalChanged && 
@@ -1322,9 +1377,12 @@ void FlightPlan::lockDelegate()
   }
   
   ++_delegateLock;
+  if (_delegateLock > 10) {
+    SG_LOG(SG_GENERAL, SG_ALERT, "hmmm");
+  }
 }
 
-void FlightPlan::unlockDelegate()
+void FlightPlan::unlockDelegates()
 {
   assert(_delegateLock > 0);
   if (_delegateLock > 1) {
@@ -1334,42 +1392,41 @@ void FlightPlan::unlockDelegate()
   
   if (_departureChanged) {
     _departureChanged = false;
-    if (_delegate) {
-      _delegate->runDepartureChanged();
+    for (auto d : _delegates) {
+      d->departureChanged();
     }
   }
   
   if (_arrivalChanged) {
     _arrivalChanged = false;
-    if (_delegate) {
-      _delegate->runArrivalChanged();
+    for (auto d : _delegates) {
+      d->arrivalChanged();
     }
   }
   
   if (_waypointsChanged) {
     _waypointsChanged = false;
     rebuildLegData();
-    if (_delegate) {
-      _delegate->runWaypointsChanged();
+    for (auto d : _delegates) {
+      d->waypointsChanged();
     }
   }
   
   if (_currentWaypointChanged) {
     _currentWaypointChanged = false;
-    if (_delegate) {
-      _delegate->runCurrentWaypointChanged();
+    for (auto d : _delegates) {
+      d->currentWaypointChanged();
     }
   }
-
+  
   --_delegateLock;
 }
   
 void FlightPlan::registerDelegateFactory(DelegateFactory* df)
 {
-  FPDelegateFactoryVec::iterator it = std::find(static_delegateFactories.begin(),
-                                                static_delegateFactories.end(), df);
+  auto it = std::find(static_delegateFactories.begin(), static_delegateFactories.end(), df);
   if (it != static_delegateFactories.end()) {
-    throw  sg_exception("duplicate delegate factory registration");
+    throw sg_exception("duplicate delegate factory registration");
   }
   
   static_delegateFactories.push_back(df);
@@ -1377,8 +1434,7 @@ void FlightPlan::registerDelegateFactory(DelegateFactory* df)
   
 void FlightPlan::unregisterDelegateFactory(DelegateFactory* df)
 {
-  FPDelegateFactoryVec::iterator it = std::find(static_delegateFactories.begin(),
-                                                static_delegateFactories.end(), df);
+  auto it = std::find(static_delegateFactories.begin(), static_delegateFactories.end(), df);
   if (it == static_delegateFactories.end()) {
     return;
   }
@@ -1388,23 +1444,28 @@ void FlightPlan::unregisterDelegateFactory(DelegateFactory* df)
   
 void FlightPlan::addDelegate(Delegate* d)
 {
-  // wrap any existing delegate(s) in the new one
-  d->_inner = _delegate;
-  _delegate = d;
+  assert(d);
+  auto it = std::find(_delegates.begin(), _delegates.end(), d);
+  assert(it == _delegates.end());
+  _delegates.push_back(d);
 }
 
 void FlightPlan::removeDelegate(Delegate* d)
 {
-  if (d == _delegate) {
-    _delegate = _delegate->_inner;
-  } else if (_delegate) {
-    _delegate->removeInner(d);
-  }
+  assert(d);
+  auto it = std::find(_delegates.begin(), _delegates.end(), d);
+  assert(it != _delegates.end());
+  _delegates.erase(it);
 }
   
-FlightPlan::Delegate::Delegate() :
-  _deleteWithPlan(false),
-  _inner(NULL)
+void FlightPlan::notifyCleared()
+{
+    for (auto d : _delegates) {
+        d->cleared();
+    }
+}
+
+FlightPlan::Delegate::Delegate()
 {
 }
 
@@ -1412,62 +1473,6 @@ FlightPlan::Delegate::~Delegate()
 {  
 }
 
-void FlightPlan::Delegate::removeInner(Delegate* d)
-{
-  if (!_inner) {
-      throw sg_exception("FlightPlan delegate not found");
-  }
-  
-  if (_inner == d) {
-    // replace with grand-child
-    _inner = d->_inner;
-  } else { // recurse downwards
-    _inner->removeInner(d);
-  }
-}
-
-void FlightPlan::Delegate::runDepartureChanged()
-{
-  if (_inner) _inner->runDepartureChanged();
-  departureChanged();
-}
-
-void FlightPlan::Delegate::runArrivalChanged()
-{
-  if (_inner) _inner->runArrivalChanged();
-  arrivalChanged();
-}
-
-void FlightPlan::Delegate::runWaypointsChanged()
-{
-  if (_inner) _inner->runWaypointsChanged();
-  waypointsChanged();
-}
-  
-void FlightPlan::Delegate::runCurrentWaypointChanged()
-{
-  if (_inner) _inner->runCurrentWaypointChanged();
-  currentWaypointChanged();
-}
-
-void FlightPlan::Delegate::runCleared()
-{
-  if (_inner) _inner->runCleared();
-  cleared();
-}  
-
-void FlightPlan::Delegate::runFinished()
-{
-    if (_inner) _inner->runFinished();
-    endOfFlightPlan();
-}
-
-void FlightPlan::Delegate::runActivated()
-{
-    if (_inner) _inner->runActivated();
-    activated();
-}
-
 void FlightPlan::setFollowLegTrackToFixes(bool tf)
 {
     _followLegTrackToFix = tf;
