@@ -39,9 +39,12 @@
 #include <sstream>
 #include <iostream>
 #include <errno.h>
+#include <algorithm>
+#include <functional>
 
 #include <Main/globals.hxx>
 #include <Viewer/viewmgr.hxx>
+#include <Scripting/NasalSys.hxx>
 
 #include <simgear/io/sg_netChat.hxx>
 
@@ -52,8 +55,8 @@
 #include <map>
 #include <vector>
 #include <string>
+#include <set>
 
-#include <boost/foreach.hpp>
 
 using std::stringstream;
 using std::ends;
@@ -65,26 +68,26 @@ using std::endl;
  * Props connection class.
  * This class represents a connection to props client.
  */
-class PropsChannel : public simgear::NetChat, public SGPropertyChangeListener
+class FGProps::PropsChannel : public simgear::NetChat, public SGPropertyChangeListener
 {
     simgear::NetBuffer buffer;
 
     /**
      * Current property node name.
      */
-    string path;
+    string path= "/";
 
     enum Mode {
         PROMPT,
         DATA
     };
-    Mode mode;
+    Mode mode = PROMPT;
 
 public:
     /**
      * Constructor.
      */
-    PropsChannel();
+    PropsChannel(FGProps* owner);
     ~PropsChannel();
 
     /**
@@ -93,15 +96,17 @@ public:
      * @param s Character string to append to buffer
      * @param n Number of characters to append.
      */
-    void collectIncomingData( const char* s, int n );
+    void collectIncomingData( const char* s, int n ) override;
 
     /**
      * Process a complete request from the props client.
      */
-    void foundTerminator();
+    void foundTerminator() override;
 
     // callback for registered listeners (subscriptions)
-    void valueChanged(SGPropertyNode *node);
+    void valueChanged(SGPropertyNode *node) override;
+
+    void publishDirtySubscriptions();
 private:
 
     typedef string_list ParameterList;
@@ -125,35 +130,44 @@ private:
     }
 
     std::vector<SGPropertyNode_ptr> _listeners;
+    std::set<SGPropertyNode_ptr> _dirtySubscriptions;
+
     typedef void (PropsChannel::*TelnetCallback) (const ParameterList&);
     std::map<std::string, TelnetCallback> callback_map;
 
     // callback implementations:
     void subscribe(const ParameterList &p);
     void unsubscribe(const ParameterList &p);
+    void beginNasal(const ParameterList &p);
+
+    FGProps* _owner = nullptr;
+    bool _colletingNasal = false;
 };
 
 /**
  *
  */
-PropsChannel::PropsChannel()
-    : buffer(512),
-      path("/"),
-      mode(PROMPT)
+FGProps::PropsChannel::PropsChannel(FGProps* owner)
+    : buffer(8192)
+    , _owner(owner)
 {
     setTerminator( "\r\n" );
     callback_map["subscribe"] 	= 	&PropsChannel::subscribe;
     callback_map["unsubscribe"]	=	&PropsChannel::unsubscribe;
+    callback_map["nasal"] =         &PropsChannel::beginNasal;
 }
 
-PropsChannel::~PropsChannel() {
+FGProps::PropsChannel::~PropsChannel()
+{
   // clean up all registered listeners
-    BOOST_FOREACH(SGPropertyNode_ptr l, _listeners) {
-    l->removeChangeListener( this  );
- }
+    for (SGPropertyNode_ptr l : _listeners) {
+        l->removeChangeListener(this);
+    }
+
+    _owner->removeChannel(this);
 }
 
-void PropsChannel::subscribe(const ParameterList &param) {
+void FGProps::PropsChannel::subscribe(const ParameterList &param) {
 	if (! check_args(param,1,"subscribe")) return;
 
 	std::string command = param[0];
@@ -179,32 +193,58 @@ void PropsChannel::subscribe(const ParameterList &param) {
   }
 }
 
-void PropsChannel::unsubscribe(const ParameterList &param) {
+void FGProps::PropsChannel::unsubscribe(const ParameterList &param) {
   if (!check_args(param,1,"unsubscribe")) return;
 
   try {
    SGPropertyNode *n = globals->get_props()->getNode( param[1].c_str() );
-   if (n)
-    n->removeChangeListener( this );
+   if (n) {
+       n->removeChangeListener( this );
+       _dirtySubscriptions.erase(n);
+   }
   } catch (sg_exception&) {
 	  error("Error:Listener could not be removed");
   }
 }
 
+void FGProps::PropsChannel::beginNasal(const ParameterList &param)
+{
+    std::string eofMarker = "##EOF##";
+    if (param.size() > 1) {
+        if ((param.at(1) == "eof") && (param.size() >= 3)) {
+            eofMarker = param.at(2);
+        }
+    } // of optional argument parsing
+    
+    _colletingNasal = true;
+    setTerminator(eofMarker);
+}
 
 //TODO: provide support for different types of subscriptions MODES ? (child added/removed, thesholds, min/max)
-  void PropsChannel::valueChanged(SGPropertyNode* ptr) {
-  //SG_LOG(SG_GENERAL, SG_ALERT, __FILE__<< "@"<<__LINE__ << ":" << __FUNCTION__ << std::endl);
-  std::stringstream response;
-  response << ptr->getPath(true) << "=" <<  ptr->getStringValue() << getTerminator(); //TODO: use hashes, echo several properties at once
-  push( response.str().c_str() );
-}
+  void FGProps::PropsChannel::valueChanged(SGPropertyNode* ptr)
+  {
+      _dirtySubscriptions.insert(ptr);
+  }
+
+  void FGProps::PropsChannel::publishDirtySubscriptions()
+  {
+      if (_dirtySubscriptions.empty())
+          return; // nothing to send
+
+      std::stringstream response;
+      for (auto sub : _dirtySubscriptions) {
+          response << sub->getPath(true) << "=" <<  sub->getStringValue() << getTerminator();
+      }
+
+      push(response.str().c_str());
+      _dirtySubscriptions.clear();
+  }
 
 /**
  *
  */
 void
-PropsChannel::collectIncomingData( const char* s, int n )
+FGProps::PropsChannel::collectIncomingData( const char* s, int n )
 {
     buffer.append( s, n );
 }
@@ -249,10 +289,37 @@ getValueTypeString( const SGPropertyNode *node )
  *
  */
 void
-PropsChannel::foundTerminator()
+FGProps::PropsChannel::foundTerminator()
 {
+    if (_colletingNasal) {
+        std::string nasalSource = buffer.getData(); // make a copy
+        _colletingNasal = false;
+        setTerminator("\r\n");
+        buffer.remove(); // safe since we copied the source above
+
+        if (globals->get_props()->getBoolValue("sim/secure-flag", true) == true) {
+            SG_LOG(SG_IO, SG_ALERT, "Telnet connection trying to run Nasal, blocked it.\n"
+                   "Run the simulator with --allow-nasal-from-sockets to allow this.");
+            error("Simulator running in secure mode, Nasal execution blocked.");
+        } else {
+            auto nasal = globals->get_subsystem<FGNasalSys>();
+            if (nasal) {
+                std::string errors, output;
+                bool ok = nasal->parseAndRunWithOutput(nasalSource, output, errors);
+                if (!ok) {
+                    error("Nasal error" + errors);
+                } else if (!output.empty()) {
+                    // success and we have output: push it
+                    push(output.c_str());
+                }
+            }
+        }
+        
+        return;
+    }
+    
     const char* cmd = buffer.getData();
-    SG_LOG( SG_IO, SG_INFO, "processing command = \"" << cmd << "\"" );
+    SG_LOG( SG_IO, SG_DEBUG, "processing command = \"" << cmd << "\"" );
 
     ParameterList tokens = simgear::strutils::split( cmd );
 
@@ -384,7 +451,7 @@ PropsChannel::foundTerminator()
                         node->setStringValue( tokens[i].c_str() );
                     }
                     if ( !globals->get_commands()
-                             ->execute( "reinit", &args) )
+                             ->execute( "reinit", &args, nullptr) )
                     {
                         SG_LOG( SG_NETWORK, SG_ALERT,
                                 "Command " << tokens[1] << " failed.");
@@ -449,7 +516,7 @@ PropsChannel::foundTerminator()
                        }
                     }
                     if ( !globals->get_commands()
-                             ->execute(tokens[1].c_str(), &args) )
+                             ->execute(tokens[1].c_str(), &args, nullptr) )
                     {
                         SG_LOG( SG_NETWORK, SG_ALERT,
                                 "Command " << tokens[1] << " failed.");
@@ -481,12 +548,12 @@ PropsChannel::foundTerminator()
             } else if ( command == "prompt" ) {
                 mode = PROMPT;
             } else if (callback_map.find(command) != callback_map.end() ) {
-		   TelnetCallback t = callback_map[ command ];
-		   if (t)
-		     	   (this->*t) (tokens);
-		   else
-			   error("No matching callback found for command:"+command);
-	    }
+                TelnetCallback t = callback_map[ command ];
+                if (t)
+                    (this->*t) (tokens);
+                else
+                    error("No matching callback found for command:"+command);
+            }
       else if ( command == "seti" ) {
         string value, tmp;
         if (tokens.size() == 3) {
@@ -579,7 +646,9 @@ setf <var> <val>   alias for setd\r\n\
 seti <var> <val>   set Int <var> to a new <val>\r\n\
 del <var> <nod>    delete <nod> in <var>\r\n\
 subscribe <var>	   subscribe to property changes \r\n\
-unscubscribe <var>  unscubscribe from property changes (var must be the property name/path used by subscribe)\r\n";
+unsubscribe <var>  unscubscribe from property changes (var must be the property name/path used by subscribe)\r\n\
+nasal [EOF <marker>]  execute arbitrary Nasal code (simulator must be running with Nasal allowed from sockets)\r\n\
+";
                 push( msg );
             }
         }
@@ -590,7 +659,7 @@ unscubscribe <var>  unscubscribe from property changes (var must be the property
         push( getTerminator() );
     }
 
-    if ( mode == PROMPT ) {
+    if ( (mode == PROMPT) && !_colletingNasal) {
         string prompt = node->getPath();
         if (prompt.empty()) {
             prompt = "/";
@@ -696,6 +765,11 @@ bool
 FGProps::process()
 {
     poller.poll();
+
+    for (auto channel : _activeChannels) {
+        channel->publishDirtySubscriptions();
+    }
+
     return true;
 }
 
@@ -709,7 +783,18 @@ FGProps::handleAccept()
     int handle = accept( &addr );
     SG_LOG( SG_IO, SG_INFO, "Props server accepted connection from "
             << addr.getHost() << ":" << addr.getPort() );
-    PropsChannel* channel = new PropsChannel();
+    PropsChannel* channel = new PropsChannel(this);
     channel->setHandle( handle );
     poller.addChannel( channel );
+    _activeChannels.push_back(channel);
+}
+
+void FGProps::removeChannel(FGProps::PropsChannel *channel)
+{
+    auto it = std::find(_activeChannels.begin(), _activeChannels.end(), channel);
+    if (it == _activeChannels.end()) {
+        SG_LOG(SG_IO, SG_WARN, "FGProps::removeChannel: unknown channel");
+    } else {
+        _activeChannels.erase(it);
+    }
 }
