@@ -22,7 +22,7 @@
 #  include "config.h"
 #endif
 
-#include <string.h>
+#include <cstring>
 
 #include "NasalPositioned.hxx"
 
@@ -45,6 +45,7 @@
 #include <Navaids/procedure.hxx>
 #include <Main/globals.hxx>
 #include <Main/fg_props.hxx>
+#include <Main/util.hxx>
 #include <Scenery/scenery.hxx>
 #include <ATC/CommStation.hxx>
 #include <Navaids/FlightPlan.hxx>
@@ -261,12 +262,13 @@ static FlightPlan* flightplanGhost(naRef r)
 
 static void routeBaseGhostDestroy(void* g)
 {
-  // nothing for now
+    RouteBase* r = (RouteBase*) g;
+    if (!RouteBase::put(r)) // unref
+        delete r;
 }
 
 static naRef airportPrototype;
 static naRef flightplanPrototype;
-static naRef waypointPrototype;
 static naRef geoCoordClass;
 static naRef fpLegPrototype;
 static naRef procedurePrototype;
@@ -357,6 +359,7 @@ naRef ghostForFlightPlan(naContext c, const FlightPlan* fp)
     return naNil();
   }
   
+  FlightPlan::get(fp); // take a ref
   return naNewGhost2(c, &FlightPlanGhostType, (void*) fp);
 }
 
@@ -366,6 +369,7 @@ naRef ghostForProcedure(naContext c, const Procedure* proc)
     return naNil();
   }
   
+  FlightPlan::get(proc); // take a ref
   return naNewGhost2(c, &ProcedureGhostType, (void*) proc);
 }
 
@@ -424,6 +428,45 @@ static const char* airportGhostGetMember(naContext c, void* g, naRef field, naRe
   return "";
 }
 
+// Return the navaid ghost associated with a waypoint of navaid type.
+static naRef waypointNavaid(naContext c, Waypt* wpt)
+{
+  FGPositioned* pos = wpt->source();
+
+  if (!FGPositioned::isNavaidType(pos)) {
+    return naNil();
+  }
+
+  return ghostForNavaid(c, static_cast<FGNavRecord*>(pos));
+}
+
+// Return the airport ghost associated with a waypoint of airport or runway
+// type.
+static naRef waypointAirport(naContext c, Waypt* wpt)
+{
+  FGPositioned* pos = wpt->source();
+
+  if (FGPositioned::isRunwayType(pos)) {
+    pos = static_cast<FGRunway*>(pos) -> airport();
+  } else if (!FGPositioned::isAirportType(pos)) {
+    return naNil();
+  }
+
+  return ghostForAirport(c, static_cast<FGAirport*>(pos));
+}
+
+// Return the runway ghost associated with a waypoint of runway type.
+static naRef waypointRunway(naContext c, Waypt* wpt)
+{
+  FGPositioned* pos = wpt->source();
+
+  if (!FGPositioned::isRunwayType(pos)) {
+    return naNil();
+  }
+
+  return ghostForRunway(c, static_cast<FGRunway*>(pos));
+}
+
 static const char* waypointCommonGetMember(naContext c, Waypt* wpt, const char* fieldName, naRef* out)
 {
   if (!strcmp(fieldName, "wp_name") || !strcmp(fieldName, "id")) *out = stringToNasal(c, wpt->ident());
@@ -445,8 +488,14 @@ static const char* waypointCommonGetMember(naContext c, Waypt* wpt, const char*
     }
   } else if (!strcmp(fieldName, "heading_course")) {
       *out = naNum(wpt->headingRadialDeg());
+  } else if (!strcmp(fieldName, "navaid")) {
+    *out = waypointNavaid(c, wpt);
+  } else if (!strcmp(fieldName, "airport")) {
+    *out = waypointAirport(c, wpt);
+  } else if (!strcmp(fieldName, "runway")) {
+    *out = waypointRunway(c, wpt);
   } else {
-    return NULL; // member not found
+    return nullptr; // member not found
   }
 
   return "";
@@ -477,10 +526,13 @@ static const char* wayptGhostGetMember(naContext c, void* g, naRef field, naRef*
   return waypointCommonGetMember(c, wpt, fieldName, out);
 }
 
-static RouteRestriction routeRestrictionFromString(const char* s)
+static RouteRestriction routeRestrictionFromArg(naRef arg)
 {
-  std::string u(s);
-  boost::to_lower(u);
+  if (naIsNil(arg) || !naIsString(arg)) {
+    return RESTRICT_NONE;
+  }
+  
+  const std::string u = simgear::strutils::lowercase(naStr_data(arg));
   if (u == "computed") return RESTRICT_COMPUTED;
   if (u == "at") return RESTRICT_AT;
   if (u == "mach") return SPEED_RESTRICT_MACH;
@@ -505,6 +557,45 @@ naRef routeRestrictionToNasal(naContext c, RouteRestriction rr)
   return naNil();
 }
 
+// navaid() method of FPLeg ghosts
+static naRef f_fpLeg_navaid(naContext c, naRef me, int argc, naRef* args)
+{
+  flightgear::Waypt* w = wayptGhost(me);
+  if (!w) {
+    naRuntimeError(c,
+                   "flightplan-leg.navaid() called, but can't find the "
+                   "underlying waypoint for the flightplan-leg object");
+  }
+
+  return waypointNavaid(c, w);
+}
+
+// airport() method of FPLeg ghosts
+static naRef f_fpLeg_airport(naContext c, naRef me, int argc, naRef* args)
+{
+  flightgear::Waypt* w = wayptGhost(me);
+  if (!w) {
+    naRuntimeError(c,
+                   "flightplan-leg.airport() called, but can't find the "
+                   "underlying waypoint for the flightplan-leg object");
+  }
+
+  return waypointAirport(c, w);
+}
+
+// runway() method of FPLeg ghosts
+static naRef f_fpLeg_runway(naContext c, naRef me, int argc, naRef* args)
+{
+  flightgear::Waypt* w = wayptGhost(me);
+  if (!w) {
+    naRuntimeError(c,
+                   "flightplan-leg.runway() called, but can't find the "
+                   "underlying waypoint for the flightplan-leg object");
+  }
+
+  return waypointRunway(c, w);
+}
+
 static const char* legGhostGetMember(naContext c, void* g, naRef field, naRef* out)
 {
   const char* fieldName = naStr_data(field);
@@ -514,7 +605,6 @@ static const char* legGhostGetMember(naContext c, void* g, naRef field, naRef* o
   if (!strcmp(fieldName, "parents")) {
     *out = naNewVector(c);
     naVec_append(*out, fpLegPrototype);
-    naVec_append(*out, waypointPrototype);
   } else if (!strcmp(fieldName, "index")) {
     *out = naNum(leg->index());
   } else if (!strcmp(fieldName, "alt_cstr")) {
@@ -532,6 +622,12 @@ static const char* legGhostGetMember(naContext c, void* g, naRef field, naRef* o
     *out = naNum(leg->courseDeg());
   } else if (!strcmp(fieldName, "distance_along_route")) {
     *out = naNum(leg->distanceAlongRoute());
+  } else if (!strcmp(fieldName, "airport")) {
+    *out = naNewFunc(c, naNewCCode(c, f_fpLeg_airport));
+  } else if (!strcmp(fieldName, "navaid")) {
+    *out = naNewFunc(c, naNewCCode(c, f_fpLeg_navaid));
+  } else if (!strcmp(fieldName, "runway")) {
+    *out = naNewFunc(c, naNewCCode(c, f_fpLeg_runway));
   } else { // check for fields defined on the underlying waypoint
     return waypointCommonGetMember(c, wpt, fieldName, out);
   }
@@ -575,6 +671,7 @@ static const char* flightplanGhostGetMember(naContext c, void* g, naRef field, n
   else if (!strcmp(fieldName, "current")) *out = naNum(fp->currentIndex());
     else if (!strcmp(fieldName, "aircraftCategory")) *out = stringToNasal(c, fp->icaoAircraftCategory());
     else if (!strcmp(fieldName, "followLegTrackToFix")) *out = naNum(fp->followLegTrackToFixes());
+    else if (!strcmp(fieldName, "active")) *out = naNum(fp->isActive());
   else {
     return 0;
   }
@@ -610,10 +707,10 @@ static void flightplanGhostSetMember(naContext c, void* g, naRef field, naRef va
     }
     
     if (naIsNil(value)) {
-      fp->setDeparture(static_cast<FGAirport*>(NULL));
+      fp->clearDeparture();
       return;
     }
-      
+    
     naRuntimeError(c, "bad argument type setting departure");
   } else if (!strcmp(fieldName, "destination")) {
     FGAirport* apt = airportGhost(value);
@@ -628,6 +725,11 @@ static void flightplanGhostSetMember(naContext c, void* g, naRef field, naRef va
       return;
     }
     
+    if (naIsNil(value)) {
+      fp->clearDestination();
+      return;
+    }
+    
     naRuntimeError(c, "bad argument type setting destination");
   } else if (!strcmp(fieldName, "departure_runway")) {
     FGRunway* rwy = runwayGhost(value);
@@ -656,13 +758,18 @@ static void flightplanGhostSetMember(naContext c, void* g, naRef field, naRef va
       fp->setSID((Transition*) proc);
       return;
     }
-        
+    
     if (naIsString(value)) {
       FGAirport* apt = fp->departureAirport();
       fp->setSID(apt->findSIDWithIdent(naStr_data(value)));
       return;
     }
     
+    if (naIsNil(value)) {
+      fp->clearSID();
+      return;
+    }
+    
     naRuntimeError(c, "bad argument type setting SID");
   } else if (!strcmp(fieldName, "star")) {
     Procedure* proc = procedureGhost(value);
@@ -682,6 +789,11 @@ static void flightplanGhostSetMember(naContext c, void* g, naRef field, naRef va
       return;
     }
     
+    if (naIsNil(value)) {
+      fp->clearSTAR();
+      return;
+    }
+    
     naRuntimeError(c, "bad argument type setting STAR");
   } else if (!strcmp(fieldName, "approach")) {
     Procedure* proc = procedureGhost(value);
@@ -696,17 +808,21 @@ static void flightplanGhostSetMember(naContext c, void* g, naRef field, naRef va
       return;
     }
     
+    if (naIsNil(value)) {
+      fp->setApproach(nullptr);
+      return;
+    }
+    
     naRuntimeError(c, "bad argument type setting approach");
   } else if (!strcmp(fieldName, "aircraftCategory")) {
-      if (!naIsString(value)) naRuntimeError(c, "aircraftCategory must be a string");
-      fp->setIcaoAircraftCategory(naStr_data(value));
+    if (!naIsString(value)) naRuntimeError(c, "aircraftCategory must be a string");
+    fp->setIcaoAircraftCategory(naStr_data(value));
   } else if (!strcmp(fieldName, "followLegTrackToFix")) {
-      int b = (int) value.num;
-      fp->setFollowLegTrackToFixes(b);
+    int b = (int) value.num;
+    fp->setFollowLegTrackToFixes(b);
   }
 }
 
-
 static naRef procedureTpType(naContext c, ProcedureType ty)
 {
   switch (ty) {
@@ -1658,6 +1774,50 @@ static naRef f_findNavaidsWithinRange(naContext c, naRef me, int argc, naRef* ar
   return r;
 }
 
+static naRef f_findNDBByFrequency(naContext c, naRef me, int argc, naRef* args)
+{
+  int argOffset = 0;
+  SGGeod pos = globals->get_aircraft_position();
+  argOffset += geodFromArgs(args, 0, argc, pos);
+  
+  if (!naIsNum(args[argOffset])) {
+    naRuntimeError(c, "findNDBByFrquency expectes frequency (in kHz) as arg %d", argOffset);
+  }
+  
+  double dbFreq = args[argOffset++].num;
+  FGNavList::TypeFilter filter(FGPositioned::NDB);
+  nav_list_type navs = FGNavList::findAllByFreq(dbFreq, pos, &filter);
+  if (navs.empty()) {
+    return naNil();
+  }
+  
+  return ghostForNavaid(c, navs.front().ptr());
+}
+
+static naRef f_findNDBsByFrequency(naContext c, naRef me, int argc, naRef* args)
+{
+  int argOffset = 0;
+  SGGeod pos = globals->get_aircraft_position();
+  argOffset += geodFromArgs(args, 0, argc, pos);
+  
+  if (!naIsNum(args[argOffset])) {
+    naRuntimeError(c, "findNDBsByFrquency expectes frequency (in kHz) as arg %d", argOffset);
+  }
+  
+  double dbFreq = args[argOffset++].num;
+  FGNavList::TypeFilter filter(FGPositioned::NDB);
+  nav_list_type navs = FGNavList::findAllByFreq(dbFreq, pos, &filter);
+  if (navs.empty()) {
+    return naNil();
+  }
+  
+  naRef r = naNewVector(c);
+  for (nav_rec_ptr a : navs) {
+    naVec_append(r, ghostForNavaid(c, a.ptr()));
+  }
+  return r;
+}
+
 static naRef f_findNavaidByFrequency(naContext c, naRef me, int argc, naRef* args)
 {
   int argOffset = 0;
@@ -1672,10 +1832,13 @@ static naRef f_findNavaidByFrequency(naContext c, naRef me, int argc, naRef* arg
   double freqMhz = args[argOffset++].num;
   if (argOffset < argc) {
     type = FGPositioned::typeFromName(naStr_data(args[argOffset]));
+    if (type == FGPositioned::NDB) {
+      naRuntimeError(c, "Use findNDBByFrquency to seach NDBs");
+    }
   }
   
   FGNavList::TypeFilter filter(type);
-  nav_list_type navs = FGNavList::findAllByFreq(freqMhz, pos, &filter);
+  auto navs = FGNavList::findAllByFreq(freqMhz, pos, &filter);
   if (navs.empty()) {
     return naNil();
   }
@@ -1697,14 +1860,15 @@ static naRef f_findNavaidsByFrequency(naContext c, naRef me, int argc, naRef* ar
   double freqMhz = args[argOffset++].num;
   if (argOffset < argc) {
     type = FGPositioned::typeFromName(naStr_data(args[argOffset]));
+    if (type == FGPositioned::NDB) {
+      naRuntimeError(c, "Use findNDBsByFrquency to seach NDBs");
+    }
   }
   
   naRef r = naNewVector(c);
-  
   FGNavList::TypeFilter filter(type);
-  nav_list_type navs = FGNavList::findAllByFreq(freqMhz, pos, &filter);
-  
-  BOOST_FOREACH(nav_rec_ptr a, navs) {
+  auto navs = FGNavList::findAllByFreq(freqMhz, pos, &filter);
+  for (nav_rec_ptr a : navs) {
     naVec_append(r, ghostForNavaid(c, a.ptr()));
   }
   
@@ -1849,32 +2013,40 @@ static naRef f_tileIndex(naContext c, naRef me, int argc, naRef* args)
   return naNum(b.gen_index());
 }
 
-static naRef f_route(naContext c, naRef me, int argc, naRef* args)
+static naRef f_createFlightplan(naContext c, naRef me, int argc, naRef* args)
 {
-  if (argc == 0) {
-    FGRouteMgr* rm = static_cast<FGRouteMgr*>(globals->get_subsystem("route-manager"));  
-    return ghostForFlightPlan(c, rm->flightPlan());
-  }
-  
-  if ((argc > 0) && naIsString(args[0])) {
-    flightgear::FlightPlan* fp = new flightgear::FlightPlan;
-    SGPath path(naStr_data(args[0]));
-    if (!path.exists()) {
-        std::string pdata = path.utf8Str();
-      naRuntimeError(c, "flightplan, no file at path %s", pdata.c_str());
+    flightgear::FlightPlanRef fp(new flightgear::FlightPlan);
+    
+    if ((argc > 0) && naIsString(args[0])) {
+        SGPath path(naStr_data(args[0]));
+        if (!path.exists()) {
+            std::string pdata = path.utf8Str();
+            naRuntimeError(c, "createFlightplan, no file at path %s", pdata.c_str());
+        }
+        
+        if (!fp->load(path)) {
+            SG_LOG(SG_NASAL, SG_WARN, "failed to load flight-plan from " << path);
+            return naNil();
+        }
+        
     }
     
-    if (!fp->load(path)) {
-      SG_LOG(SG_NASAL, SG_WARN, "failed to load flight-plan from " << path);
-      delete fp;
-      return naNil();
+    return ghostForFlightPlan(c, fp.get());
+}
+
+static naRef f_flightplan(naContext c, naRef me, int argc, naRef* args)
+{
+    if (argc == 0) {
+        FGRouteMgr* rm = static_cast<FGRouteMgr*>(globals->get_subsystem("route-manager"));
+        return ghostForFlightPlan(c, rm->flightPlan());
     }
     
-    return ghostForFlightPlan(c, fp);
-  }
-  
-  naRuntimeError(c, "bad arguments to flightplan()");
-  return naNil();
+    if ((argc > 0) && naIsString(args[0])) {
+        return f_createFlightplan(c, me, argc, args);
+    }
+    
+    naRuntimeError(c, "bad arguments to flightplan()");
+    return naNil();
 }
 
 class NasalFPDelegate : public FlightPlan::Delegate
@@ -2246,8 +2418,8 @@ static naRef f_flightplan_insertWP(naContext c, naRef me, int argc, naRef* args)
     index = (int) args[1].num;
   }
   
-  fp->insertWayptAtIndex(wp.get(), index);
-  return naNil();
+  auto leg = fp->insertWayptAtIndex(wp.get(), index);
+  return ghostForLeg(c, leg);
 }
 
 static naRef f_flightplan_insertWPAfter(naContext c, naRef me, int argc, naRef* args)
@@ -2263,8 +2435,8 @@ static naRef f_flightplan_insertWPAfter(naContext c, naRef me, int argc, naRef*
     index = (int) args[1].num;
   }
   
-  fp->insertWayptAtIndex(wp.get(), index + 1);
-  return naNil();
+  auto leg = fp->insertWayptAtIndex(wp.get(), index + 1);
+  return ghostForLeg(c, leg);
 }
 
 static naRef f_flightplan_insertWaypoints(naContext c, naRef me, int argc, naRef* args)
@@ -2412,6 +2584,15 @@ static naRef f_flightplan_indexOfWp(naContext c, naRef me, int argc, naRef* args
     return naNum(fp->findWayptIndex(positioned));
   }
   
+  FlightPlan::Leg* leg = fpLegGhost(args[0]);
+  if (leg) {
+    if (leg->owner() == fp) {
+      return naNum(leg->index());
+    }
+    
+    naRuntimeError(c, "flightplan.indexOfWP called on leg from different flightplan");
+  }
+
   SGGeod pos;
   int argOffset = geodFromArgs(args, 0, argc, pos);
   if (argOffset > 0) {
@@ -2421,19 +2602,52 @@ static naRef f_flightplan_indexOfWp(naContext c, naRef me, int argc, naRef* args
   return naNum(-1);
 }
 
+static naRef f_flightplan_save(naContext c, naRef me, int argc, naRef* args)
+{
+  FlightPlan* fp = flightplanGhost(me);
+  if (!fp) {
+    naRuntimeError(c, "save called on non-flightplan object");
+  }
+  
+  if ((argc < 1) || !naIsString(args[0])) {
+    naRuntimeError(c, "flightplan.save, no file path argument");
+  }
+  
+  SGPath raw_path(naStr_data(args[0]));
+  SGPath validated_path = fgValidatePath(raw_path, true);
+  if (validated_path.isNull()) {
+    naRuntimeError(c, "flightplan.save, writing to path is not permitted");
+  }
+  
+  bool ok = fp->save(validated_path);
+  return naNum(ok);
+}
+
 static naRef f_leg_setSpeed(naContext c, naRef me, int argc, naRef* args)
 {
   FlightPlan::Leg* leg = fpLegGhost(me);
   if (!leg) {
     naRuntimeError(c, "leg.setSpeed called on non-flightplan-leg object");
   }
-
-    double speed = 0.0;
-    if ((argc < 2) || !convertToNum(args[0], speed))
+  
+  double speed = 0.0;
+  RouteRestriction rr = RESTRICT_AT;
+  if (argc > 0) {
+    if (naIsNil(args[0])) {
+        // clear the restriction to NONE
+      rr = RESTRICT_NONE;
+    } else if (convertToNum(args[0], speed)) {
+      if ((argc > 1) && naIsString(args[1])) {
+        rr = routeRestrictionFromArg(args[1]);
+      } else {
         naRuntimeError(c, "bad arguments to setSpeed");
+      }
+    }
     
-  RouteRestriction rr = routeRestrictionFromString(naStr_data(args[1]));
-  leg->setSpeed(rr, speed);
+    leg->setSpeed(rr, speed);
+  } else {
+      naRuntimeError(c, "bad arguments to setSpeed");
+  }
   
   return naNil();
 }
@@ -2445,13 +2659,25 @@ static naRef f_leg_setAltitude(naContext c, naRef me, int argc, naRef* args)
     naRuntimeError(c, "leg.setAltitude called on non-flightplan-leg object");
   }
   
-    double alt = 0.0;
-    if ((argc < 2) || !convertToNum(args[0], alt))
+  double altitude = 0.0;
+  RouteRestriction rr = RESTRICT_AT;
+  if (argc > 0) {
+    if (naIsNil(args[0])) {
+      // clear the restriction to NONE
+      rr = RESTRICT_NONE;
+    } else if (convertToNum(args[0], altitude)) {
+      if (argc > 1) {
+        rr = routeRestrictionFromArg(args[1]);
+      } else {
         naRuntimeError(c, "bad arguments to leg.setAltitude");
+      }
+    }
+    
+    leg->setAltitude(rr, altitude);
+  } else {
+      naRuntimeError(c, "bad arguments to setleg.setAltitude");
+  }
     
-  RouteRestriction rr = routeRestrictionFromString(naStr_data(args[1]));
-    leg->setAltitude(rr, alt);
-
   return naNil();
 }
 
@@ -2498,65 +2724,6 @@ static naRef f_leg_courseAndDistanceFrom(naContext c, naRef me, int argc, naRef*
     return result;
 }
 
-static naRef f_waypoint_navaid(naContext c, naRef me, int argc, naRef* args)
-{
-  flightgear::Waypt* w = wayptGhost(me);
-  if (!w) {
-    naRuntimeError(c, "waypoint.navaid called on non-waypoint object");
-  }
-  
-  FGPositioned* pos = w->source();
-  if (!pos) {
-    return naNil();
-  }
-  
-  switch (pos->type()) {
-  case FGPositioned::VOR:
-  case FGPositioned::NDB:
-  case FGPositioned::ILS:
-  case FGPositioned::LOC:
-  case FGPositioned::GS:
-  case FGPositioned::DME:
-  case FGPositioned::TACAN: {
-    FGNavRecord* nav = (FGNavRecord*) pos;
-    return ghostForNavaid(c, nav);
-  }
-      
-  default:
-    return naNil();
-  }
-}
-
-static naRef f_waypoint_airport(naContext c, naRef me, int argc, naRef* args)
-{
-  flightgear::Waypt* w = wayptGhost(me);
-  if (!w) {
-    naRuntimeError(c, "waypoint.navaid called on non-waypoint object");
-  }
-  
-  FGPositioned* pos = w->source();
-  if (!pos || FGAirport::isAirportType(pos)) {
-    return naNil();
-  }
-  
-  return ghostForAirport(c, (FGAirport*) pos);
-}
-
-static naRef f_waypoint_runway(naContext c, naRef me, int argc, naRef* args)
-{
-  flightgear::Waypt* w = wayptGhost(me);
-  if (!w) {
-    naRuntimeError(c, "waypoint.navaid called on non-waypoint object");
-  }
-  
-  FGPositioned* pos = w->source();
-  if (!pos || (pos->type() != FGPositioned::RUNWAY)) {
-    return naNil();
-  }
-  
-  return ghostForRunway(c, (FGRunway*) pos);
-}
-
 static naRef f_procedure_transition(naContext c, naRef me, int argc, naRef* args)
 {
   Procedure* proc = procedureGhost(me);
@@ -2634,11 +2801,14 @@ static struct { const char* name; naCFunction func; } funcs[] = {
   { "findAirportsByICAO", f_findAirportsByICAO },
   { "navinfo", f_navinfo },
   { "findNavaidsWithinRange", f_findNavaidsWithinRange },
-  { "findNavaidByFrequency", f_findNavaidByFrequency },
-  { "findNavaidsByFrequency", f_findNavaidsByFrequency },
+  { "findNDBByFrequencyKHz", f_findNDBByFrequency },
+  { "findNDBsByFrequencyKHz", f_findNDBsByFrequency },
+  { "findNavaidByFrequencyMHz", f_findNavaidByFrequency },
+  { "findNavaidsByFrequencyMHz", f_findNavaidsByFrequency },
   { "findNavaidsByID", f_findNavaidsByIdent },
   { "findFixesByID", f_findFixesByIdent },
-  { "flightplan", f_route },
+  { "flightplan", f_flightplan },
+  { "createFlightplan", f_createFlightplan },
   { "registerFlightPlanDelegate", f_registerFPDelegate },
   { "createWP", f_createWP },
   { "createWPFrom", f_createWPFrom },
@@ -2693,14 +2863,9 @@ naRef initNasalPositioned(naRef globals, naContext c)
     hashset(c, flightplanPrototype, "finish", naNewFunc(c, naNewCCode(c, f_flightplan_finish)));
     hashset(c, flightplanPrototype, "activate", naNewFunc(c, naNewCCode(c, f_flightplan_activate)));
     hashset(c, flightplanPrototype, "indexOfWP", naNewFunc(c, naNewCCode(c, f_flightplan_indexOfWp)));
-    
-    waypointPrototype = naNewHash(c);
-    naSave(c, waypointPrototype);
-    
-    hashset(c, waypointPrototype, "navaid", naNewFunc(c, naNewCCode(c, f_waypoint_navaid)));
-    hashset(c, waypointPrototype, "runway", naNewFunc(c, naNewCCode(c, f_waypoint_runway)));
-    hashset(c, waypointPrototype, "airport", naNewFunc(c, naNewCCode(c, f_waypoint_airport)));
-  
+
+    hashset(c, flightplanPrototype, "save", naNewFunc(c, naNewCCode(c, f_flightplan_save)));
+
     procedurePrototype = naNewHash(c);
     naSave(c, procedurePrototype);
     hashset(c, procedurePrototype, "transition", naNewFunc(c, naNewCCode(c, f_procedure_transition)));
