@@ -38,6 +38,7 @@
 #include <simgear/nasal/cppbind/Ghost.hxx>
 #include <simgear/nasal/cppbind/NasalHash.hxx>
 
+#include "NasalAddons.hxx"
 #include "NasalSGPath.hxx"
 #include "NasalSys.hxx"
 #include "NasalSys_private.hxx"
@@ -297,20 +298,37 @@ FGNasalSys::~FGNasalSys()
     nasalSys = 0;
 }
 
-bool FGNasalSys::parseAndRun(const char* sourceCode)
+bool FGNasalSys::parseAndRunWithOutput(const std::string& source, std::string& output, std::string& errors)
 {
     naContext ctx = naNewContext();
-    naRef code = parse(ctx, "FGNasalSys::parseAndRun()", sourceCode,
-                       strlen(sourceCode));
+    naRef code = parse(ctx, "FGNasalSys::parseAndRun()", source.c_str(),
+                       source.size(), errors);
     if(naIsNil(code)) {
         naFreeContext(ctx);
         return false;
     }
-    callWithContext(ctx, code, 0, 0, naNil());
+    naRef result = callWithContext(ctx, code, 0, 0, naNil());
+    
+    // if there was a result value, try to convert it to a string
+    // value.
+    if (!naIsNil(result)) {
+        naRef s = naStringValue(ctx, result);
+        if (!naIsNil(s)) {
+            output = naStr_data(s);
+        }
+    }
+    
     naFreeContext(ctx);
     return true;
 }
 
+bool FGNasalSys::parseAndRun(const std::string& source)
+{
+    std::string errors;
+    std::string output;
+    return parseAndRunWithOutput(source, output, errors);
+}
+
 #if 0
 FGNasalScript* FGNasalSys::parseScript(const char* src, const char* name)
 {
@@ -490,7 +508,7 @@ static naRef f_fgcommand(naContext c, naRef me, int argc, naRef* args)
     else
         node = new SGPropertyNode;
 
-    return naNum(globals->get_commands()->execute(naStr_data(cmd), node));
+    return naNum(globals->get_commands()->execute(naStr_data(cmd), node, nullptr));
 }
 
 // settimer(func, dt, simtime) extension function.  Falls through to
@@ -662,7 +680,7 @@ public:
         _sys->gcRelease(_gcRoot);
     }
 
-    virtual bool operator()(const SGPropertyNode* aNode)
+    virtual bool operator()(const SGPropertyNode* aNode, SGPropertyNode * root)
     {
         _sys->setCmdArg(const_cast<SGPropertyNode*>(aNode));
         naRef args[1];
@@ -881,7 +899,7 @@ void FGNasalSys::init()
     for(i=0; funcs[i].name; i++)
         hashset(_globals, funcs[i].name,
                 naNewFunc(_context, naNewCCode(_context, funcs[i].func)));
-    nasal::Hash io_module = nasal::Hash(_globals, _context).get<nasal::Hash>("io");
+    nasal::Hash io_module = getGlobals().get<nasal::Hash>("io");
     io_module.set("open", f_open);
 
     // And our SGPropertyNode wrapper
@@ -911,9 +929,7 @@ void FGNasalSys::init()
       .member("simulatedTime", &TimerObj::isSimTime, &f_timerObj_setSimTime)
       .member("isRunning", &TimerObj::isRunning);
 
-
-    // Set allowed paths for Nasal I/O
-    fgInitAllowedPaths();
+    flightgear::addons::initAddonClassesForNasal(_globals, _context);
 
     // Now load the various source files in the Nasal directory
     simgear::Dir nasalDir(SGPath(globals->get_fg_root(), "Nasal"));
@@ -1209,7 +1225,8 @@ bool FGNasalSys::createModule(const char* moduleName, const char* fileName,
                               int argc, naRef* args)
 {
     naContext ctx = naNewContext();
-    naRef code = parse(ctx, fileName, src, len);
+    std::string errors;
+    naRef code = parse(ctx, fileName, src, len, errors);
     if(naIsNil(code)) {
         naFreeContext(ctx);
         return false;
@@ -1258,16 +1275,21 @@ naRef FGNasalSys::getModule(const char* moduleName)
     return mod;
 }
 
-naRef FGNasalSys::parse(naContext ctx, const char* filename, const char* buf, int len)
+naRef FGNasalSys::parse(naContext ctx, const char* filename,
+                        const char* buf, int len,
+                        std::string& errors)
 {
     int errLine = -1;
     naRef srcfile = naNewString(ctx);
     naStr_fromdata(srcfile, (char*)filename, strlen(filename));
     naRef code = naParseCode(ctx, srcfile, 1, (char*)buf, len, &errLine);
     if(naIsNil(code)) {
-        SG_LOG(SG_NASAL, SG_ALERT,
-               "Nasal parse error: " << naGetError(ctx) <<
-               " in "<< filename <<", line " << errLine);
+        std::ostringstream errorMessageStream;
+        errorMessageStream << "Nasal parse error: " << naGetError(ctx) <<
+            " in "<< filename <<", line " << errLine;
+        errors = errorMessageStream.str();
+        SG_LOG(SG_NASAL, SG_ALERT, errors);
+               
         return naNil();
     }
 
@@ -1278,10 +1300,12 @@ naRef FGNasalSys::parse(naContext ctx, const char* filename, const char* buf, in
 bool FGNasalSys::handleCommand( const char* moduleName,
                                 const char* fileName,
                                 const char* src,
-                                const SGPropertyNode* arg )
+                                const SGPropertyNode* arg,
+                                SGPropertyNode* root)
 {
     naContext ctx = naNewContext();
-    naRef code = parse(ctx, fileName, src, strlen(src));
+    std::string errorMessage;
+    naRef code = parse(ctx, fileName, src, strlen(src), errorMessage);
     if(naIsNil(code)) {
         naFreeContext(ctx);
         return false;
@@ -1310,7 +1334,7 @@ bool FGNasalSys::handleCommand( const char* moduleName,
     return true;
 }
 
-bool FGNasalSys::handleCommand(const SGPropertyNode* arg)
+bool FGNasalSys::handleCommand(const SGPropertyNode * arg, SGPropertyNode * root)
 {
   const char* src = arg->getStringValue("script");
   const char* moduleName = arg->getStringValue("module");
@@ -1318,7 +1342,8 @@ bool FGNasalSys::handleCommand(const SGPropertyNode* arg)
   return handleCommand( moduleName,
                         arg->getPath(true).c_str(),
                         src,
-                        arg );
+                        arg,
+                        root);
 }
 
 // settimer(func, dt, simtime) extension function.  The first argument
