@@ -24,11 +24,17 @@
 #include <Main/fg_props.hxx>
 
 #include <sstream>
+#include <limits>
 
 #if defined(SG_MAC)
     #include <osgViewer/api/Cocoa/GraphicsWindowCocoa>
 #endif
 
+#if defined(HAVE_QT)
+    #include "GraphicsWindowQt5.hxx"
+#endif
+
+
 using namespace std;
 using namespace osg;
 
@@ -56,16 +62,19 @@ void WindowBuilder::initWindowBuilder(bool stencil)
 
 WindowBuilder::WindowBuilder(bool stencil) : defaultCounter(0)
 {
-    defaultTraits = makeDefaultTraits(stencil);
+#if defined (HAVE_QT)
+    usingQtGraphicsWindow = fgGetBool("/sim/rendering/graphics-window-qt", false);
+#endif
+    makeDefaultTraits(stencil);
 }
 
-GraphicsContext::Traits*
-WindowBuilder::makeDefaultTraits(bool stencil)
+void WindowBuilder::makeDefaultTraits(bool stencil)
 {
     GraphicsContext::WindowingSystemInterface* wsi
         = osg::GraphicsContext::getWindowingSystemInterface();
-    GraphicsContext::Traits* traits = new osg::GraphicsContext::Traits;
-
+    defaultTraits = new osg::GraphicsContext::Traits;
+    auto traits = defaultTraits.get();
+    
     traits->readDISPLAY();
     if (traits->displayNum < 0)
         traits->displayNum = 0;
@@ -81,10 +90,6 @@ WindowBuilder::makeDefaultTraits(bool stencil)
     if (stencil)
         traits->stencil = 8;
 
-    unsigned screenwidth = 0;
-    unsigned screenheight = 0;
-    wsi->getScreenResolution(*traits, screenwidth, screenheight);
-
     traits->doubleBuffer = true;
     traits->mipMapGeneration = true;
     traits->windowName = "FlightGear";
@@ -92,31 +97,61 @@ WindowBuilder::makeDefaultTraits(bool stencil)
     traits->sampleBuffers = fgGetInt("/sim/rendering/multi-sample-buffers", traits->sampleBuffers);
     traits->samples = fgGetInt("/sim/rendering/multi-samples", traits->samples);
     traits->vsync = fgGetBool("/sim/rendering/vsync-enable", traits->vsync);
-    traits->windowDecoration = !fgGetBool("/sim/startup/fullscreen");
-
-    if (!traits->windowDecoration) {
-        // fullscreen
-        traits->supportsResize = false;
-        traits->width = screenwidth;
-        traits->height = screenheight;
-        SG_LOG(SG_VIEW,SG_DEBUG,"Using full screen size for window: " << screenwidth << " x " << screenheight);
-    } else {
-        // window
-        int w = fgGetInt("/sim/startup/xsize");
-        int h = fgGetInt("/sim/startup/ysize");
+    
+    const bool wantFullscreen = fgGetBool("/sim/startup/fullscreen");
+    if (usingQtGraphicsWindow) {
+#if defined(HAVE_QT)
+        // fullscreen is handled by Qt natively
+        // we will check and set fullscreen mode when building
+        // the window instance
+        auto data = new GraphicsWindowQt5::WindowData;
+        data->createFullscreen = wantFullscreen;
+        data->isPrimaryWindow = true;
+        
+        traits->inheritedWindowData = data;
+        traits->windowDecoration = true;
         traits->supportsResize = true;
-        traits->width = w;
-        traits->height = h;
-        if ((w>0)&&(h>0))
-        {
-            traits->x = ((unsigned)w>screenwidth) ? 0 : (screenwidth-w)/3;
-            traits->y = ((unsigned)h>screenheight) ? 0 : (screenheight-h)/3;
+        traits->width = fgGetInt("/sim/startup/xsize");
+        traits->height = fgGetInt("/sim/startup/ysize");
+        
+        // these are marker values to tell GraphicsWindowQt5 to use default x/y
+        traits->x = std::numeric_limits<int>::max();
+        traits->y = std::numeric_limits<int>::max();
+#else
+        SG_LOG(SG_VIEW,SG_ALERT,"requested Qt GraphicsWindow in non-Qt build");
+#endif
+    } else {
+        unsigned screenwidth = 0;
+        unsigned screenheight = 0;
+        // this is a deprecated method, should be screen-aware.
+        wsi->getScreenResolution(*traits, screenwidth, screenheight);
+        
+        // handle fullscreen manually
+        traits->windowDecoration = !wantFullscreen;
+        if (!traits->windowDecoration) {
+            // fullscreen
+            traits->supportsResize = false;
+            traits->width = screenwidth;
+            traits->height = screenheight;
+            SG_LOG(SG_VIEW,SG_DEBUG,"Using full screen size for window: " << screenwidth << " x " << screenheight);
+        } else {
+            // window
+            int w = fgGetInt("/sim/startup/xsize");
+            int h = fgGetInt("/sim/startup/ysize");
+            traits->supportsResize = true;
+            traits->width = w;
+            traits->height = h;
+            if ((w>0)&&(h>0))
+            {
+                traits->x = ((unsigned)w>screenwidth) ? 0 : (screenwidth-w)/3;
+                traits->y = ((unsigned)h>screenheight) ? 0 : (screenheight-h)/3;
+            }
+            SG_LOG(SG_VIEW,SG_DEBUG,"Using initial window size: " << w << " x " << h);
         }
-        SG_LOG(SG_VIEW,SG_DEBUG,"Using initial window size: " << w << " x " << h);
     }
-    return traits;
-}
 }
+    
+} // of namespace flightgear
 
 namespace
 {
@@ -159,10 +194,93 @@ inline int setFromProperty(bool& place, const SGPropertyNode* node,
 
 namespace flightgear
 {
+    
+void WindowBuilder::setFullscreenTraits(const SGPropertyNode* winNode, GraphicsContext::Traits* traits)
+{
+    const SGPropertyNode* orrNode = winNode->getNode("overrideRedirect");
+    bool overrideRedirect = orrNode && orrNode->getBoolValue();
+    traits->overrideRedirect = overrideRedirect;
+
+#if defined(HAVE_QT)
+    if (usingQtGraphicsWindow) {
+        auto data = new GraphicsWindowQt5::WindowData;
+        data->createFullscreen = true;
+        traits->inheritedWindowData = data;
+        traits->windowDecoration = winNode->getBoolValue("decoration");
+    } else
+#endif
+    // this codepath is mandatory on non-Qt builds
+    {
+        traits->windowDecoration = false;
+        
+        unsigned int width = 0;
+        unsigned int height = 0;
+        auto wsi = osg::GraphicsContext::getWindowingSystemInterface();
+        wsi->getScreenResolution(*traits, width, height);
+        traits->width = width;
+        traits->height = height;
+        traits->supportsResize = false;
+        traits->x = 0;
+        traits->y = 0;
+    }
+}
+
+bool WindowBuilder::setWindowedTraits(const SGPropertyNode* winNode, GraphicsContext::Traits* traits)
+{
+    bool customTraits = false;
+#if defined(HAVE_QT)
+    if (usingQtGraphicsWindow) {
+        if (winNode->hasValue("fullscreen")) {
+            auto data = new GraphicsWindowQt5::WindowData;
+            data->createFullscreen = false;
+            traits->inheritedWindowData = data;
+            customTraits = true;
+        }
+        customTraits |= setFromProperty(traits->windowDecoration, winNode, "decoration");
+        customTraits |= setFromProperty(traits->width, winNode, "width");
+        customTraits |= setFromProperty(traits->height, winNode, "height");
+    } else
+#endif
+    {
+        int resizable = 0;
+        const SGPropertyNode* fullscreenNode = winNode->getNode("fullscreen");
+        if (fullscreenNode && !fullscreenNode->getBoolValue())
+        {
+            traits->windowDecoration = true;
+            resizable = 1;
+        }
+        resizable |= setFromProperty(traits->windowDecoration, winNode, "decoration");
+        resizable |= setFromProperty(traits->width, winNode, "width");
+        resizable |= setFromProperty(traits->height, winNode, "height");
+        if (resizable) {
+            traits->supportsResize = true;
+            customTraits = true;
+        }
+    }
+    
+    return customTraits;
+}
+    
+void WindowBuilder::setMacPoseAsStandaloneApp(GraphicsContext::Traits* traits)
+{
+#if defined(SG_MAC)
+    if (!usingQtGraphicsWindow) {
+        // this logic is unecessary if using a Qt window, since everything
+        // plays together nicely
+        int flags = osgViewer::GraphicsWindowCocoa::WindowData::CheckForEvents;
+        
+        // avoid both QApplication and OSG::CocoaViewer doing single-application
+        // init (Apple menu, making front process, etc)
+        if (poseAsStandaloneApp) {
+            flags |= osgViewer::GraphicsWindowCocoa::WindowData::PoseAsStandaloneApp;
+        }
+        traits->inheritedWindowData = new osgViewer::GraphicsWindowCocoa::WindowData(flags);
+    }
+#endif
+}
+    
 GraphicsWindow* WindowBuilder::buildWindow(const SGPropertyNode* winNode)
 {
-    GraphicsContext::WindowingSystemInterface* wsi
-        = osg::GraphicsContext::getWindowingSystemInterface();
     WindowSystemAdapter* wsa = WindowSystemAdapter::getWSA();
     string windowName;
     if (winNode->hasChild("window-name"))
@@ -171,49 +289,22 @@ GraphicsWindow* WindowBuilder::buildWindow(const SGPropertyNode* winNode)
         windowName = winNode->getStringValue("name");
     GraphicsWindow* result = 0;
     if (!windowName.empty()) {
+        // look for an existing window and return that
         result = wsa->findWindow(windowName);
         if (result)
             return result;
     }
-    GraphicsContext::Traits* traits
-        = new GraphicsContext::Traits(*defaultTraits);
+    auto traits = new GraphicsContext::Traits(*defaultTraits);
     int traitsSet = setFromProperty(traits->hostName, winNode, "host-name");
     traitsSet |= setFromProperty(traits->displayNum, winNode, "display");
     traitsSet |= setFromProperty(traits->screenNum, winNode, "screen");
 
     const SGPropertyNode* fullscreenNode = winNode->getNode("fullscreen");
-    const SGPropertyNode* orrNode = winNode->getNode("overrideRedirect");
-
     if (fullscreenNode && fullscreenNode->getBoolValue()) {
-        // fullscreen mode
-        unsigned width = 0;
-        unsigned height = 0;
-        wsi->getScreenResolution(*traits, width, height);
-        traits->windowDecoration = false;
-        traits->width = width;
-        traits->height = height;
-        traits->supportsResize = false;
-	bool overrideRedirect = orrNode && orrNode->getBoolValue();
-	traits->overrideRedirect = overrideRedirect;
-        traits->x = 0;
-        traits->y = 0;
+        setFullscreenTraits(winNode, traits);
         traitsSet = 1;
     } else {
-        int resizable = 0;
-        if (fullscreenNode && !fullscreenNode->getBoolValue())
-        {
-            traits->windowDecoration = true;
-            resizable = 1;
-        }
-        resizable |= setFromProperty(traits->windowDecoration, winNode,
-                                     "decoration");
-        resizable |= setFromProperty(traits->width, winNode, "width");
-        resizable |= setFromProperty(traits->height, winNode, "height");
-        if (resizable) {
-            traits->supportsResize = true;
-            traitsSet = 1;
-        }
-        // Otherwise use default values.
+        traitsSet |= setWindowedTraits(winNode, traits);
     }
     traitsSet |= setFromProperty(traits->x, winNode, "x");
     traitsSet |= setFromProperty(traits->y, winNode, "y");
@@ -224,20 +315,19 @@ GraphicsWindow* WindowBuilder::buildWindow(const SGPropertyNode* winNode)
         traits->windowName = makeName("FlightGear", defaultCounter++);
     }
 
-#if defined(SG_MAC)
-    int flags = osgViewer::GraphicsWindowCocoa::WindowData::CheckForEvents;
+    setMacPoseAsStandaloneApp(traits);
 
-    // avoid both QApplication and OSG::CocoaViewer doing single-application
-    // init (Apple menu, making front process, etc)
-    if (poseAsStandaloneApp) {
-        flags |= osgViewer::GraphicsWindowCocoa::WindowData::PoseAsStandaloneApp;
-    }
-    traits->inheritedWindowData = new osgViewer::GraphicsWindowCocoa::WindowData(flags);
-#endif
-    
     bool drawGUI = false;
     traitsSet |= setFromProperty(drawGUI, winNode, "gui");
     if (traitsSet) {
+#if defined (HAVE_QT)
+        if (usingQtGraphicsWindow) {
+            // this assumes the user only sets the 'gui' flag on one window, not ideal
+            auto data = static_cast<GraphicsWindowQt5::WindowData*>(traits->inheritedWindowData.get());
+            data->isPrimaryWindow = drawGUI;
+        }
+#endif
+        
         GraphicsContext* gc = GraphicsContext::createGraphicsContext(traits);
         if (gc) {
             GraphicsWindow* window = WindowSystemAdapter::getWSA()
@@ -265,16 +355,7 @@ GraphicsWindow* WindowBuilder::getDefaultWindow()
         = new GraphicsContext::Traits(*defaultTraits);
     traits->windowName = "FlightGear";
 
-#if defined(SG_MAC)
-    int flags = osgViewer::GraphicsWindowCocoa::WindowData::CheckForEvents;
-
-    // avoid both QApplication and OSG::CocoaViewer doing single-application
-    // init (Apple menu, making front process, etc)
-    if (poseAsStandaloneApp) {
-        flags |= osgViewer::GraphicsWindowCocoa::WindowData::PoseAsStandaloneApp;
-    }
-    traits->inheritedWindowData = new osgViewer::GraphicsWindowCocoa::WindowData(flags);
-#endif
+    setMacPoseAsStandaloneApp(traits);
 
     GraphicsContext* gc = GraphicsContext::createGraphicsContext(traits);
     if (gc) {
