@@ -2,7 +2,7 @@
 // implemented as an osgViewer
 //
 // Copyright (C) 2007  Tim Moore timoore@redhat.com
-// Copyright (C) 2007 Mathias Froehlich 
+// Copyright (C) 2007 Mathias Froehlich
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -18,9 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include <algorithm>
 #include <iostream>
@@ -61,6 +59,12 @@
 #include "WindowBuilder.hxx"
 #include "WindowSystemAdapter.hxx"
 
+#if defined(HAVE_QT)
+#include "GraphicsWindowQt5.hxx"
+#include <GUI/QtLauncher.hxx>
+#include <QCoreApplication>
+#endif
+
 // Static linking of OSG needs special macros
 #ifdef OSG_LIBRARY_STATIC
 #include <osgDB/Registry>
@@ -97,12 +101,14 @@ USE_OSGPLUGIN(txf);
 // fg_os implementation
 //
 
-using namespace std;    
+using namespace std;
 using namespace flightgear;
 using namespace osg;
 
 osg::ref_ptr<osgViewer::Viewer> viewer;
 
+bool global_usingGraphicsWindowQt = false;
+
 static void setStereoMode( const char * mode )
 {
     DisplaySettings::StereoMode stereoMode = DisplaySettings::QUAD_BUFFER;
@@ -144,7 +150,7 @@ static void setStereoMode( const char * mode )
     {
         stereoMode = DisplaySettings::CHECKERBOARD;
     } else {
-        stereoOn = false; 
+        stereoOn = false;
     }
     DisplaySettings::instance()->setStereo( stereoOn );
     DisplaySettings::instance()->setStereoMode( stereoMode );
@@ -173,7 +179,7 @@ static const char * getStereoMode()
         return "VERTICAL_INTERLACE";
     } else if( stereoMode == DisplaySettings::CHECKERBOARD ) {
         return "CHECKERBOARD";
-    } 
+    }
     return "OFF";
 }
 
@@ -226,7 +232,7 @@ public:
     {
         osg::NotifySeverity severity = osg::WARN;
         string val = boost::to_lower_copy(string(node->getStringValue()));
-        
+
         if (val == "fatal") {
             severity = osg::FATAL;
         } else if (val == "warn") {
@@ -238,7 +244,7 @@ public:
         } else if ((val == "debug") || (val == "debug-info")) {
             severity = osg::DEBUG_INFO;
         }
-        
+
         osg::setNotifyLevel(severity);
     }
 };
@@ -250,7 +256,7 @@ void updateOSGNotifyLevel()
 void fgOSOpenWindow(bool stencil)
 {
     osg::setNotifyHandler(new NotifyLogger);
-    
+
     viewer = new osgViewer::Viewer;
     viewer->setDatabasePager(FGScenery::getPagerSingleton());
 
@@ -268,7 +274,7 @@ void fgOSOpenWindow(bool stencil)
       viewer->setThreadingModel(osgViewer::Viewer::SingleThreaded);
     WindowBuilder::initWindowBuilder(stencil);
     CameraGroup::buildDefaultGroup(viewer.get());
-    
+
     FGEventHandler* manipulator = globals->get_renderer()->getEventHandler();
     WindowSystemAdapter* wsa = WindowSystemAdapter::getWSA();
     if (wsa->windows.size() != 1) {
@@ -289,14 +295,14 @@ void fgOSResetProperties()
     NotifyLevelListener* l = new NotifyLevelListener;
     globals->addListenerToCleanup(l);
     osgLevel->addChangeListener(l, true);
-    
+
     osg::Camera* guiCamera = getGUICamera(CameraGroup::getDefault());
     if (guiCamera) {
         Viewport* guiViewport = guiCamera->getViewport();
         fgSetInt("/sim/startup/xsize", guiViewport->width());
         fgSetInt("/sim/startup/ysize", guiViewport->height());
     }
-    
+
     DisplaySettings * displaySettings = DisplaySettings::instance();
     fgTie("/sim/rendering/osg-displaysettings/eye-separation", displaySettings, &DisplaySettings::getEyeSeparation, &DisplaySettings::setEyeSeparation );
     fgTie("/sim/rendering/osg-displaysettings/screen-distance", displaySettings, &DisplaySettings::getScreenDistance, &DisplaySettings::setScreenDistance );
@@ -316,7 +322,7 @@ void fgOSExit(int code)
     viewer->setDone(true);
     viewer->getDatabasePager()->cancel();
     status = code;
-    
+
     // otherwise we crash if OSG does logging during static destruction, eg
     // GraphicsWindowX11, since OSG statics may have been created before the
     // sglog static, despite our best efforts in boostrap.cxx
@@ -326,16 +332,19 @@ void fgOSExit(int code)
 int fgOSMainLoop()
 {
     viewer->setReleaseContextAtEndOfFrameHint(false);
-    if (!viewer->isRealized())
+    if (!viewer->isRealized()) {
         viewer->realize();
+    }
+
     while (!viewer->done()) {
         fgIdleHandler idleFunc = globals->get_renderer()->getEventHandler()->getIdleHandler();
         if (idleFunc)
             (*idleFunc)();
+
         globals->get_renderer()->update();
         viewer->frame( globals->get_sim_time_sec() );
     }
-    
+
     return status;
 }
 
@@ -345,7 +354,7 @@ int fgGetKeyModifiers()
     if (!r || !r->getEventHandler()) { // happens during shutdown
       return 0;
     }
-    
+
     return r->getEventHandler()->getCurrentModifiers();
 }
 
@@ -356,6 +365,18 @@ void fgWarpMouse(int x, int y)
 
 void fgOSInit(int* argc, char** argv)
 {
+#if defined(HAVE_QT)
+    global_usingGraphicsWindowQt = fgGetBool("/sim/rendering/graphics-window-qt", false);
+    if (global_usingGraphicsWindowQt) {
+        flightgear::initApp(*argc, argv);
+        SG_LOG(SG_GL, SG_INFO, "Using Qt implementation of GraphicsWindow");
+        flightgear::initQtWindowingSystem();
+    } else {
+        // stock OSG windows are not Hi-DPI aware
+        fgSetDouble("/sim/rendering/gui-pixel-ratio", 1.0);
+        SG_LOG(SG_GL, SG_INFO, "Using stock OSG implementation of GraphicsWindow");
+    }
+#endif
     globals->get_renderer()->init();
     WindowSystemAdapter::setWSA(new WindowSystemAdapter);
 }
@@ -365,7 +386,7 @@ void fgOSCloseWindow()
     if (viewer) {
         // https://code.google.com/p/flightgear-bugs/issues/detail?id=1291
         // https://sourceforge.net/p/flightgear/codetickets/1830/
-        // explicitly stop trheading before we delete the renderer or
+        // explicitly stop threading before we delete the renderer or
         // viewMgr (which ultimately holds refs to the CameraGroup, and
         // GraphicsContext)
         viewer->stopThreading();
@@ -388,9 +409,20 @@ void fgOSFullScreen()
      * The other windows should use fixed setup from the camera.xml file anyway. */
     osgViewer::GraphicsWindow* window = windows[0];
 
+#if defined(HAVE_QT)
+    if (global_usingGraphicsWindowQt) {
+        const bool wasFullscreen = fgGetBool("/sim/startup/fullscreen");
+        auto qtWin = static_cast<flightgear::GraphicsWindowQt5*>(window);
+        qtWin->setFullscreen(!wasFullscreen);
+        fgSetBool("/sim/startup/fullscreen", !wasFullscreen);
+
+        // FIXME tell lies here for HiDPI sizing?
+        fgSetInt("/sim/startup/xsize", qtWin->getGLWindow()->width());
+        fgSetInt("/sim/startup/ysize", qtWin->getGLWindow()->height());
+    } else
+#endif
     {
         osg::GraphicsContext::WindowingSystemInterface    *wsi = osg::GraphicsContext::getWindowingSystemInterface();
-
         if (wsi == NULL)
         {
             SG_LOG(SG_VIEW, SG_ALERT, "ERROR: No WindowSystemInterface available. Cannot toggle window fullscreen.");
@@ -461,7 +493,7 @@ void fgOSFullScreen()
         window->setWindowDecoration(isFullScreen);
         window->setWindowRectangle(x, y, width, height);
         window->grabFocusIfPointerInWindow();
-    }
+    } // of stock GraphicsWindow verison (OSG has no native fullscreen mode)
 }
 
 static void setMouseCursor(osgViewer::GraphicsWindow* gw, int cursor)
@@ -469,7 +501,7 @@ static void setMouseCursor(osgViewer::GraphicsWindow* gw, int cursor)
     if (!gw) {
         return;
     }
-  
+
     osgViewer::GraphicsWindow::MouseCursor mouseCursor;
     mouseCursor = osgViewer::GraphicsWindow::InheritCursor;
     if (cursor == MOUSE_CURSOR_NONE)
@@ -514,7 +546,7 @@ void fgSetMouseCursor(int cursor)
     _cursor = cursor;
     if (!viewer)
         return;
-    
+
     std::vector<osgViewer::GraphicsWindow*> windows;
     viewer->getWindows(windows);
     BOOST_FOREACH(osgViewer::GraphicsWindow* gw, windows) {
