@@ -7,7 +7,7 @@
 #include <iostream>
 
 #include <simgear/constants.h>
-#include <simgear/misc/sgstream.hxx>
+#include <simgear/io/iostreams/sgstream.hxx>
 #include <simgear/misc/strutils.hxx>
 #include <simgear/misc/sg_path.hxx>
 
