@@ -21,25 +21,39 @@ public:
 
     unsigned int indexOfChild(const FGCanvasElement* e) const;
 
+    CanvasItem* createQuickItem(QQuickItem *parent) override;
+    CanvasItem* quickItem() const override
+    { return _quick; }
+
+    void removeChild(FGCanvasElement* child);
 signals:
     void childAdded();
     void childRemoved(int index);
 
+    void canvasSizeChanged();
 protected:
     virtual void doPaint(FGCanvasPaintContext* context) const override;
 
+    void doPolish() override;
+
     bool onChildAdded(LocalProp *prop) override;
     bool onChildRemoved(LocalProp *prop) override;
 
     virtual void markStyleDirty() override;
+
+    void doDestroy() override;
 private:
     void markCachedSymbolDirty();
     int indexOfChildWithProp(LocalProp *prop) const;
+    void resetChildQuickItemZValues();
 
 private:
     mutable FGCanvasElementVec _children;
     mutable bool _zIndicesDirty = false;
     mutable bool _cachedSymbolDirty = false;
+
+
+    CanvasItem* _quick = nullptr;
 };
 
 #endif // FGCANVASGROUP_H
