@@ -52,7 +52,7 @@
 #include <simgear/debug/logstream.hxx>
 #include <simgear/math/SGGeodesy.hxx>
 #include <simgear/misc/sg_path.hxx>
-#include <simgear/misc/sgstream.hxx>
+#include <simgear/io/iostreams/sgstream.hxx>
 #include <simgear/misc/ResourceManager.hxx>
 #include <simgear/props/props.hxx>
 #include <simgear/props/props_io.hxx>
@@ -160,7 +160,7 @@ int processSTG(osg::ref_ptr<simgear::SGReaderWriterOptions> options,
 	ss >> index;
 	if (ss.fail()) {
 		SG_LOG(SG_TERRAIN, SG_ALERT,
-				"Unable to determine bucket from STG filename " << ss);
+				"Unable to determine bucket from STG filename " << ss.rdbuf());
 		return EXIT_FAILURE;
 	}
 
